/*!
 * jsoneditor.js
 *
 * @brief
 * JSONEditor is a web-based tool to view, edit, format, and validate JSON.
 * It has various modes such as a tree editor, a code editor, and a plain text
 * editor.
 *
 * Supported browsers: Chrome, Firefox, Safari, Opera, Internet Explorer 8+
 *
 * @license
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy
 * of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 *
 * Copyright (c) 2011-2020 Jos de Jong, http://jsoneditoronline.org
 *
 * @author  Jos de Jong, <wjosdejong@gmail.com>
 * @version 9.1.5
 * @date    2020-12-14
 */
!function(e,t){"object"==typeof exports&&"object"==typeof module?module.exports=t():"function"==typeof define&&define.amd?define([],t):"object"==typeof exports?exports.JSONEditor=t():e.JSONEditor=t()}(window,function(){return i={},o.m=n=[function(e,t,n){"use strict";n.r(t),n.d(t,"parse",function(){return h}),n.d(t,"trySimpleJsonRepair",function(){return u}),n.d(t,"escapeUnicodeChars",function(){return p}),n.d(t,"validate",function(){return f}),n.d(t,"extend",function(){return m}),n.d(t,"clear",function(){return g}),n.d(t,"getType",function(){return v}),n.d(t,"isUrl",function(){return b}),n.d(t,"isArray",function(){return x}),n.d(t,"getWindow",function(){return C}),n.d(t,"getAbsoluteLeft",function(){return E}),n.d(t,"getAbsoluteTop",function(){return _}),n.d(t,"addClassName",function(){return T}),n.d(t,"removeAllClassNames",function(){return w}),n.d(t,"removeClassName",function(){return S}),n.d(t,"stripFormatting",function(){return j}),n.d(t,"setEndOfContentEditable",function(){return k}),n.d(t,"selectContentEditable",function(){return N}),n.d(t,"getSelection",function(){return O}),n.d(t,"setSelection",function(){return I}),n.d(t,"getSelectionOffset",function(){return D}),n.d(t,"setSelectionOffset",function(){return A}),n.d(t,"getInnerText",function(){return P}),n.d(t,"hasParentNode",function(){return F}),n.d(t,"getInternetExplorerVersion",function(){return M}),n.d(t,"isFirefox",function(){return B}),n.d(t,"addEventListener",function(){return L}),n.d(t,"removeEventListener",function(){return R}),n.d(t,"isChildOf",function(){return z}),n.d(t,"parsePath",function(){return H}),n.d(t,"stringifyPath",function(){return U}),n.d(t,"improveSchemaError",function(){return J}),n.d(t,"isPromise",function(){return $}),n.d(t,"isValidValidationError",function(){return q}),n.d(t,"insideRect",function(){return K}),n.d(t,"debounce",function(){return W}),n.d(t,"textDiff",function(){return Q}),n.d(t,"getInputSelection",function(){return Z}),n.d(t,"getIndexForPosition",function(){return X}),n.d(t,"getPositionForPath",function(){return G}),n.d(t,"compileJSONPointer",function(){return Y}),n.d(t,"getColorCSS",function(){return ee}),n.d(t,"isValidColor",function(){return te}),n.d(t,"makeFieldTooltip",function(){return ne}),n.d(t,"get",function(){return ie}),n.d(t,"findUniqueName",function(){return oe}),n.d(t,"getChildPaths",function(){return re}),n.d(t,"sort",function(){return se}),n.d(t,"sortObjectKeys",function(){return ae}),n.d(t,"parseString",function(){return le}),n.d(t,"isTimestamp",function(){return ce}),n.d(t,"formatSize",function(){return de}),n.d(t,"limitCharacters",function(){return he}),n.d(t,"isObject",function(){return ue}),n.d(t,"contains",function(){return pe}),n.d(t,"isValidationErrorChanged",function(){return fe});var t=n(19),t=n(12),o=n.n(t),t=n(7),i=n.n(t),t=n(18),r=n.n(t),t=n(20),s=n.n(t),a=n(1);function l(e){return(l="function"==typeof Symbol&&"symbol"==typeof Symbol.iterator?function(e){return typeof e}:function(e){return e&&"function"==typeof Symbol&&e.constructor===Symbol&&e!==Symbol.prototype?"symbol":typeof e})(e)}var c=1e4,d=9466848e5;function h(t){try{return JSON.parse(t)}catch(e){throw f(t),e}}function u(t){try{return i()(t)}catch(e){return t}}function p(e){return e.replace(/[\u007F-\uFFFF]/g,function(e){return"\\u"+("0000"+e.charCodeAt(0).toString(16)).slice(-4)})}function f(e){(void 0!==r.a?r.a:JSON).parse(e)}function m(e,t){for(var n in t)me(t,n)&&(e[n]=t[n]);return e}function g(e){for(var t in e)me(e,t)&&delete e[t];return e}function v(e){return null===e?"null":void 0===e?"undefined":e instanceof Number||"number"==typeof e?"number":e instanceof String||"string"==typeof e?"string":e instanceof Boolean||"boolean"==typeof e?"boolean":e instanceof RegExp?"regexp":x(e)?"array":"object"}var y=/^https?:\/\/\S+$/;function b(e){return("string"==typeof e||e instanceof String)&&y.test(e)}function x(e){return"[object Array]"===Object.prototype.toString.call(e)}function C(e){return e.ownerDocument.defaultView}function E(e){return e.getBoundingClientRect().left+window.pageXOffset||document.scrollLeft||0}function _(e){return e.getBoundingClientRect().top+window.pageYOffset||document.scrollTop||0}function T(e,t){var n=e.className.split(" ");-1===n.indexOf(t)&&(n.push(t),e.className=n.join(" "))}function w(e){e.className=""}function S(e,t){var n=e.className.split(" "),t=n.indexOf(t);-1!==t&&(n.splice(t,1),e.className=n.join(" "))}function j(e){for(var t=e.childNodes,n=0,i=t.length;n<i;n++){var o=t[n];o.style&&o.removeAttribute("style");var r=o.attributes;if(r)for(var s=r.length-1;0<=s;s--){var a=r[s];!0===a.specified&&o.removeAttribute(a.name)}j(o)}}function k(e){var t;document.createRange&&((t=document.createRange()).selectNodeContents(e),t.collapse(!1),(e=window.getSelection()).removeAllRanges(),e.addRange(t))}function N(e){var t;e&&"DIV"===e.nodeName&&window.getSelection&&document.createRange&&((t=document.createRange()).selectNodeContents(e),(e=window.getSelection()).removeAllRanges(),e.addRange(t))}function O(){if(window.getSelection){var e=window.getSelection();if(e.getRangeAt&&e.rangeCount)return e.getRangeAt(0)}return null}function I(e){var t;e&&window.getSelection&&((t=window.getSelection()).removeAllRanges(),t.addRange(e))}function D(){var e=O();return e&&"startOffset"in e&&"endOffset"in e&&e.startContainer&&e.startContainer===e.endContainer?{startOffset:e.startOffset,endOffset:e.endOffset,container:e.startContainer.parentNode}:null}function A(e){var t;document.createRange&&window.getSelection&&window.getSelection()&&(t=document.createRange(),e.container.firstChild||e.container.appendChild(document.createTextNode("")),t.setStart(e.container.firstChild,e.startOffset),t.setEnd(e.container.firstChild,e.endOffset),I(t))}function P(e,t){if(void 0===t&&(t={_text:"",flush:function(){var e=this._text;return this._text="",e},set:function(e){this._text=e}}),e.nodeValue){var n=e.nodeValue.replace(/\s*\n\s*/g,"");return""!==n?t.flush()+n:""}if(e.hasChildNodes()){for(var i=e.childNodes,o="",r=0,s=i.length;r<s;r++){var a,l=i[r];"DIV"===l.nodeName||"P"===l.nodeName?((a=(a=i[r-1])?a.nodeName:void 0)&&"DIV"!==a&&"P"!==a&&"BR"!==a&&(""!==o&&(o+="\n"),t.flush()),o+=P(l,t),t.set("\n")):"BR"===l.nodeName?(o+=t.flush(),t.set("\n")):o+=P(l,t)}return o}return""}function F(e,t){for(var n=e?e.parentNode:void 0;n;){if(n===t)return!0;n=n.parentNode}return!1}function M(){var e;return-1===V&&(e=-1,"undefined"!=typeof navigator&&"Microsoft Internet Explorer"===navigator.appName&&(null!=/MSIE ([0-9]+[.0-9]+)/.exec(navigator.userAgent)&&(e=parseFloat(RegExp.$1))),V=e),V}var V=-1;function B(){return"undefined"!=typeof navigator&&-1!==navigator.userAgent.indexOf("Firefox")}function L(e,t,n,i){if(e.addEventListener)return void 0===i&&(i=!1),"mousewheel"===t&&B()&&(t="DOMMouseScroll"),e.addEventListener(t,n,i),n;if(e.attachEvent){i=function(){return n.call(e,window.event)};return e.attachEvent("on"+t,i),i}}function R(e,t,n,i){e.removeEventListener?(void 0===i&&(i=!1),"mousewheel"===t&&B()&&(t="DOMMouseScroll"),e.removeEventListener(t,n,i)):e.detachEvent&&e.detachEvent("on"+t,n)}function z(e,t){for(var n=e.parentNode;n;){if(n===t)return!0;n=n.parentNode}return!1}function H(n){var e=[],i=0;function t(e){for(var t="";void 0!==n[i]&&n[i]!==e;)t+=n[i],i++;if(n[i]!==e)throw new Error("Invalid JSON path: unexpected end, character "+e+" expected");return t}for(;void 0!==n[i];)if("."===n[i])i++,e.push(function(){for(var e="";void 0!==n[i]&&/[\w$]/.test(n[i]);)e+=n[i],i++;if(""===e)throw new Error("Invalid JSON path: property name expected at index "+i);return e}());else{if("["!==n[i])throw new Error('Invalid JSON path: unexpected character "'+n[i]+'" at index '+i);if("'"===n[++i]||'"'===n[i]){var o=n[i];if(i++,e.push(t(o)),n[i]!==o)throw new Error("Invalid JSON path: closing quote ' expected at index "+i);i++}else{o=t("]").trim();if(0===o.length)throw new Error("Invalid JSON path: array value expected at index "+i);o="*"===o?o:JSON.parse(o),e.push(o)}if("]"!==n[i])throw new Error("Invalid JSON path: closing bracket ] expected at index "+i);i++}return e}function U(e){return e.map(function(e){return"number"==typeof e?"["+e+"]":"string"==typeof e&&e.match(/^[A-Za-z0-9_$]+$/)?"."+e:'["'+e+'"]'}).join("")}function J(e){var t,n;return"enum"!==e.keyword||!Array.isArray(e.schema)||(n=e.schema)&&(5<(n=n.map(function(e){return JSON.stringify(e)})).length&&(t=["("+(n.length-5)+" more...)"],(n=n.slice(0,5)).push(t)),e.message="should be equal to one of: "+n.join(", ")),"additionalProperties"===e.keyword&&(e.message="should NOT have additional property: "+e.params.additionalProperty),e}function $(e){return e&&"function"==typeof e.then&&"function"==typeof e.catch}function q(e){return"object"===l(e)&&Array.isArray(e.path)&&"string"==typeof e.message}function K(e,t,n){n=void 0!==n?n:0;return t.left-n>=e.left&&t.right+n<=e.right&&t.top-n>=e.top&&t.bottom+n<=e.bottom}function W(i,o,r){var s;return function(){var e=this,t=arguments,n=r&&!s;clearTimeout(s),s=setTimeout(function(){s=null,r||i.apply(e,t)},o),n&&i.apply(e,t)}}function Q(e,t){for(var n=t.length,i=0,o=e.length,r=t.length;t.charAt(i)===e.charAt(i)&&i<n;)i++;for(;t.charAt(r-1)===e.charAt(o-1)&&i<r&&0<o;)r--,o--;return{start:i,end:r}}function Z(t){var e,n,i,o,r=0,s=0;return"number"==typeof t.selectionStart&&"number"==typeof t.selectionEnd?(r=t.selectionStart,s=t.selectionEnd):(o=document.selection.createRange())&&o.parentElement()===t&&(i=t.value.length,e=t.value.replace(/\r\n/g,"\n"),(n=t.createTextRange()).moveToBookmark(o.getBookmark()),(o=t.createTextRange()).collapse(!1),-1<n.compareEndPoints("StartToEnd",o)?r=s=i:(r=-n.moveStart("character",-i),r+=e.slice(0,r).split("\n").length-1,-1<n.compareEndPoints("EndToEnd",o)?s=i:(s=-n.moveEnd("character",-i),s+=e.slice(0,s).split("\n").length-1))),{startIndex:r,endIndex:s,start:a(r),end:a(s)};function a(e){e=t.value.substring(0,e);return{row:(e.match(/\n/g)||[]).length+1,column:e.length-e.lastIndexOf("\n")}}}function X(e,t,n){e=e.value||"";if(0<t&&0<n){e=e.split("\n",t);t=Math.min(e.length,t),n=Math.min(e[t-1].length,n-1);n=1===t?n:n+1;return e.slice(0,t-1).join("\n").length+n}return-1}function G(e,t){var n,i=[];if(!t||!t.length)return i;try{n=s.a.parse(e)}catch(e){return i}return t.forEach(function(e){var t=Y(H(e)),t=n.pointers[t];t&&i.push({path:e,line:t.key?t.key.line:t.value?t.value.line:0,column:t.key?t.key.column:t.value?t.value.column:0})}),i}function Y(e){return e.map(function(e){return"/"+String(e).replace(/~/g,"~0").replace(/\//g,"~1")}).join("")}function ee(e){var t=document.createElement("div");return t.style.color=e,t.style.color.split(/\s+/).join("").toLowerCase()||null}function te(e){return!!ee(e)}function ne(n,e){if(!n)return"";var i="";return n.title&&(i+=n.title),n.description&&(0<i.length&&(i+="\n"),i+=n.description),n.default&&(0<i.length&&(i+="\n\n"),i+=Object(a.c)("default",void 0,e)+"\n",i+=JSON.stringify(n.default,null,2)),Array.isArray(n.examples)&&0<n.examples.length&&(0<i.length&&(i+="\n\n"),i+=Object(a.c)("examples",void 0,e)+"\n",n.examples.forEach(function(e,t){i+=JSON.stringify(e,null,2),t!==n.examples.length-1&&(i+="\n")})),i}function ie(e,t){for(var n=e,i=0;i<t.length&&null!=n;i++)n=n[t[i]];return n}function oe(e,t){for(var n=e.replace(/ \(copy( \d+)?\)$/,""),i=n,o=1;-1!==t.indexOf(i);){i=n+" ("+("copy"+(1<o?" "+o:""))+")";o++}return i}function re(e,t){var n={};if(Array.isArray(e))for(var i=Math.min(e.length,c),o=0;o<i;o++)!function t(n,i,o,r){(Array.isArray(n)||ue(n))&&!r||(i[o||""]=!0),ue(n)&&Object.keys(n).forEach(function(e){t(n[e],i,o+"."+e,r)})}(e[o],n,"",t);else n[""]=!0;return Object.keys(n).sort()}function se(e,t,n){var i=t&&"."!==t?H(t):[],o="desc"===n?-1:1,e=e.slice();return e.sort(function(e,t){e=ie(e,i),t=ie(t,i);return o*(t<e?1:e<t?-1:0)}),e}function ae(t,e){var n="desc"===e?-1:1,e=Object.keys(t).sort(function(e,t){return n*o()(e,t)}),i={};return e.forEach(function(e){i[e]=t[e]}),i}function le(e){if(""===e)return"";var t=e.toLowerCase();if("null"===t)return null;if("true"===t)return!0;if("false"===t)return!1;var n=Number(e),t=parseFloat(e);return isNaN(n)||isNaN(t)?e:n}function ce(e,t){return"number"==typeof t&&d<t&&isFinite(t)&&Math.floor(t)===t&&!isNaN(new Date(t).valueOf())}function de(e){if(e<900)return e.toFixed()+" B";e/=1e3;if(e<900)return e.toFixed(1)+" KB";e/=1e3;if(e<900)return e.toFixed(1)+" MB";e/=1e3;return e<900?e.toFixed(1)+" GB":(e/1e3).toFixed(1)+" TB"}function he(e,t){return e.length<=t?e:e.slice(0,t)+"..."}function ue(e){return"object"===l(e)&&null!==e&&!Array.isArray(e)}function pe(e,t){return-1!==e.indexOf(t)}function fe(n,e){if(!e&&!n)return!1;if(e&&!n||!e&&n)return!0;if(e.length!==n.length)return!0;for(var t=0;t<n.length;++t){var i=function(t){if(!("error"===n[t].type?e.find(function(e){return e.line===n[t].line}):e.find(function(e){return e.dataPath===n[t].dataPath&&e.schemaPath===n[t].schemaPath})))return{v:!0}}(t);if("object"===l(i))return i.v}return!1}function me(e,t){return Object.prototype.hasOwnProperty.call(e,t)}},function(e,t,n){"use strict";n.d(t,"a",function(){return l}),n.d(t,"b",function(){return c}),n.d(t,"c",function(){return d});var t=n(19),i=["en","pt-BR","zh-CN","tr","ja","fr-FR","de"],r={en:{array:"Array",auto:"Auto",appendText:"Append",appendTitle:"Append a new field with type 'auto' after this field (Ctrl+Shift+Ins)",appendSubmenuTitle:"Select the type of the field to be appended",appendTitleAuto:"Append a new field with type 'auto' (Ctrl+Shift+Ins)",ascending:"Ascending",ascendingTitle:"Sort the childs of this ${type} in ascending order",actionsMenu:"Click to open the actions menu (Ctrl+M)",cannotParseFieldError:"Cannot parse field into JSON",cannotParseValueError:"Cannot parse value into JSON",collapseAll:"Collapse all fields",compactTitle:"Compact JSON data, remove all whitespaces (Ctrl+Shift+\\)",descending:"Descending",descendingTitle:"Sort the childs of this ${type} in descending order",drag:"Drag to move this field (Alt+Shift+Arrows)",duplicateKey:"duplicate key",duplicateText:"Duplicate",duplicateTitle:"Duplicate selected fields (Ctrl+D)",duplicateField:"Duplicate this field (Ctrl+D)",duplicateFieldError:"Duplicate field name",empty:"empty",expandAll:"Expand all fields",expandTitle:"Click to expand/collapse this field (Ctrl+E). \nCtrl+Click to expand/collapse including all childs.",formatTitle:"Format JSON data, with proper indentation and line feeds (Ctrl+\\)",insert:"Insert",insertTitle:"Insert a new field with type 'auto' before this field (Ctrl+Ins)",insertSub:"Select the type of the field to be inserted",object:"Object",ok:"Ok",redo:"Redo (Ctrl+Shift+Z)",removeText:"Remove",removeTitle:"Remove selected fields (Ctrl+Del)",removeField:"Remove this field (Ctrl+Del)",repairTitle:"Repair JSON: fix quotes and escape characters, remove comments and JSONP notation, turn JavaScript objects into JSON.",searchTitle:"Search fields and values",searchNextResultTitle:"Next result (Enter)",searchPreviousResultTitle:"Previous result (Shift + Enter)",selectNode:"Select a node...",showAll:"show all",showMore:"show more",showMoreStatus:"displaying ${visibleChilds} of ${totalChilds} items.",sort:"Sort",sortTitle:"Sort the childs of this ${type}",sortTitleShort:"Sort contents",sortFieldLabel:"Field:",sortDirectionLabel:"Direction:",sortFieldTitle:"Select the nested field by which to sort the array or object",sortAscending:"Ascending",sortAscendingTitle:"Sort the selected field in ascending order",sortDescending:"Descending",sortDescendingTitle:"Sort the selected field in descending order",string:"String",transform:"Transform",transformTitle:"Filter, sort, or transform the childs of this ${type}",transformTitleShort:"Filter, sort, or transform contents",extract:"Extract",extractTitle:"Extract this ${type}",transformQueryTitle:"Enter a JMESPath query",transformWizardLabel:"Wizard",transformWizardFilter:"Filter",transformWizardSortBy:"Sort by",transformWizardSelectFields:"Select fields",transformQueryLabel:"Query",transformPreviewLabel:"Preview",type:"Type",typeTitle:"Change the type of this field",openUrl:"Ctrl+Click or Ctrl+Enter to open url in new window",undo:"Undo last action (Ctrl+Z)",validationCannotMove:"Cannot move a field into a child of itself",autoType:'Field type "auto". The field type is automatically determined from the value and can be a string, number, boolean, or null.',objectType:'Field type "object". An object contains an unordered set of key/value pairs.',arrayType:'Field type "array". An array contains an ordered collection of values.',stringType:'Field type "string". Field type is not determined from the value, but always returned as string.',modeEditorTitle:"Switch Editor Mode",modeCodeText:"Code",modeCodeTitle:"Switch to code highlighter",modeFormText:"Form",modeFormTitle:"Switch to form editor",modeTextText:"Text",modeTextTitle:"Switch to plain text editor",modeTreeText:"Tree",modeTreeTitle:"Switch to tree editor",modeViewText:"View",modeViewTitle:"Switch to tree view",modePreviewText:"Preview",modePreviewTitle:"Switch to preview mode",examples:"Examples",default:"Default",containsInvalidProperties:"Contains invalid properties",containsInvalidItems:"Contains invalid items"},"zh-CN":{array:"数组",auto:"自动",appendText:"追加",appendTitle:"在此字段后追加一个类型为“auto”的新字段 (Ctrl+Shift+Ins)",appendSubmenuTitle:"选择要追加的字段类型",appendTitleAuto:"追加类型为“auto”的新字段 (Ctrl+Shift+Ins)",ascending:"升序",ascendingTitle:"升序排列${type}的子节点",actionsMenu:"点击打开动作菜单(Ctrl+M)",cannotParseFieldError:"无法将字段解析为JSON",cannotParseValueError:"无法将值解析为JSON",collapseAll:"缩进所有字段",compactTitle:"压缩JSON数据，删除所有空格 (Ctrl+Shift+\\)",descending:"降序",descendingTitle:"降序排列${type}的子节点",drag:"拖拽移动该节点(Alt+Shift+Arrows)",duplicateKey:"重复键",duplicateText:"复制",duplicateTitle:"复制选中字段(Ctrl+D)",duplicateField:"复制该字段(Ctrl+D)",duplicateFieldError:"重复的字段名称",empty:"清空",expandAll:"展开所有字段",expandTitle:"点击 展开/收缩 该字段(Ctrl+E). \nCtrl+Click 展开/收缩 包含所有子节点.",formatTitle:"使用适当的缩进和换行符格式化JSON数据 (Ctrl+\\)",insert:"插入",insertTitle:"在此字段前插入类型为“auto”的新字段 (Ctrl+Ins)",insertSub:"选择要插入的字段类型",object:"对象",ok:"Ok",redo:"重做 (Ctrl+Shift+Z)",removeText:"移除",removeTitle:"移除选中字段 (Ctrl+Del)",removeField:"移除该字段 (Ctrl+Del)",repairTitle:"修复JSON：修复引号和转义符，删除注释和JSONP表示法，将JavaScript对象转换为JSON。",selectNode:"选择一个节点...",showAll:"展示全部",showMore:"展示更多",showMoreStatus:"显示${totalChilds}的${visibleChilds}项目.",sort:"排序",sortTitle:"排序${type}的子节点",sortTitleShort:"内容排序",sortFieldLabel:"字段：",sortDirectionLabel:"方向：",sortFieldTitle:"选择用于对数组或对象排序的嵌套字段",sortAscending:"升序排序",sortAscendingTitle:"按照该字段升序排序",sortDescending:"降序排序",sortDescendingTitle:"按照该字段降序排序",string:"字符串",transform:"变换",transformTitle:"筛选，排序，或者转换${type}的子节点",transformTitleShort:"筛选，排序，或者转换内容",extract:"提取",extractTitle:"提取这个 ${type}",transformQueryTitle:"输入JMESPath查询",transformWizardLabel:"向导",transformWizardFilter:"筛选",transformWizardSortBy:"排序",transformWizardSelectFields:"选择字段",transformQueryLabel:"查询",transformPreviewLabel:"预览",type:"类型",typeTitle:"更改字段类型",openUrl:"Ctrl+Click 或者 Ctrl+Enter 在新窗口打开链接",undo:"撤销上次动作 (Ctrl+Z)",validationCannotMove:"无法将字段移入其子节点",autoType:'字段类型 "auto". 字段类型由值自动确定 可以为 string，number，boolean，或者 null.',objectType:'字段类型 "object". 对象包含一组无序的键/值对.',arrayType:'字段类型 "array". 数组包含值的有序集合.',stringType:'字段类型 "string". 字段类型由值自动确定，但始终作为字符串返回.',modeCodeText:"代码",modeCodeTitle:"切换至代码高亮",modeFormText:"表单",modeFormTitle:"切换至表单编辑",modeTextText:"文本",modeTextTitle:"切换至文本编辑",modeTreeText:"树",modeTreeTitle:"切换至树编辑",modeViewText:"视图",modeViewTitle:"切换至树视图",modePreviewText:"预览",modePreviewTitle:"切换至预览模式",examples:"例子",default:"缺省",containsInvalidProperties:"包含无效的属性",containsInvalidItems:"包含无效项目"},"pt-BR":{array:"Lista",auto:"Automatico",appendText:"Adicionar",appendTitle:"Adicionar novo campo com tipo 'auto' depois deste campo (Ctrl+Shift+Ins)",appendSubmenuTitle:"Selecione o tipo do campo a ser adicionado",appendTitleAuto:"Adicionar novo campo com tipo 'auto' (Ctrl+Shift+Ins)",ascending:"Ascendente",ascendingTitle:"Organizar filhor do tipo ${type} em crescente",actionsMenu:"Clique para abrir o menu de ações (Ctrl+M)",cannotParseFieldError:"Não é possível analisar o campo no JSON",cannotParseValueError:"Não é possível analisar o valor em JSON",collapseAll:"Fechar todos campos",compactTitle:"Dados JSON compactos, remova todos os espaços em branco (Ctrl+Shift+\\)",descending:"Descendente",descendingTitle:"Organizar o filhos do tipo ${type} em decrescente",duplicateKey:"chave duplicada",drag:"Arraste para mover este campo (Alt+Shift+Arrows)",duplicateText:"Duplicar",duplicateTitle:"Duplicar campos selecionados (Ctrl+D)",duplicateField:"Duplicar este campo (Ctrl+D)",duplicateFieldError:"Nome do campo duplicado",empty:"vazio",expandAll:"Expandir todos campos",expandTitle:"Clique para expandir/encolher este campo (Ctrl+E). \nCtrl+Click para expandir/encolher incluindo todos os filhos.",formatTitle:"Formate dados JSON, com recuo e feeds de linha adequados (Ctrl+\\)",insert:"Inserir",insertTitle:"Inserir um novo campo do tipo 'auto' antes deste campo (Ctrl+Ins)",insertSub:"Selecionar o tipo de campo a ser inserido",object:"Objeto",ok:"Ok",redo:"Refazer (Ctrl+Shift+Z)",removeText:"Remover",removeTitle:"Remover campos selecionados (Ctrl+Del)",removeField:"Remover este campo (Ctrl+Del)",repairTitle:"Repare JSON: corrija aspas e caracteres de escape, remova comentários e notação JSONP, transforme objetos JavaScript em JSON.",selectNode:"Selecione um nódulo...",showAll:"mostrar todos",showMore:"mostrar mais",showMoreStatus:"exibindo ${visibleChilds} de ${totalChilds} itens.",sort:"Organizar",sortTitle:"Organizar os filhos deste ${type}",sortTitleShort:"Organizar os filhos",sortFieldLabel:"Campo:",sortDirectionLabel:"Direção:",sortFieldTitle:"Selecione um campo filho pelo qual ordenar o array ou objeto",sortAscending:"Ascendente",sortAscendingTitle:"Ordenar o campo selecionado por ordem ascendente",sortDescending:"Descendente",sortDescendingTitle:"Ordenar o campo selecionado por ordem descendente",string:"Texto",transform:"Transformar",transformTitle:"Filtrar, ordenar ou transformar os filhos deste ${type}",transformTitleShort:"Filtrar, ordenar ou transformar conteúdos",transformQueryTitle:"Insira uma expressão JMESPath",transformWizardLabel:"Assistente",transformWizardFilter:"Filtro",transformWizardSortBy:"Ordenar por",transformWizardSelectFields:"Selecionar campos",transformQueryLabel:"Expressão",transformPreviewLabel:"Visualizar",type:"Tipo",typeTitle:"Mudar o tipo deste campo",openUrl:"Ctrl+Click ou Ctrl+Enter para abrir link em nova janela",undo:"Desfazer último ação (Ctrl+Z)",validationCannotMove:"Não pode mover um campo como filho dele mesmo",autoType:'Campo do tipo "auto". O tipo do campo é determinao automaticamente a partir do seu valor e pode ser texto, número, verdade/falso ou nulo.',objectType:'Campo do tipo "objeto". Um objeto contém uma lista de pares com chave e valor.',arrayType:'Campo do tipo "lista". Uma lista contem uma coleção de valores ordenados.',stringType:'Campo do tipo "string". Campo do tipo nao é determinado através do seu valor, mas sempre retornara um texto.',examples:"Exemplos",default:"Revelia",containsInvalidProperties:"Contém propriedades inválidas",containsInvalidItems:"Contém itens inválidos"},tr:{array:"Dizin",auto:"Otomatik",appendText:"Ekle",appendTitle:"Bu alanın altına 'otomatik' tipinde yeni bir alan ekle (Ctrl+Shift+Ins)",appendSubmenuTitle:"Eklenecek alanın tipini seç",appendTitleAuto:"'Otomatik' tipinde yeni bir alan ekle (Ctrl+Shift+Ins)",ascending:"Artan",ascendingTitle:"${type}'ın alt tiplerini artan düzende sırala",actionsMenu:"Aksiyon menüsünü açmak için tıklayın (Ctrl+M)",collapseAll:"Tüm alanları kapat",descending:"Azalan",descendingTitle:"${type}'ın alt tiplerini azalan düzende sırala",drag:"Bu alanı taşımak için sürükleyin (Alt+Shift+Arrows)",duplicateKey:"Var olan anahtar",duplicateText:"Aşağıya kopyala",duplicateTitle:"Seçili alanlardan bir daha oluştur (Ctrl+D)",duplicateField:"Bu alandan bir daha oluştur (Ctrl+D)",duplicateFieldError:"Duplicate field name",cannotParseFieldError:"Alan JSON'a ayrıştırılamıyor",cannotParseValueError:"JSON'a değer ayrıştırılamıyor",empty:"boş",expandAll:"Tüm alanları aç",expandTitle:"Bu alanı açmak/kapatmak için tıkla (Ctrl+E). \nAlt alanlarda dahil tüm alanları açmak için Ctrl+Click ",insert:"Ekle",insertTitle:"Bu alanın üstüne 'otomatik' tipinde yeni bir alan ekle (Ctrl+Ins)",insertSub:"Araya eklenecek alanın tipini seç",object:"Nesne",ok:"Tamam",redo:"Yeniden yap (Ctrl+Shift+Z)",removeText:"Kaldır",removeTitle:"Seçilen alanları kaldır (Ctrl+Del)",removeField:"Bu alanı kaldır (Ctrl+Del)",selectNode:"Bir nesne seç...",showAll:"tümünü göster",showMore:"daha fazla göster",showMoreStatus:"${totalChilds} alanın ${visibleChilds} alt alanları gösteriliyor",sort:"Sırala",sortTitle:"${type}'ın alt alanlarını sırala",sortTitleShort:"İçerikleri sırala",sortFieldLabel:"Alan:",sortDirectionLabel:"Yön:",sortFieldTitle:"Diziyi veya nesneyi sıralamak için iç içe geçmiş alanı seçin",sortAscending:"Artan",sortAscendingTitle:"Seçili alanı artan düzende sırala",sortDescending:"Azalan",sortDescendingTitle:"Seçili alanı azalan düzende sırala",string:"Karakter Dizisi",transform:"Dönüştür",transformTitle:"${type}'ın alt alanlarını filtrele, sırala veya dönüştür",transformTitleShort:"İçerikleri filterele, sırala veya dönüştür",transformQueryTitle:"JMESPath sorgusu gir",transformWizardLabel:"Sihirbaz",transformWizardFilter:"Filtre",transformWizardSortBy:"Sırala",transformWizardSelectFields:"Alanları seç",transformQueryLabel:"Sorgu",transformPreviewLabel:"Önizleme",type:"Tip",typeTitle:"Bu alanın tipini değiştir",openUrl:"URL'i yeni bir pencerede açmak için Ctrl+Click veya Ctrl+Enter",undo:"Son değişikliği geri al (Ctrl+Z)",validationCannotMove:"Alt alan olarak taşınamıyor",autoType:'Alan tipi "otomatik". Alan türü otomatik olarak değerden belirlenirve bir dize, sayı, boolean veya null olabilir.',objectType:'Alan tipi "nesne". Bir nesne, sıralanmamış bir anahtar / değer çifti kümesi içerir.',arrayType:'Alan tipi "dizi". Bir dizi, düzenli değerler koleksiyonu içerir.',stringType:'Alan tipi "karakter dizisi". Alan türü değerden belirlenmez,ancak her zaman karakter dizisi olarak döndürülür.',modeCodeText:"Kod",modeCodeTitle:"Kod vurgulayıcıya geç",modeFormText:"Form",modeFormTitle:"Form düzenleyiciye geç",modeTextText:"Metin",modeTextTitle:"Düz metin düzenleyiciye geç",modeTreeText:"Ağaç",modeTreeTitle:"Ağaç düzenleyiciye geç",modeViewText:"Görünüm",modeViewTitle:"Ağaç görünümüne geç",examples:"Örnekler",default:"Varsayılan",containsInvalidProperties:"Geçersiz özellikler içeriyor",containsInvalidItems:"Geçersiz öğeler içeriyor"},ja:{array:"配列",auto:"オート",appendText:"追加",appendTitle:'次のフィールドに"オート"のフィールドを追加 (Ctrl+Shift+Ins)',appendSubmenuTitle:"追加するフィールドの型を選択してください",appendTitleAuto:'"オート"のフィールドを追加 (Ctrl+Shift+Ins)',ascending:"昇順",ascendingTitle:"${type}の子要素を昇順に並べ替え",actionsMenu:"クリックしてアクションメニューを開く (Ctrl+M)",collapseAll:"すべてを折りたたむ",descending:"降順",descendingTitle:"${type}の子要素を降順に並べ替え",drag:"ドラッグして選択中のフィールドを移動 (Alt+Shift+Arrows)",duplicateKey:"複製キー",duplicateText:"複製",duplicateTitle:"選択中のフィールドを複製 (Ctrl+D)",duplicateField:"選択中のフィールドを複製 (Ctrl+D)",duplicateFieldError:"フィールド名が重複しています",cannotParseFieldError:"JSONのフィールドを解析できません",cannotParseValueError:"JSONの値を解析できません",empty:"空",expandAll:"すべてを展開",expandTitle:"クリックしてフィールドを展開/折りたたむ (Ctrl+E). \nCtrl+Click ですべての子要素を展開/折りたたむ",insert:"挿入",insertTitle:"選択中のフィールドの前に新しいフィールドを挿入 (Ctrl+Ins)",insertSub:"挿入するフィールドの型を選択",object:"オブジェクト",ok:"実行",redo:"やり直す (Ctrl+Shift+Z)",removeText:"削除",removeTitle:"選択中のフィールドを削除 (Ctrl+Del)",removeField:"選択中のフィールドを削除 (Ctrl+Del)",selectNode:"ノードを選択...",showAll:"すべてを表示",showMore:"もっと見る",showMoreStatus:"${totalChilds}個のアイテムのうち ${visibleChilds}個を表示しています。",sort:"並べ替え",sortTitle:"${type}の子要素を並べ替え",sortTitleShort:"並べ替え",sortFieldLabel:"フィールド:",sortDirectionLabel:"順序:",sortFieldTitle:"配列またはオブジェクトを並び替えるためのフィールドを選択",sortAscending:"昇順",sortAscendingTitle:"選択中のフィールドを昇順に並び替え",sortDescending:"降順",sortDescendingTitle:"選択中のフィールドを降順に並び替え",string:"文字列",transform:"変換",transformTitle:"${type}の子要素をフィルター・並び替え・変換する",transformTitleShort:"内容をフィルター・並び替え・変換する",extract:"抽出",extractTitle:"${type}を抽出",transformQueryTitle:"JMESPathクエリを入力",transformWizardLabel:"ウィザード",transformWizardFilter:"フィルター",transformWizardSortBy:"並び替え",transformWizardSelectFields:"フィールドを選択",transformQueryLabel:"クエリ",transformPreviewLabel:"プレビュー",type:"型",typeTitle:"選択中のフィールドの型を変更",openUrl:"Ctrl+Click または Ctrl+Enter で 新規ウィンドウでURLを開く",undo:"元に戻す (Ctrl+Z)",validationCannotMove:"子要素に移動できません ",autoType:"オート： フィールドの型は値から自動的に決定されます。 (文字列・数値・ブール・null)",objectType:"オブジェクト： オブジェクトは順序が決まっていないキーと値のペア組み合わせです。",arrayType:"配列： 配列は順序が決まっている値の集合体です。",stringType:"文字列： フィールド型は値から決定されませんが、常に文字列として返されます。",modeCodeText:"コードモード",modeCodeTitle:"ハイライトモードに切り替え",modeFormText:"フォームモード",modeFormTitle:"フォームモードに切り替え",modeTextText:"テキストモード",modeTextTitle:"テキストモードに切り替え",modeTreeText:"ツリーモード",modeTreeTitle:"ツリーモードに切り替え",modeViewText:"ビューモード",modeViewTitle:"ビューモードに切り替え",modePreviewText:"プレビュー",modePreviewTitle:"プレビューに切り替え",examples:"例",default:"デフォルト",containsInvalidProperties:"無効なプロパティが含まれています",containsInvalidItems:"無効なアイテムが含まれています"},"fr-FR":{array:"Liste",auto:"Auto",appendText:"Ajouter",appendTitle:"Ajouter un champ de type 'auto' après ce champ (Ctrl+Shift+Ins)",appendSubmenuTitle:"Sélectionner le type du champ à ajouter",appendTitleAuto:"Ajouter un champ de type 'auto' (Ctrl+Shift+Ins)",ascending:"Ascendant",ascendingTitle:"Trier les enfants de ce ${type} par ordre ascendant",actionsMenu:"Ouvrir le menu des actions (Ctrl+M)",collapseAll:"Regrouper",descending:"Descendant",descendingTitle:"Trier les enfants de ce ${type} par ordre descendant",drag:"Déplacer (Alt+Shift+Arrows)",duplicateKey:"Dupliquer la clé",duplicateText:"Dupliquer",duplicateTitle:"Dupliquer les champs sélectionnés (Ctrl+D)",duplicateField:"Dupliquer ce champ (Ctrl+D)",duplicateFieldError:"Dupliquer le nom de champ",cannotParseFieldError:"Champ impossible à parser en JSON",cannotParseValueError:"Valeur impossible à parser en JSON",empty:"vide",expandAll:"Étendre",expandTitle:"Étendre/regrouper ce champ (Ctrl+E). \nCtrl+Click pour étendre/regrouper avec tous les champs.",insert:"Insérer",insertTitle:"Insérer un champ de type 'auto' avant ce champ (Ctrl+Ins)",insertSub:"Sélectionner le type de champ à insérer",object:"Objet",ok:"Ok",redo:"Rejouer (Ctrl+Shift+Z)",removeText:"Supprimer",removeTitle:"Supprimer les champs sélectionnés (Ctrl+Del)",removeField:"Supprimer ce champ (Ctrl+Del)",searchTitle:"Rechercher champs et valeurs",searchNextResultTitle:"Résultat suivant (Enter)",searchPreviousResultTitle:"Résultat précédent (Shift + Enter)",selectNode:"Sélectionner un nœud...",showAll:"voir tout",showMore:"voir plus",showMoreStatus:"${visibleChilds} éléments affichés de ${totalChilds}.",sort:"Trier",sortTitle:"Trier les champs de ce ${type}",sortTitleShort:"Trier",sortFieldLabel:"Champ:",sortDirectionLabel:"Direction:",sortFieldTitle:"Sélectionner les champs permettant de trier les listes et objet",sortAscending:"Ascendant",sortAscendingTitle:"Trier les champs sélectionnés par ordre ascendant",sortDescending:"Descendant",sortDescendingTitle:"Trier les champs sélectionnés par ordre descendant",string:"Chaîne",transform:"Transformer",transformTitle:"Filtrer, trier, or transformer les enfants de ce ${type}",transformTitleShort:"Filtrer, trier ou transformer le contenu",extract:"Extraire",extractTitle:"Extraire ce ${type}",transformQueryTitle:"Saisir une requête JMESPath",transformWizardLabel:"Assistant",transformWizardFilter:"Filtrer",transformWizardSortBy:"Trier par",transformWizardSelectFields:"Sélectionner les champs",transformQueryLabel:"Requête",transformPreviewLabel:"Prévisualisation",type:"Type",typeTitle:"Changer le type de ce champ",openUrl:"Ctrl+Click ou Ctrl+Enter pour ouvrir l'url dans une autre fenêtre",undo:"Annuler la dernière action (Ctrl+Z)",validationCannotMove:"Cannot move a field into a child of itself",autoType:'Champe de type "auto". Ce type de champ est automatiquement déterminé en fonction de la valeur et peut être de type "chaîne", "nombre", "booléen" ou null.',objectType:'Champ de type "objet". Un objet contient un ensemble non ordonné de paires clé/valeur.',arrayType:'Champ de type "liste". Une liste contient une collection ordonnée de valeurs.',stringType:'Champ de type "chaîne". Ce type de champ n\'est pas déterminé en fonction de la valeur, mais retourne systématiquement une chaîne de caractères.',modeEditorTitle:"Changer mode d'édition",modeCodeText:"Code",modeCodeTitle:"Activer surlignage code",modeFormText:"Formulaire",modeFormTitle:"Activer formulaire",modeTextText:"Texte",modeTextTitle:"Activer éditeur texte",modeTreeText:"Arbre",modeTreeTitle:"Activer éditeur arbre",modeViewText:"Lecture seule",modeViewTitle:"Activer vue arbre",modePreviewText:"Prévisualisation",modePreviewTitle:"Activer mode prévisualiser",examples:"Exemples",default:"Défaut",containsInvalidProperties:"Contient des propriétés non valides",containsInvalidItems:"Contient des éléments invalides"},de:{array:"Auflistung",auto:"Auto",appendText:"anhängen",appendTitle:"Fügen Sie nach diesem Feld ein neues Feld mit dem Typ 'auto' ein (Strg+Umschalt+Ein)",appendSubmenuTitle:"Wählen Sie den Typ des neuen Feldes",appendTitleAuto:"Ein neues Feld vom Typ 'auto' hinzufügen (Strg+Umschalt+Ein)",ascending:"Aufsteigend",ascendingTitle:"Sortieren Sie die Elemente dieses ${type} in aufsteigender Reihenfolge",actionsMenu:"Klicken Sie zum Öffnen des Aktionsmenüs (Strg+M)",cannotParseFieldError:"Feld kann nicht in JSON geparst werden",cannotParseValueError:"Wert kann nicht in JSON geparst werden",collapseAll:"Alle Felder zuklappen",compactTitle:"JSON-Daten verdichten, alle Leerzeichen entfernen (Strg+Umschalt+\\)",descending:"Absteigend",descendingTitle:"Sortieren Sie die Elemente dieses ${type} in absteigender Reihenfolge",drag:"Ziehen, um dieses Feld zu verschieben (Alt+Umschalt+Pfeile)",duplicateKey:"Doppelter Schlüssel",duplicateText:"Duplikat",duplicateTitle:"Ausgewählte Felder duplizieren (Strg+D)",duplicateField:"Dieses Feld duplizieren (Strg+D)",duplicateFieldError:"Doppelter Feldname",empty:"leer",expandAll:"Alle Felder anzeigen",expandTitle:"Klicken Sie, um dieses Feld zu erweitern/zu kollabieren (Strg+E). \nStrg+Klicken Sie, um dieses Feld einschließlich aller Elemente zu erweitern/zu kollabieren.",formatTitle:"JSON-Daten mit korrekter Einrückung und Zeilenvorschüben formatieren (Strg+\\)",insert:"einfügen",insertTitle:"Fügen Sie vor diesem Feld ein neues Feld mit dem Typ 'auto' ein (Strg+Einfg)",insertSub:"Wählen Sie den Typ des neuen Feldes",object:"Objekt",ok:"Ok",redo:"Wiederholen (Strg+Umschalt+Z)",removeText:"entfernen",removeTitle:"Ausgewählte Felder entfernen (Strg+Entf)",removeField:"Dieses Feld entfernen (Strg+Entf)",repairTitle:"JSON reparieren: Anführungszeichen und Escape-Zeichen korrigieren, Kommentare und JSONP-Notation entfernen, JavaScript-Objekte in JSON umwandeln.",searchTitle:"Suchfelder und Werte",searchNextResultTitle:"Nächstes Ergebnis (Enter)",searchPreviousResultTitle:"Vorheriges Ergebnis (Umschalt + Eingabe)",selectNode:"Wählen Sie einen Knoten aus...",showAll:"alle anzeigen",showMore:"mehr anzeigen",showMoreStatus:"Anzeige von ${visibleChilds} von ${totalChilds}-Elementen.",sort:"Sortieren",sortTitle:"Sortieren Sie die Elemente dieses ${type}",sortTitleShort:"Inhalt sortieren",sortFieldLabel:"Feld:",sortDirectionLabel:"Richtung:",sortFieldTitle:"Wählen Sie das verschachtelte Feld, nach dem das Array oder Objekt sortiert werden soll.",sortAscending:"Aufsteigend",sortAscendingTitle:"Sortieren Sie das ausgewählte Feld in aufsteigender Reihenfolge",sortDescending:"Absteigend",sortDescendingTitle:"Sortieren Sie das ausgewählte Feld in absteigender Reihenfolge",string:"Zeichenfolge",transform:"Verwandeln",transformTitle:"Die Elemente dieses ${type} filtern, sortieren oder transformieren",transformTitleShort:"Inhalte filtern, sortieren oder transformieren",extract:"Auszug",extractTitle:"Extrahieren Sie diesen ${type}",transformQueryTitle:"Eine JMESPath-Abfrage eingeben",transformWizardLabel:"Zauberer",transformWizardFilter:"Filter",transformWizardSortBy:"Sortieren nach",transformWizardSelectFields:"Felder auswählen",transformQueryLabel:"Anfrage",transformPreviewLabel:"Vorschau",type:"Geben Sie  ein.",typeTitle:"Ändern Sie den Typ dieses Feldes",openUrl:"Strg+Klicken oder Strg+Eingabe, um die URL in einem neuen Fenster zu öffnen",undo:"Letzte Aktion rückgängig machen (Strg+Z)",validationCannotMove:"Kann ein Feld nicht in ein Kind seiner selbst verschieben",autoType:'Feldtyp "auto". Der Feldtyp wird automatisch aus dem Wert bestimmt und kann ein String, eine Zahl, boolesch oder null sein.',objectType:'Feldtyp "Objekt". Ein Objekt enthält eine ungeordnete Menge von Schlüssel/Wert-Paaren.',arrayType:'Feldtyp "Array". Ein Array enthält eine geordnete Sammlung von Werten.',stringType:'Feldtyp "Zeichenfolge". Der Feldtyp wird nicht aus dem Wert bestimmt, sondern immer als Zeichenfolge zurückgegeben.',modeEditorTitle:"Editor-Modus umschalten",modeCodeText:"Code",modeCodeTitle:"Umschalten auf Code-Highlighter",modeFormText:"Formular",modeFormTitle:"Zum Formular-Editor wechseln",modeTextText:"Text",modeTextTitle:"Zum Editor für einfachen Text wechseln",modeTreeText:"Baum",modeTreeTitle:"Zum Baum-Editor wechseln",modeViewText:"Siehe",modeViewTitle:"Zur Baumansicht wechseln",modePreviewText:"Vorschau",modePreviewTitle:"In den Vorschau-Modus wechseln",examples:"Beispiele",default:"Standardmäßig",containsInvalidProperties:"Enthält ungültige Eigenschaften",containsInvalidItems:"Enthält ungültige Elemente"}},s="en",o="undefined"!=typeof navigator?navigator.language||navigator.userLanguage:void 0,a=i.find(function(e){return e===o})||s;function l(t){var e;t&&((e=i.find(function(e){return e===t}))?a=e:console.error("Language not found"))}function c(e){if(e)for(var t in e)!function(t){i.find(function(e){return e===t})||i.push(t),r[t]=Object.assign({},r[s],r[t],e[t])}(t)}function d(e,t,n){var i=r[n=n||a][e]||r[s][e]||e;if(t)for(var o in t)i=i.replace("${"+o+"}",t[o]);return i}},function(e,t,n){"use strict";n.d(t,"a",function(){return i}),n.d(t,"d",function(){return o}),n.d(t,"b",function(){return r}),n.d(t,"c",function(){return s});var i=document.body,o=10485760,r=2e4,s=2147483648},function(e,t,n){"use strict";n.d(t,"a",function(){return o});var c=n(11),d=n(0),u=n(1);function i(e,t){for(var n=0;n<t.length;n++){var i=t[n];i.enumerable=i.enumerable||!1,i.configurable=!0,"value"in i&&(i.writable=!0),Object.defineProperty(e,i.key,i)}}var o=function(){function l(t,e){!function(e){if(!(e instanceof l))throw new TypeError("Cannot call a class as a function")}(this),this.dom={};var h=this,n=this.dom;this.anchor=void 0,this.items=t,this.eventListeners={},this.selection=void 0,this.onClose=e?e.close:void 0,this.limitHeight=!!e&&e.limitHeight;var i=document.createElement("div");i.className="jsoneditor-contextmenu-root",n.root=i;e=document.createElement("div");e.className="jsoneditor-contextmenu",n.menu=e,i.appendChild(e);i=document.createElement("ul");i.className="jsoneditor-menu",e.appendChild(i),n.list=i,n.items=[];e=document.createElement("button");e.type="button",n.focusButton=e;n=document.createElement("li");n.style.overflow="hidden",n.style.height="0",n.appendChild(e),i.appendChild(n),function l(c,d,e){e.forEach(function(t){var n,e,i,o,r,s,a;"separator"===t.type?((i=document.createElement("div")).className="jsoneditor-separator",(r=document.createElement("li")).appendChild(i),c.appendChild(r)):(n={},e=document.createElement("li"),c.appendChild(e),(i=document.createElement("button")).type="button",i.className=t.className,n.button=i,t.title&&(i.title=t.title),t.click&&(i.onclick=function(e){e.preventDefault(),h.hide(),t.click()}),e.appendChild(i),t.submenu?((r=document.createElement("div")).className="jsoneditor-icon",i.appendChild(r),(r=document.createElement("div")).className="jsoneditor-text"+(t.click?"":" jsoneditor-right-margin"),r.appendChild(document.createTextNode(t.text)),i.appendChild(r),(o=t.click?(i.className+=" jsoneditor-default",(a=document.createElement("button")).type="button",(n.buttonExpand=a).className="jsoneditor-expand",(r=document.createElement("div")).className="jsoneditor-expand",a.appendChild(r),e.appendChild(a),t.submenuTitle&&(a.title=t.submenuTitle),a):((s=document.createElement("div")).className="jsoneditor-expand",i.appendChild(s),i)).onclick=function(e){e.preventDefault(),h._onExpandItem(n),o.focus()},a=[],n.subItems=a,s=document.createElement("ul"),(n.ul=s).className="jsoneditor-menu",s.style.height="0",e.appendChild(s),l(s,a,t.submenu)):((a=document.createElement("div")).className="jsoneditor-icon",i.appendChild(a),(a=document.createElement("div")).className="jsoneditor-text",a.appendChild(document.createTextNode(Object(u.c)(t.text))),i.appendChild(a)),d.push(n))})}(i,this.dom.items,t),this.maxHeight=0,t.forEach(function(e){e=24*(t.length+(e.submenu?e.submenu.length:0));h.maxHeight=Math.max(h.maxHeight,e)})}var e,t,n;return e=l,(t=[{key:"_getVisibleButtons",value:function(){var t=[],n=this;return this.dom.items.forEach(function(e){t.push(e.button),e.buttonExpand&&t.push(e.buttonExpand),e.subItems&&e===n.expandedItem&&e.subItems.forEach(function(e){t.push(e.button),e.buttonExpand&&t.push(e.buttonExpand)})}),t}},{key:"show",value:function(e,t,n){this.hide();var i=!0,o=e.parentNode,r=e.getBoundingClientRect(),s=o.getBoundingClientRect(),o=t.getBoundingClientRect(),a=this;this.dom.absoluteAnchor=Object(c.a)(e,t,function(){a.hide()}),r.bottom+this.maxHeight<o.bottom||r.top-this.maxHeight>o.top&&(i=!1);n=n?0:r.top-s.top;i?(s=e.offsetHeight,this.dom.menu.style.left="0",this.dom.menu.style.top=n+s+"px",this.dom.menu.style.bottom=""):(this.dom.menu.style.left="0",this.dom.menu.style.top="",this.dom.menu.style.bottom="0px"),this.limitHeight&&(o=i?o.bottom-r.bottom-10:r.top-o.top-10,this.dom.list.style.maxHeight=o+"px",this.dom.list.style.overflowY="auto"),this.dom.absoluteAnchor.appendChild(this.dom.root),this.selection=Object(d.getSelection)(),this.anchor=e,setTimeout(function(){a.dom.focusButton.focus()},0),l.visibleMenu&&l.visibleMenu.hide(),l.visibleMenu=this}},{key:"hide",value:function(){this.dom.absoluteAnchor&&(this.dom.absoluteAnchor.destroy(),delete this.dom.absoluteAnchor),this.dom.root.parentNode&&(this.dom.root.parentNode.removeChild(this.dom.root),this.onClose&&this.onClose()),l.visibleMenu===this&&(l.visibleMenu=void 0)}},{key:"_onExpandItem",value:function(n){var i,o=this,e=n===this.expandedItem,t=this.expandedItem;t&&(t.ul.style.height="0",t.ul.style.padding="",setTimeout(function(){o.expandedItem!==t&&(t.ul.style.display="",Object(d.removeClassName)(t.ul.parentNode,"jsoneditor-selected"))},300),this.expandedItem=void 0),e||((i=n.ul).style.display="block",i.clientHeight,setTimeout(function(){if(o.expandedItem===n){for(var e=0,t=0;t<i.childNodes.length;t++)e+=i.childNodes[t].clientHeight;i.style.height=e+"px",i.style.padding="5px 10px"}},0),Object(d.addClassName)(i.parentNode,"jsoneditor-selected"),this.expandedItem=n)}},{key:"_onKeyDown",value:function(e){var t,n,i,o,r=e.target,s=e.which,a=!1;27===s?(this.selection&&Object(d.setSelection)(this.selection),this.anchor&&this.anchor.focus(),this.hide(),a=!0):9===s?e.shiftKey?0===(n=(t=this._getVisibleButtons()).indexOf(r))&&(t[t.length-1].focus(),a=!0):(n=(t=this._getVisibleButtons()).indexOf(r))===t.length-1&&(t[0].focus(),a=!0):37===s?("jsoneditor-expand"===r.className&&(n=(t=this._getVisibleButtons()).indexOf(r),(i=t[n-1])&&i.focus()),a=!0):38===s?(n=(t=this._getVisibleButtons()).indexOf(r),(i=t[n-1])&&"jsoneditor-expand"===i.className&&(i=t[n-2]),(i=i||t[t.length-1])&&i.focus(),a=!0):39===s?(n=(t=this._getVisibleButtons()).indexOf(r),(o=t[n+1])&&"jsoneditor-expand"===o.className&&o.focus(),a=!0):40===s&&(n=(t=this._getVisibleButtons()).indexOf(r),(o=t[n+1])&&"jsoneditor-expand"===o.className&&(o=t[n+2]),(o=o||t[0])&&(o.focus(),a=!0),a=!0),a&&(e.stopPropagation(),e.preventDefault())}}])&&i(e.prototype,t),n&&i(e,n),l}();o.visibleMenu=void 0},function(e,t,n){"use strict";n.d(t,"a",function(){return o}),n.d(t,"b",function(){return r});var t=n(21),i=n.n(t),s=n(0);function o(e,t){var n=t.sort,i=t.filter,o=t.projection,r="";return i?(t="@"!==i.field?["0"].concat(Object(s.parsePath)("."+i.field)):["0"],t="string"==typeof Object(s.get)(e,t)?i.value:Object(s.parseString)(i.value),r+="[? "+i.field+" "+i.relation+" `"+JSON.stringify(t)+"`]"):r+=Array.isArray(e)?"[*]":"@",n&&("desc"===n.direction?r+=" | reverse(sort_by(@, &"+n.field+"))":r+=" | sort_by(@, &"+n.field+")"),o&&("]"!==r[r.length-1]&&(r+=" | [*]"),1===o.fields.length?r+="."+o.fields[0]:1<o.fields.length&&(r+=".{"+o.fields.map(function(e){var t=e.split(".");return t[t.length-1]+": "+e}).join(", ")+"}")),r}function r(e,t){return i.a.search(e,t)}},function(e,t,n){"use strict";n.r(t),n.d(t,"showSortModal",function(){return s});var t=n(14),i=n.n(t),o=n(1),r=n(0);function s(e,t,s,n){var a=Array.isArray(t)?Object(r.getChildPaths)(t):[""],l=n&&n.path&&Object(r.contains)(a,n.path)?n.path:a[0],c=n&&n.direction||"asc",n='<div class="pico-modal-contents"><div class="pico-modal-header">'+Object(o.c)("sort")+"</div><form><table><tbody><tr>  <td>"+Object(o.c)("sortFieldLabel")+' </td>  <td class="jsoneditor-modal-input">  <div class="jsoneditor-select-wrapper">    <select id="field" title="'+Object(o.c)("sortFieldTitle")+'">    </select>  </div>  </td></tr><tr>  <td>'+Object(o.c)("sortDirectionLabel")+' </td>  <td class="jsoneditor-modal-input">  <div id="direction" class="jsoneditor-button-group"><input type="button" value="'+Object(o.c)("sortAscending")+'" title="'+Object(o.c)("sortAscendingTitle")+'" data-value="asc" class="jsoneditor-button-first jsoneditor-button-asc"/><input type="button" value="'+Object(o.c)("sortDescending")+'" title="'+Object(o.c)("sortDescendingTitle")+'" data-value="desc" class="jsoneditor-button-last jsoneditor-button-desc"/>  </div>  </td></tr><tr><td colspan="2" class="jsoneditor-modal-input jsoneditor-modal-actions">  <input type="submit" id="ok" value="'+Object(o.c)("ok")+'" /></td></tr></tbody></table></form></div>';i()({parent:e,content:n,overlayClass:"jsoneditor-modal-overlay",overlayStyles:{backgroundColor:"rgb(1,1,1)",opacity:.3},modalClass:"jsoneditor-modal jsoneditor-modal-sort"}).afterCreate(function(t){var e=t.modalElem().querySelector("form"),n=t.modalElem().querySelector("#ok"),i=t.modalElem().querySelector("#field"),o=t.modalElem().querySelector("#direction");function r(e){o.value=e,o.className="jsoneditor-button-group jsoneditor-button-group-value-"+o.value}a.forEach(function(e){var t,n=document.createElement("option");n.text=""===(t=e)?"@":"."===t[0]?t.slice(1):t,n.value=e,i.appendChild(n)}),i.value=l||a[0],r(c||"asc"),o.onclick=function(e){r(e.target.getAttribute("data-value"))},n.onclick=function(e){e.preventDefault(),e.stopPropagation(),t.close(),s({path:i.value,direction:o.value})},e&&(e.onsubmit=n.onclick)}).afterClose(function(e){e.destroy()}).show()}},function(e,t,n){"use strict";n.r(t),n.d(t,"showTransformModal",function(){return a});var t=n(14),i=n.n(t),t=n(10),w=n.n(t),o=n(1);function r(e){return(r="function"==typeof Symbol&&"symbol"==typeof Symbol.iterator?function(e){return typeof e}:function(e){return e&&"function"==typeof Symbol&&e.constructor===Symbol&&e!==Symbol.prototype?"symbol":typeof e})(e)}function S(e,t,n,i){return"boolean"==typeof e||e instanceof Boolean||null===e||"number"==typeof e||e instanceof Number||"string"==typeof e||e instanceof String||e instanceof Date?JSON.stringify(e):Array.isArray(e)?function(e,t,n,i){for(var o=t?n+t:void 0,r=t?"[\n":"[",s=0;s<e.length;s++){var a=e[s];if(t&&(r+=o),r+=void 0!==a&&"function"!=typeof a?S(a,t,o,i):"null",s<e.length-1&&(r+=t?",\n":","),r.length>i)return r+"..."}return r+=t?"\n"+n+"]":"]"}(e,t,n,i):e&&"object"===r(e)?function(e,t,n,i){var o,r=t?n+t:void 0,s=!0,a=t?"{\n":"{";if("function"==typeof e.toJSON)return S(e.toJSON(),t,n,i);for(o in e)if(function(e,t){return Object.prototype.hasOwnProperty.call(e,t)}(e,o)){var l=e[o];if(s?s=!1:a+=t?",\n":",",a+=t?r+'"'+o+'": ':'"'+o+'":',(a+=S(l,t,r,i)).length>i)return a+"..."}return a+=t?"\n"+n+"}":"}"}(e,t,n,i):void 0}function j(e,t){for(var n="";0<t--;)n+=e;return n}var k=n(0),N=n(2),s='Enter a <a href="http://jmespath.org" target="_blank">JMESPath</a> query to filter, sort, or transform the JSON data.<br/>To learn JMESPath, go to <a href="http://jmespath.org/tutorial.html" target="_blank">the interactive tutorial</a>.';function a(e){var t=e.container,x=e.json,n=e.queryDescription,n=void 0===n?s:n,C=e.createQuery,E=e.executeQuery,_=e.onTransform,T=x,n='<label class="pico-modal-contents"><div class="pico-modal-header">'+Object(o.c)("transform")+"</div><p>"+n+'</p><div class="jsoneditor-jmespath-label">'+Object(o.c)("transformWizardLabel")+' </div><div id="wizard" class="jsoneditor-jmespath-block jsoneditor-jmespath-wizard">  <table class="jsoneditor-jmespath-wizard-table">    <tbody>      <tr>        <th>'+Object(o.c)("transformWizardFilter")+'</th>        <td class="jsoneditor-jmespath-filter">          <div class="jsoneditor-inline jsoneditor-jmespath-filter-field" >            <select id="filterField">            </select>          </div>          <div class="jsoneditor-inline jsoneditor-jmespath-filter-relation" >            <select id="filterRelation">              <option value="==">==</option>              <option value="!=">!=</option>              <option value="<">&lt;</option>              <option value="<=">&lt;=</option>              <option value=">">&gt;</option>              <option value=">=">&gt;=</option>            </select>          </div>          <div class="jsoneditor-inline jsoneditor-jmespath-filter-value" >            <input type="text" class="value" placeholder="value..." id="filterValue" />          </div>        </td>      </tr>      <tr>        <th>'+Object(o.c)("transformWizardSortBy")+'</th>        <td class="jsoneditor-jmespath-filter">          <div class="jsoneditor-inline jsoneditor-jmespath-sort-field">            <select id="sortField">            </select>          </div>          <div class="jsoneditor-inline jsoneditor-jmespath-sort-order" >            <select id="sortOrder">              <option value="asc">Ascending</option>              <option value="desc">Descending</option>            </select>          </div>        </td>      </tr>      <tr id="selectFieldsPart">        <th>'+Object(o.c)("transformWizardSelectFields")+'</th>        <td class="jsoneditor-jmespath-filter">          <select class="jsoneditor-jmespath-select-fields" id="selectFields" multiple></select>        </td>      </tr>    </tbody>  </table></div><div class="jsoneditor-jmespath-label">'+Object(o.c)("transformQueryLabel")+' </div><div class="jsoneditor-jmespath-block">  <textarea id="query"             rows="4"             autocomplete="off"             autocorrect="off"             autocapitalize="off"             spellcheck="false"            title="'+Object(o.c)("transformQueryTitle")+'">[*]</textarea></div><div class="jsoneditor-jmespath-label">'+Object(o.c)("transformPreviewLabel")+' </div><div class="jsoneditor-jmespath-block">  <textarea id="preview"       class="jsoneditor-transform-preview"      readonly> </textarea></div><div class="jsoneditor-jmespath-block jsoneditor-modal-actions">  <input type="submit" id="ok" value="'+Object(o.c)("ok")+'" autofocus /></div></div>';i()({parent:t,content:n,overlayClass:"jsoneditor-modal-overlay",overlayStyles:{backgroundColor:"rgb(1,1,1)",opacity:.3},modalClass:"jsoneditor-modal jsoneditor-modal-transform",focus:!1}).afterCreate(function(t){var e=t.modalElem(),n=e.querySelector("#wizard"),o=e.querySelector("#ok"),r=e.querySelector("#filterField"),s=e.querySelector("#filterRelation"),a=e.querySelector("#filterValue"),l=e.querySelector("#sortField"),c=e.querySelector("#sortOrder"),d=e.querySelector("#selectFields"),h=e.querySelector("#query"),u=e.querySelector("#preview");Array.isArray(T)||(n.style.fontStyle="italic",n.textContent="(wizard not available for objects, only for arrays)"),Object(k.getChildPaths)(x).forEach(function(e){var t=g(e),e=document.createElement("option");e.text=t,e.value=t,r.appendChild(e);e=document.createElement("option");e.text=t,e.value=t,l.appendChild(e)});var i=Object(k.getChildPaths)(x,!0).filter(function(e){return""!==e});0<i.length?i.forEach(function(e){var t=g(e),e=document.createElement("option");e.text=t,e.value=t,d.appendChild(e)}):(m=e.querySelector("#selectFieldsPart"))&&(m.style.display="none");var p=new w.a(r,{defaultSelected:!1,clearable:!0,allowDeselect:!0,placeholder:"field..."}),f=new w.a(s,{defaultSelected:!1,clearable:!0,allowDeselect:!0,placeholder:"compare..."}),n=new w.a(l,{defaultSelected:!1,clearable:!0,allowDeselect:!0,placeholder:"field..."}),i=new w.a(c,{defaultSelected:!1,clearable:!0,allowDeselect:!0,placeholder:"order..."}),m=new w.a(d,{multiple:!0,clearable:!0,defaultSelected:!1,placeholder:"select fields..."});function g(e){return""===e?"@":"."===e[0]?e.slice(1):e}p.on("selectr.change",b),f.on("selectr.change",b),a.oninput=b,n.on("selectr.change",b),i.on("selectr.change",b),m.on("selectr.change",b),e.querySelector(".pico-modal-contents").onclick=function(e){"A"!==e.target.nodeName&&e.preventDefault()};var v=Object(k.debounce)(function(){try{var e=E(T,h.value);u.className="jsoneditor-transform-preview",u.value=(t=e,n=2,e=N.b,"number"==typeof n?10<n?i=j(" ",10):1<=n&&(i=j(" ",n)):"string"==typeof n&&""!==n&&(i=n),(t=S(t,i,"",e)).length>e?(i=t,("number"==typeof(e=e)?i.slice(0,e):i)+"..."):t),o.disabled=!1}catch(e){u.className="jsoneditor-transform-preview jsoneditor-error",u.value=e.toString(),o.disabled=!0}var t,n,i},300);function y(e,t){try{h.value=C(e,t),o.disabled=!1,v()}catch(e){var n='Error: an error happened when executing "createQuery": '+(e.message||e.toString());h.value="",o.disabled=!0,u.className="jsoneditor-transform-preview jsoneditor-error",u.value=n}}function b(){var e={};if(r.value&&s.value&&a.value&&(e.filter={field:r.value,relation:s.value,value:a.value}),l.value&&c.value&&(e.sort={field:l.value,direction:c.value}),d.value){for(var t,n=[],i=0;i<d.options.length;i++)d.options[i].selected&&(t=d.options[i].value,n.push(t));e.projection={fields:n}}y(x,e)}h.oninput=v,o.onclick=function(e){e.preventDefault(),e.stopPropagation(),t.close(),_(h.value)},y(x,{}),setTimeout(function(){h.select(),h.focus(),h.selectionStart=3,h.selectionEnd=3})}).afterClose(function(e){e.destroy()}).show()}},function(e,t,n){e.exports=function(){"use strict";var i,n,e=(i=function(e,t){return(i=Object.setPrototypeOf||{__proto__:[]}instanceof Array&&function(e,t){e.__proto__=t}||function(e,t){for(var n in t)Object.prototype.hasOwnProperty.call(t,n)&&(e[n]=t[n])})(e,t)},function(e,t){function n(){this.constructor=e}i(e,t),e.prototype=null===t?Object.create(t):(n.prototype=t.prototype,new n)}),o=(n=SyntaxError,e(t,n),t);function t(e,t){e=n.call(this,e+" (char "+t+")")||this;return e.char=t,e}var r=["'","‘","’","`","´"],s=['"',"“","”"];function a(e){return/^[a-zA-Z_]$/.test(e)}function l(e){return"0"<=e&&e<="9"}function c(e){return" "===e||"\t"===e||"\n"===e||"\r"===e}function d(e){return" "===e||" "<=e&&e<=" "||" "===e||" "===e||"　"===e}function h(e){return r.includes(e)?"'":s.includes(e)?'"':e}function u(e,t){t=e.lastIndexOf(t);return-1!==t?e.substring(0,t)+e.substring(t+1):e}function p(e,t){return e.replace(/\s*$/,function(e){return t+e})}var f=0,m=1,g=2,v=3,y=4,b=5,x=6,C={"":!0,"{":!0,"}":!0,"[":!0,"]":!0,":":!0,",":!0,"(":!0,")":!0,";":!0,"+":!0},E={'"':'"',"\\":"\\","/":"/",b:"\b",f:"\f",n:"\n",r:"\r",t:"\t"},_={"\b":"\\b","\f":"\\f","\n":"\\n","\r":"\\r","\t":"\\t"},T={null:"null",true:"true",false:"false"},w={None:"null",True:"true",False:"false"},S="",j="",k=0,N="",O="",I=x;function D(){k++,N=S.charAt(k)}function A(){return I===f&&("["===O||"{"===O)||I===g||I===m||I===v}function P(){j+=O,I=x,O="",function(){if(C[N])return I=f,O=N,D();!function(){if(l(N)||"-"===N){if(I=m,"-"===N){if(O+=N,D(),!l(N))throw new o("Invalid number, digit expected",k)}else"0"===N&&(O+=N,D());for(;l(N);)O+=N,D();if("."===N){if(O+=N,D(),!l(N))throw new o("Invalid number, digit expected",k);for(;l(N);)O+=N,D()}if("e"===N||"E"===N){if(O+=N,D(),"+"!==N&&"-"!==N||(O+=N,D()),!l(N))throw new o("Invalid number, digit expected",k);for(;l(N);)O+=N,D()}return}!function(){if(function(e){return r.includes(e)||s.includes(e)}(N)){var e=h(N);for(O+='"',I=g,D();""!==N&&h(N)!==e;)if("\\"===N)if(D(),void 0!==E[N])O+="\\"+N,D();else if("u"===N){O+="\\u",D();for(var t=0;t<4;t++){if(!/^[0-9a-fA-F]$/.test(N))throw new o("Invalid unicode character",k-O.length);O+=N,D()}}else{if("'"!==N)throw new o('Invalid escape character "\\'+N+'"',k);O+="'",D()}else _[N]?O+=_[N]:O+='"'===N?'\\"':N,D();if(h(N)!==e)throw new o("End of string expected",k-O.length);return O+='"',D()}!function(){if(a(N)){for(I=v;a(N)||l(N)||"$"===N;)O+=N,D();return}!function(){if(c(N)||d(N)){for(I=y;c(N)||d(N);)O+=N,D();return}!function(){if("/"===N&&"*"===S[k+1]){for(I=b;""!==N&&("*"!==N||"*"===N&&"/"!==S[k+1]);)O+=N,D();return"*"===N&&"/"===S[k+1]&&(O+=N,D(),O+=N,D())}if("/"===N&&"/"===S[k+1]){for(I=b;""!==N&&"\n"!==N;)O+=N,D();return}!function(){I=x;for(;""!==N;)O+=N,D();throw new o('Syntax error in part "'+O+'"',k-O.length)}()}()}()}()}()}()}(),I===y&&(O=function(e){for(var t="",n=0;n<e.length;n++){var i=e[n];t+=d(i)?" ":i}return t}(O),P()),I===b&&(I=x,O="",P())}function F(){if(I!==f||"{"!==O)!function(){if(I===f&&"["===O){if(P(),I===f&&"]"===O)return P();for(;;)if(F(),I===f&&","===O){if(P(),I===f&&"]"===O){j=u(j,",");break}}else{if(!A())break;j=p(j,",")}return I===f&&"]"===O?P():j=p(j,"]")}!function(){if(I===g){for(P();I===f&&"+"===O;){var e;O="",P(),I===g&&(e=j.lastIndexOf('"'),j=j.substring(0,e)+O.substring(1),O="",P())}return}!function(){if(I===m)return P();!function(){if(I===v){if(T[O])return P();if(w[O])return O=w[O],P();var e=O,t=j.length;if(O="",P(),I===f&&"("===O)return O="",P(),F(),I===f&&")"===O&&(O="",P(),I===f&&";"===O&&(O="",P()));for(j=function(e,t,n){return e.substring(0,n)+t+e.substring(n)}(j,'"'+e,t);I===v||I===m;)P();return j+='"'}!function(){throw new o(""===O?"Unexpected end of json string":"Value expected",k-O.length)}()}()}()}()}();else if(P(),I!==f||"}"!==O){for(;;){if(I!==v&&I!==m||(I=g,O='"'+O+'"'),I!==g)throw new o("Object key expected",k-O.length);if(P(),I===f&&":"===O)P();else{if(!A())throw new o("Colon expected",k-O.length);j=p(j,":")}if(F(),I===f&&","===O){if(P(),I===f&&"}"===O){j=u(j,",");break}}else{if(I!==g&&I!==m&&I!==v)break;j=p(j,",")}}I===f&&"}"===O?P():j=p(j,"}")}else P()}return function(e){if(j="",k=0,N=(S=e).charAt(0),O="",I=x,P(),e=I===f&&"{"===O,F(),""===O)return j;if(e&&A()){for(;A();)j=p(j,","),F();return"[\n"+j+"\n]"}throw new o("Unexpected characters",k-O.length)}}()},function(e,t,n){"use strict";function o(e,t){for(var n=0;n<t.length;n++){var i=t[n];i.enumerable=i.enumerable||!1,i.configurable=!0,"value"in i&&(i.writable=!0),Object.defineProperty(e,i.key,i)}}n.d(t,"a",function(){return i});var i=function(){function t(e){if(!function(e){if(!(e instanceof t))throw new TypeError("Cannot call a class as a function")}(this),this.target=e.target||null,!this.target)throw new Error('FocusTracker constructor called without a "target" to track.');this.onFocus="function"==typeof e.onFocus?e.onFocus:null,this.onBlur="function"==typeof e.onBlur?e.onBlur:null,this._onClick=this._onEvent.bind(this),this._onKeyUp=function(e){9!==e.which&&9!==e.keyCode||this._onEvent(e)}.bind(this),this.focusFlag=!1,this.firstEventFlag=!0,(this.onFocus||this.onBlur)&&(document.addEventListener("click",this._onClick),document.addEventListener("keyup",this._onKeyUp))}var e,n,i;return e=t,(n=[{key:"destroy",value:function(){document.removeEventListener("click",this._onClick),document.removeEventListener("keyup",this._onKeyUp),this._onEvent({target:document.body})}},{key:"_onEvent",value:function(e){e=e.target,e=e===this.target||!(!this.target.contains(e)&&!this.target.contains(document.activeElement));e?this.focusFlag||(this.onFocus&&this.onFocus({type:"focus",target:this.target}),this.focusFlag=!0):(this.focusFlag||this.firstEventFlag)&&(this.onBlur&&this.onBlur({type:"blur",target:this.target}),this.focusFlag=!1,this.firstEventFlag&&(this.firstEventFlag=!1))}}])&&o(e.prototype,n),i&&o(e,i),t}()},function(e,t,n){"use strict";n.d(t,"a",function(){return o});var u=n(3),p=n(1);function i(e,t){for(var n=0;n<t.length;n++){var i=t[n];i.enumerable=i.enumerable||!1,i.configurable=!0,"value"in i&&(i.writable=!0),Object.defineProperty(e,i.key,i)}}var o=function(){function h(e,t,n,i){!function(e){if(!(e instanceof h))throw new TypeError("Cannot call a class as a function")}(this);for(var o={code:{text:Object(p.c)("modeCodeText"),title:Object(p.c)("modeCodeTitle"),click:function(){i("code")}},form:{text:Object(p.c)("modeFormText"),title:Object(p.c)("modeFormTitle"),click:function(){i("form")}},text:{text:Object(p.c)("modeTextText"),title:Object(p.c)("modeTextTitle"),click:function(){i("text")}},tree:{text:Object(p.c)("modeTreeText"),title:Object(p.c)("modeTreeTitle"),click:function(){i("tree")}},view:{text:Object(p.c)("modeViewText"),title:Object(p.c)("modeViewTitle"),click:function(){i("view")}},preview:{text:Object(p.c)("modePreviewText"),title:Object(p.c)("modePreviewTitle"),click:function(){i("preview")}}},r=[],s=0;s<t.length;s++){var a=t[s],l=o[a];if(!l)throw new Error('Unknown mode "'+a+'"');l.className="jsoneditor-type-modes"+(n===a?" jsoneditor-selected":""),r.push(l)}var c=o[n];if(!c)throw new Error('Unknown mode "'+n+'"');var c=c.text,d=document.createElement("button");d.type="button",d.className="jsoneditor-modes jsoneditor-separator",d.textContent=c+" ▾",d.title=Object(p.c)("modeEditorTitle"),d.onclick=function(){new u.a(r).show(d,e)};c=document.createElement("div");c.className="jsoneditor-modes",c.style.position="relative",c.appendChild(d),e.appendChild(c),this.dom={container:e,box:d,frame:c}}var e,t,n;return e=h,(t=[{key:"focus",value:function(){this.dom.box.focus()}},{key:"destroy",value:function(){this.dom&&this.dom.frame&&this.dom.frame.parentNode&&this.dom.frame.parentNode.removeChild(this.dom.frame),this.dom=null}}])&&i(e.prototype,t),n&&i(e,n),h}()},function(e,t,n){"use strict";function i(){}var o={defaultSelected:!0,width:"auto",disabled:!1,searchable:!0,clearable:!1,sortSelected:!1,allowDeselect:!1,closeOnScroll:!1,nativeDropdown:!1,placeholder:"Select an option...",taggable:!1,tagPlaceholder:"Enter a tag..."};i.prototype={on:function(e,t){this._events=this._events||{},this._events[e]=this._events[e]||[],this._events[e].push(t)},off:function(e,t){this._events=this._events||{},e in this._events!=!1&&this._events[e].splice(this._events[e].indexOf(t),1)},emit:function(e){if(this._events=this._events||{},e in this._events!=!1)for(var t=0;t<this._events[e].length;t++)this._events[e][t].apply(this,Array.prototype.slice.call(arguments,1))}},i.mixin=function(e){for(var t=["on","off","emit"],n=0;n<t.length;n++)"function"==typeof e?e.prototype[t[n]]=i.prototype[t[n]]:e[t[n]]=i.prototype[t[n]];return e};var d={extend:function(e,t){for(var n in t=t||{},e)e.hasOwnProperty(n)&&(t.hasOwnProperty(n)||(t[n]=e[n]));return t},each:function(e,t,n){if("[object Object]"===Object.prototype.toString.call(e))for(var i in e)Object.prototype.hasOwnProperty.call(e,i)&&t.call(n,i,e[i],e);else for(var o=0,r=e.length;o<r;o++)t.call(n,o,e[o],e)},createElement:function(e,t){var n,i,o=document,r=o.createElement(e);if(t&&"[object Object]"===Object.prototype.toString.call(t))for(n in t)n in r?r[n]=t[n]:"html"===n?r.textContent=t[n]:"text"===n?(i=o.createTextNode(t[n]),r.appendChild(i)):r.setAttribute(n,t[n]);return r},hasClass:function(e,t){if(e)return e.classList?e.classList.contains(t):!!e.className&&!!e.className.match(new RegExp("(\\s|^)"+t+"(\\s|$)"))},addClass:function(e,t){d.hasClass(e,t)||(e.classList?e.classList.add(t):e.className=e.className.trim()+" "+t)},removeClass:function(e,t){d.hasClass(e,t)&&(
e.classList?e.classList.remove(t):e.className=e.className.replace(new RegExp("(^|\\s)"+t.split(" ").join("|")+"(\\s|$)","gi")," "))},closest:function(e,t){return e&&e!==document.body&&(t(e)?e:d.closest(e.parentNode,t))},isInt:function(e){return"number"==typeof e&&isFinite(e)&&Math.floor(e)===e},debounce:function(i,o,r){var s;return function(){var e=this,t=arguments,n=r&&!s;clearTimeout(s),s=setTimeout(function(){s=null,r||i.apply(e,t)},o),n&&i.apply(e,t)}},rect:function(e,t){var n=window,i=e.getBoundingClientRect(),e=t?n.pageXOffset:0,n=t?n.pageYOffset:0;return{bottom:i.bottom+n,height:i.height,left:i.left+e,right:i.right+e,top:i.top+n,width:i.width}},includes:function(e,t){return-1<e.indexOf(t)},truncate:function(e){for(;e.firstChild;)e.removeChild(e.firstChild)}};function l(e,t){return e.hasOwnProperty(t)&&(!0===e[t]||e[t].length)}function s(e,t,n){e.parentNode?e.parentNode.parentNode||t.appendChild(e.parentNode):t.appendChild(e),d.removeClass(e,"excluded"),n||(e.textContent=e.textContent+"")}function a(){var n,e;this.items.length&&(n=document.createDocumentFragment(),this.config.pagination?(e=this.pages.slice(0,this.pageIndex),d.each(e,function(e,t){d.each(t,function(e,t){s(t,n,this.customOption)},this)},this)):d.each(this.items,function(e,t){s(t,n,this.customOption)},this),n.childElementCount&&(d.removeClass(this.items[this.navIndex],"active"),this.navIndex=n.querySelector(".selectr-option").idx,d.addClass(this.items[this.navIndex],"active")),this.tree.appendChild(n))}function c(e,t){return t=t||e,t=this.customOption?this.config.renderOption(t):e.textContent,(t=d.createElement("li",{class:"selectr-option",html:t,role:"treeitem","aria-selected":!1})).idx=e.idx,this.items.push(t),e.defaultSelected&&this.defaultSelected.push(e.idx),e.disabled&&(t.disabled=!0,d.addClass(t,"disabled")),t}function r(){(this.config.searchable||this.config.taggable)&&(this.input.value=null,this.searching=!1,this.config.searchable&&d.removeClass(this.inputContainer,"active"),d.hasClass(this.container,"notice")&&(d.removeClass(this.container,"notice"),d.addClass(this.container,"open"),this.input.focus()),d.each(this.items,function(e,t){d.removeClass(t,"excluded"),this.customOption||(t.textContent=t.textContent+"")},this))}function h(e,t){if(t=t||{},!e)throw new Error("You must supply either a HTMLSelectElement or a CSS3 selector string.");if("string"==typeof(this.el=e)&&(this.el=document.querySelector(e)),null===this.el)throw new Error("The element you passed to Selectr can not be found.");if("select"!==this.el.nodeName.toLowerCase())throw new Error("The element you passed to Selectr is not a HTMLSelectElement.");this.render(t)}var u=function(){var n,e=this.tree,t=e.scrollTop;e.scrollHeight-e.offsetHeight<=t&&this.pageIndex<this.pages.length&&(n=document.createDocumentFragment(),d.each(this.pages[this.pageIndex],function(e,t){s(t,n,this.customOption)},this),e.appendChild(n),this.pageIndex++,this.emit("selectr.paginate",{items:this.items.length,total:this.data.length,page:this.pageIndex,pages:this.pages.length}))};h.prototype.render=function(e){var t;this.rendered||(this.config=d.extend(o,e),this.originalType=this.el.type,this.originalIndex=this.el.tabIndex,this.defaultSelected=[],this.originalOptionCount=this.el.options.length,(this.config.multiple||this.config.taggable)&&(this.el.multiple=!0),this.disabled=l(this.config,"disabled"),this.opened=!1,this.config.taggable&&(this.config.searchable=!1),this.navigating=!1,this.mobileDevice=!1,/Android|webOS|iPhone|iPad|BlackBerry|Windows Phone|Opera Mini|IEMobile|Mobile/i.test(navigator.userAgent)&&(this.mobileDevice=!0),this.customOption=this.config.hasOwnProperty("renderOption")&&"function"==typeof this.config.renderOption,this.customSelected=this.config.hasOwnProperty("renderSelection")&&"function"==typeof this.config.renderSelection,i.mixin(this),function(){this.requiresPagination=this.config.pagination&&0<this.config.pagination,l(this.config,"width")&&(d.isInt(this.config.width)?this.width=this.config.width+"px":"auto"===this.config.width?this.width="100%":d.includes(this.config.width,"%")&&(this.width=this.config.width)),this.container=d.createElement("div",{class:"selectr-container"}),this.config.customClass&&d.addClass(this.container,this.config.customClass),this.mobileDevice?d.addClass(this.container,"selectr-mobile"):d.addClass(this.container,"selectr-desktop"),this.el.tabIndex=-1,this.config.nativeDropdown||this.mobileDevice?d.addClass(this.el,"selectr-visible"):d.addClass(this.el,"selectr-hidden"),this.selected=d.createElement("div",{class:"selectr-selected",disabled:this.disabled,tabIndex:1,"aria-expanded":!1}),this.label=d.createElement(this.el.multiple?"ul":"span",{class:"selectr-label"});var e,t=d.createElement("div",{class:"selectr-options-container"});this.tree=d.createElement("ul",{class:"selectr-options",role:"tree","aria-hidden":!0,"aria-expanded":!1}),this.notice=d.createElement("div",{class:"selectr-notice"}),this.el.setAttribute("aria-hidden",!0),this.disabled&&(this.el.disabled=!0),this.el.multiple&&(d.addClass(this.label,"selectr-tags"),d.addClass(this.container,"multiple"),this.tags=[],this.selectedValues=this.getSelectedProperties("value"),this.selectedIndexes=this.getSelectedProperties("idx")),this.selected.appendChild(this.label),this.config.clearable&&(this.selectClear=d.createElement("button",{class:"selectr-clear",type:"button"}),this.container.appendChild(this.selectClear),d.addClass(this.container,"clearable")),this.config.taggable&&(e=d.createElement("li",{class:"input-tag"}),this.input=d.createElement("input",{class:"selectr-tag-input",placeholder:this.config.tagPlaceholder,tagIndex:0,autocomplete:"off",autocorrect:"off",autocapitalize:"off",spellcheck:"false",role:"textbox",type:"search"}),e.appendChild(this.input),this.label.appendChild(e),d.addClass(this.container,"taggable"),this.tagSeperators=[","],this.config.tagSeperators&&(this.tagSeperators=this.tagSeperators.concat(this.config.tagSeperators))),this.config.searchable&&(this.input=d.createElement("input",{class:"selectr-input",tagIndex:-1,autocomplete:"off",autocorrect:"off",autocapitalize:"off",spellcheck:"false",role:"textbox",type:"search"}),this.inputClear=d.createElement("button",{class:"selectr-input-clear",type:"button"}),this.inputContainer=d.createElement("div",{class:"selectr-input-container"}),this.inputContainer.appendChild(this.input),this.inputContainer.appendChild(this.inputClear),t.appendChild(this.inputContainer)),t.appendChild(this.notice),t.appendChild(this.tree),this.items=[],this.options=[],this.el.options.length&&(this.options=[].slice.call(this.el.options));var n,i,o,r=!1,s=0;this.el.children.length&&d.each(this.el.children,function(e,t){"OPTGROUP"===t.nodeName?(r=d.createElement("ul",{class:"selectr-optgroup",role:"group",html:"<li class='selectr-optgroup--label'>"+t.label+"</li>"}),d.each(t.children,function(e,t){t.idx=s,r.appendChild(c.call(this,t,r)),s++},this)):(t.idx=s,c.call(this,t),s++)},this),this.config.data&&Array.isArray(this.config.data)&&(n=!(this.data=[]),r=!1,s=0,d.each(this.config.data,function(e,t){l(t,"children")?(n=d.createElement("optgroup",{label:t.text}),r=d.createElement("ul",{class:"selectr-optgroup",role:"group",html:"<li class='selectr-optgroup--label'>"+t.text+"</li>"}),d.each(t.children,function(e,t){(i=new Option(t.text,t.value,!1,t.hasOwnProperty("selected")&&!0===t.selected)).disabled=l(t,"disabled"),this.options.push(i),n.appendChild(i),i.idx=s,r.appendChild(c.call(this,i,t)),this.data[s]=t,s++},this)):((i=new Option(t.text,t.value,!1,t.hasOwnProperty("selected")&&!0===t.selected)).disabled=l(t,"disabled"),this.options.push(i),i.idx=s,c.call(this,i,t),this.data[s]=t,s++)},this)),this.setSelected(!0);for(var a=this.navIndex=0;a<this.items.length;a++)if(o=this.items[a],!d.hasClass(o,"disabled")){d.addClass(o,"active"),this.navIndex=a;break}this.requiresPagination&&(this.pageIndex=1,this.paginate()),this.container.appendChild(this.selected),this.container.appendChild(t),this.placeEl=d.createElement("div",{class:"selectr-placeholder"}),this.setPlaceholder(),this.selected.appendChild(this.placeEl),this.disabled&&this.disable(),this.el.parentNode.insertBefore(this.container,this.el),this.container.appendChild(this.el)}.call(this),this.bindEvents(),this.update(),this.optsRect=d.rect(this.tree),this.rendered=!0,this.el.multiple||(this.el.selectedIndex=this.selectedIndex),t=this,setTimeout(function(){t.emit("selectr.init")},20))},h.prototype.getSelected=function(){return this.el.querySelectorAll("option:checked")},h.prototype.getSelectedProperties=function(t){var e=this.getSelected();return[].slice.call(e).map(function(e){return e[t]}).filter(function(e){return null!=e})},h.prototype.bindEvents=function(){var i=this;this.events={},this.events.dismiss=function(e){e=e.target;this.container.contains(e)||!this.opened&&!d.hasClass(this.container,"notice")||this.close()}.bind(this),this.events.navigate=function(e){if(e=e||window.event,this.items.length&&this.opened&&d.includes([13,38,40],e.which)){if(e.preventDefault(),13===e.which)return!(this.config.taggable&&0<this.input.value.length)&&this.change(this.navIndex);var t,n=this.items[this.navIndex];switch(e.which){case 38:(t=0)<this.navIndex&&this.navIndex--;break;case 40:t=1,this.navIndex<this.items.length-1&&this.navIndex++}for(this.navigating=!0;d.hasClass(this.items[this.navIndex],"disabled")||d.hasClass(this.items[this.navIndex],"excluded");)if(t?this.navIndex++:this.navIndex--,this.searching){if(this.navIndex>this.tree.lastElementChild.idx){this.navIndex=this.tree.lastElementChild.idx;break}if(this.navIndex<this.tree.firstElementChild.idx){this.navIndex=this.tree.firstElementChild.idx;break}}e=d.rect(this.items[this.navIndex]);t?(0===this.navIndex?this.tree.scrollTop=0:e.top+e.height>this.optsRect.top+this.optsRect.height&&(this.tree.scrollTop=this.tree.scrollTop+(e.top+e.height-(this.optsRect.top+this.optsRect.height))),this.navIndex===this.tree.childElementCount-1&&this.requiresPagination&&u.call(this)):0===this.navIndex?this.tree.scrollTop=0:e.top-this.optsRect.top<0&&(this.tree.scrollTop=this.tree.scrollTop+(e.top-this.optsRect.top)),n&&d.removeClass(n,"active"),d.addClass(this.items[this.navIndex],"active")}else this.navigating=!1}.bind(this),this.events.reset=this.reset.bind(this),(this.config.nativeDropdown||this.mobileDevice)&&(this.container.addEventListener("touchstart",function(e){e.changedTouches[0].target===i.el&&i.toggle()}),(this.config.nativeDropdown||this.mobileDevice)&&this.container.addEventListener("click",function(e){e.preventDefault(),e.stopPropagation(),e.target===i.el&&i.toggle()}),this.el.addEventListener("change",function(e){var t;i.el.multiple?(t=i.getSelectedProperties("idx"),t=function(e,t){for(var n,i=[],o=e.slice(0),r=0;r<t.length;r++)-1<(n=o.indexOf(t[r]))?o.splice(n,1):i.push(t[r]);return[i,o]}(i.selectedIndexes,t),d.each(t[0],function(e,t){i.select(t)},i),d.each(t[1],function(e,t){i.deselect(t)},i)):-1<i.el.selectedIndex&&i.select(i.el.selectedIndex)})),this.config.nativeDropdown&&this.container.addEventListener("keydown",function(e){"Enter"===e.key&&i.selected===document.activeElement&&(i.toggle(),setTimeout(function(){i.el.focus()},200))}),this.selected.addEventListener("click",function(e){i.disabled||i.toggle(),e.preventDefault(),e.stopPropagation()}),this.label.addEventListener("click",function(e){d.hasClass(e.target,"selectr-tag-remove")&&i.deselect(e.target.parentNode.idx)}),this.selectClear&&this.selectClear.addEventListener("click",this.clear.bind(this)),this.tree.addEventListener("mousedown",function(e){e.preventDefault()}),this.tree.addEventListener("click",function(e){e.preventDefault(),e.stopPropagation();e=d.closest(e.target,function(e){return e&&d.hasClass(e,"selectr-option")});e&&(d.hasClass(e,"disabled")||(d.hasClass(e,"selected")?(i.el.multiple||!i.el.multiple&&i.config.allowDeselect)&&i.deselect(e.idx):i.select(e.idx),i.opened&&!i.el.multiple&&i.close()))}),this.tree.addEventListener("mouseover",function(e){d.hasClass(e.target,"selectr-option")&&(d.hasClass(e.target,"disabled")||(d.removeClass(i.items[i.navIndex],"active"),d.addClass(e.target,"active"),i.navIndex=[].slice.call(i.items).indexOf(e.target)))}),this.config.searchable&&(this.input.addEventListener("focus",function(e){i.searching=!0}),this.input.addEventListener("blur",function(e){i.searching=!1}),this.input.addEventListener("keyup",function(e){i.search(),i.config.taggable||(this.value.length?d.addClass(this.parentNode,"active"):d.removeClass(this.parentNode,"active"))}),this.inputClear.addEventListener("click",function(e){i.input.value=null,r.call(i),i.tree.childElementCount||a.call(i)})),this.config.taggable&&this.input.addEventListener("keyup",function(e){var n;i.search(),i.config.taggable&&this.value.length&&(n=this.value.trim(),13!==e.which&&!d.includes(i.tagSeperators,e.key)||(d.each(i.tagSeperators,function(e,t){n=n.replace(t,"")}),i.add({value:n,text:n,selected:!0},!0)?(i.close(),r.call(i)):(this.value="",i.setMessage("That tag is already in use."))))}),this.update=d.debounce(function(){i.opened&&i.config.closeOnScroll&&i.close(),i.width&&(i.container.style.width=i.width),i.invert()},50),this.requiresPagination&&(this.paginateItems=d.debounce(function(){u.call(this)},50),this.tree.addEventListener("scroll",this.paginateItems.bind(this))),document.addEventListener("click",this.events.dismiss),window.addEventListener("keydown",this.events.navigate),window.addEventListener("resize",this.update),window.addEventListener("scroll",this.update),this.el.form&&this.el.form.addEventListener("reset",this.events.reset)},h.prototype.setSelected=function(e){var n;this.config.data||this.el.multiple||!this.el.options.length||(0===this.el.selectedIndex&&(this.el.options[0].defaultSelected||this.config.defaultSelected||(this.el.selectedIndex=-1)),this.selectedIndex=this.el.selectedIndex,-1<this.selectedIndex&&this.select(this.selectedIndex)),this.config.multiple&&"select-one"===this.originalType&&!this.config.data&&this.el.options[0].selected&&!this.el.options[0].defaultSelected&&(this.el.options[0].selected=!1),d.each(this.options,function(e,t){t.selected&&t.defaultSelected&&this.select(t.idx)},this),this.config.selectedValue&&this.setValue(this.config.selectedValue),this.config.data&&(!this.el.multiple&&this.config.defaultSelected&&this.el.selectedIndex<0&&this.select(0),n=0,d.each(this.config.data,function(e,t){l(t,"children")?d.each(t.children,function(e,t){t.hasOwnProperty("selected")&&!0===t.selected&&this.select(n),n++},this):(t.hasOwnProperty("selected")&&!0===t.selected&&this.select(n),n++)},this))},h.prototype.destroy=function(){this.rendered&&(this.emit("selectr.destroy"),"select-one"===this.originalType&&(this.el.multiple=!1),this.config.data&&(this.el.textContent=""),d.removeClass(this.el,"selectr-hidden"),this.el.form&&d.off(this.el.form,"reset",this.events.reset),d.off(document,"click",this.events.dismiss),d.off(document,"keydown",this.events.navigate),d.off(window,"resize",this.update),d.off(window,"scroll",this.update),this.container.parentNode.replaceChild(this.el,this.container),this.rendered=!1)},h.prototype.change=function(e){var t=this.items[e],n=this.options[e];n.disabled||(n.selected&&d.hasClass(t,"selected")?this.deselect(e):this.select(e),this.opened&&!this.el.multiple&&this.close())},h.prototype.select=function(i){var e=this.items[i],t=[].slice.call(this.el.options),n=this.options[i];if(this.el.multiple){if(d.includes(this.selectedIndexes,i))return!1;if(this.config.maxSelections&&this.tags.length===this.config.maxSelections)return this.setMessage("A maximum of "+this.config.maxSelections+" items can be selected.",!0),!1;this.selectedValues.push(n.value),this.selectedIndexes.push(i),function(e){var l,c=this,n=document.createDocumentFragment(),t=this.options[e.idx],i=this.data?this.data[e.idx]:t,o=this.customSelected?this.config.renderSelection(i):t.textContent,i=d.createElement("li",{class:"selectr-tag",html:o}),o=d.createElement("button",{class:"selectr-tag-remove",type:"button"});i.appendChild(o),i.idx=e.idx,i.tag=t.value,this.tags.push(i),this.config.sortSelected?(t=this.tags.slice(),l=function(e,i){e.replace(/(\d+)|(\D+)/g,function(e,t,n){i.push([t||1/0,n||""])})},t.sort(function(e,t){var n,i,o=[],r=[];for(!0===c.config.sortSelected?(n=e.tag,i=t.tag):"text"===c.config.sortSelected&&(n=e.textContent,i=t.textContent),l(n,o),l(i,r);o.length&&r.length;){var s=o.shift(),a=r.shift(),a=s[0]-a[0]||s[1].localeCompare(a[1]);if(a)return a}return o.length-r.length}),d.each(t,function(e,t){n.appendChild(t)}),this.label.textContent=""):n.appendChild(i),this.config.taggable?this.label.insertBefore(n,this.input.parentNode):this.label.appendChild(n)}.call(this,e)}else{var o=this.data?this.data[i]:n;this.label.textContent=this.customSelected?this.config.renderSelection(o):n.textContent,this.selectedValue=n.value,this.selectedIndex=i,d.each(this.options,function(e,t){var n=this.items[e];e!==i&&(n&&d.removeClass(n,"selected"),t.selected=!1,t.removeAttribute("selected"))},this)}d.includes(t,n)||this.el.add(n),e.setAttribute("aria-selected",!0),d.addClass(e,"selected"),d.addClass(this.container,"has-selected"),n.selected=!0,n.setAttribute("selected",""),this.emit("selectr.change",n),this.emit("selectr.select",n)},h.prototype.deselect=function(e,t){var n=this.items[e],i=this.options[e];if(this.el.multiple){var o=this.selectedIndexes.indexOf(e);this.selectedIndexes.splice(o,1);o=this.selectedValues.indexOf(i.value);this.selectedValues.splice(o,1),function(n){var i=!1;d.each(this.tags,function(e,t){t.idx===n.idx&&(i=t)},this),i&&(this.label.removeChild(i),this.tags.splice(this.tags.indexOf(i),1))}.call(this,n),this.tags.length||d.removeClass(this.container,"has-selected")}else{if(!t&&!this.config.clearable&&!this.config.allowDeselect)return!1;this.label.textContent="",this.selectedValue=null,this.el.selectedIndex=this.selectedIndex=-1,d.removeClass(this.container,"has-selected")}this.items[e].setAttribute("aria-selected",!1),d.removeClass(this.items[e],"selected"),i.selected=!1,i.removeAttribute("selected"),this.emit("selectr.change",null),this.emit("selectr.deselect",i)},h.prototype.setValue=function(n){var i=Array.isArray(n);if(i||(n=n.toString().trim()),!this.el.multiple&&i)return!1;d.each(this.options,function(e,t){(i&&d.includes(n.toString(),t.value)||t.value===n)&&this.change(t.idx)},this)},h.prototype.getValue=function(e,t){var n,i;return this.el.multiple?e?this.selectedIndexes.length&&(i={values:[]},d.each(this.selectedIndexes,function(e,t){t=this.options[t];i.values[e]={value:t.value,text:t.textContent}},this)):i=this.selectedValues.slice():i=e?{value:(n=this.options[this.selectedIndex]).value,text:n.textContent}:this.selectedValue,e&&t&&(i=JSON.stringify(i)),i},h.prototype.add=function(n,i){if(n){if(this.data=this.data||[],this.items=this.items||[],this.options=this.options||[],Array.isArray(n))d.each(n,function(e,t){this.add(t,i)},this);else if("[object Object]"===Object.prototype.toString.call(n)){if(i){var o=!1;if(d.each(this.options,function(e,t){t.value.toLowerCase()===n.value.toLowerCase()&&(o=!0)}),o)return!1}var e=d.createElement("option",n);return this.data.push(n),this.options.push(e),e.idx=0<this.options.length?this.options.length-1:0,c.call(this,e),n.selected&&this.select(e.idx),e}return this.setPlaceholder(),this.config.pagination&&this.paginate(),!0}},h.prototype.remove=function(n){var i,o=[];Array.isArray(n)?d.each(n,function(e,t){d.isInt(t)?o.push(this.getOptionByIndex(t)):"string"==typeof n&&o.push(this.getOptionByValue(t))},this):d.isInt(n)?o.push(this.getOptionByIndex(n)):"string"==typeof n&&o.push(this.getOptionByValue(n)),o.length&&(d.each(o,function(e,t){i=t.idx,this.el.remove(t),this.options.splice(i,1);t=this.items[i].parentNode;t&&t.removeChild(this.items[i]),this.items.splice(i,1),d.each(this.options,function(e,t){t.idx=e,this.items[e].idx=e},this)},this),this.setPlaceholder(),this.config.pagination&&this.paginate())},h.prototype.removeAll=function(){this.clear(!0),d.each(this.el.options,function(e,t){this.el.remove(t)},this),d.truncate(this.tree),this.items=[],this.options=[],this.data=[],this.navIndex=0,this.requiresPagination&&(this.requiresPagination=!1,this.pageIndex=1,this.pages=[]),this.setPlaceholder()},h.prototype.search=function(o){var r,e,t;this.navigating||(o=o||this.input.value,r=document.createDocumentFragment(),this.removeMessage(),d.truncate(this.tree),1<o.length?(d.each(this.options,function(e,t){var n,i=this.items[t.idx];d.includes(t.textContent.toLowerCase(),o.toLowerCase())&&!t.disabled?(s(i,r,this.customOption),d.removeClass(i,"excluded"),this.customOption||(i.textContent="",(n=function(e,t){var n=new RegExp(e,"i").exec(t);if(n){e=n.index,n=n.index+n[0].length;return{before:t.substring(0,e),match:t.substring(e,n),after:t.substring(n)}}return null}(o,t.textContent))&&(i.appendChild(document.createTextNode(n.before)),(t=document.createElement("span")).className="selectr-match",t.appendChild(document.createTextNode(n.match)),i.appendChild(t),i.appendChild(document.createTextNode(n.after))))):d.addClass(i,"excluded")},this),r.childElementCount?(e=this.items[this.navIndex],t=r.firstElementChild,d.removeClass(e,"active"),this.navIndex=t.idx,d.addClass(t,"active")):this.config.taggable||this.setMessage("no results.")):a.call(this),this.tree.appendChild(r))},h.prototype.toggle=function(){this.disabled||(this.opened?this.close():this.open())},h.prototype.open=function(){var e=this;return!!this.options.length&&(this.opened||this.emit("selectr.open"),this.opened=!0,this.mobileDevice||this.config.nativeDropdown?(d.addClass(this.container,"native-open"),void(this.config.data&&d.each(this.options,function(e,t){this.el.add(t)},this))):(d.addClass(this.container,"open"),a.call(this),this.invert(),this.tree.scrollTop=0,d.removeClass(this.container,"notice"),this.selected.setAttribute("aria-expanded",!0),this.tree.setAttribute("aria-hidden",!1),this.tree.setAttribute("aria-expanded",!0),void(this.config.searchable&&!this.config.taggable&&setTimeout(function(){e.input.focus(),e.input.tabIndex=0},10))))},h.prototype.close=function(){var e;this.opened&&this.emit("selectr.close"),this.opened=!1,this.mobileDevice||this.config.nativeDropdown?d.removeClass(this.container,"native-open"):(e=d.hasClass(this.container,"notice"),this.config.searchable&&!e&&(this.input.blur(),this.input.tabIndex=-1,this.searching=!1),e&&(d.removeClass(this.container,"notice"),this.notice.textContent=""),d.removeClass(this.container,"open"),d.removeClass(this.container,"native-open"),this.selected.setAttribute("aria-expanded",!1),this.tree.setAttribute("aria-hidden",!0),this.tree.setAttribute("aria-expanded",!1),d.truncate(this.tree),r.call(this))},h.prototype.enable=function(){this.disabled=!1,this.el.disabled=!1,this.selected.tabIndex=this.originalIndex,this.el.multiple&&d.each(this.tags,function(e,t){t.lastElementChild.tabIndex=0}),d.removeClass(this.container,"selectr-disabled")},h.prototype.disable=function(e){e||(this.el.disabled=!0),this.selected.tabIndex=-1,this.el.multiple&&d.each(this.tags,function(e,t){t.lastElementChild.tabIndex=-1}),this.disabled=!0,d.addClass(this.container,"selectr-disabled")},h.prototype.reset=function(){this.disabled||(this.clear(),this.setSelected(!0),d.each(this.defaultSelected,function(e,t){this.select(t)},this),this.emit("selectr.reset"))},h.prototype.clear=function(e){var t;this.el.multiple?this.selectedIndexes.length&&(t=this.selectedIndexes.slice(),d.each(t,function(e,t){this.deselect(t)},this)):-1<this.selectedIndex&&this.deselect(this.selectedIndex,e),this.emit("selectr.clear")},h.prototype.serialise=function(e){var i=[];return d.each(this.options,function(e,t){var n={value:t.value,text:t.textContent};t.selected&&(n.selected=!0),t.disabled&&(n.disabled=!0),i[e]=n}),e?JSON.stringify(i):i},h.prototype.serialize=function(e){return this.serialise(e)},h.prototype.setPlaceholder=function(e){e=e||this.config.placeholder||this.el.getAttribute("placeholder"),this.options.length||(e="No options available"),this.placeEl.textContent=e},h.prototype.paginate=function(){if(this.items.length){var n=this;return this.pages=this.items.map(function(e,t){return t%n.config.pagination==0?n.items.slice(t,t+n.config.pagination):null}).filter(function(e){return e}),this.pages}},h.prototype.setMessage=function(e,t){t&&this.close(),d.addClass(this.container,"notice"),this.notice.textContent=e},h.prototype.removeMessage=function(){d.removeClass(this.container,"notice"),this.notice.textContent=""},h.prototype.invert=function(){var e=d.rect(this.selected),t=this.tree.parentNode.offsetHeight,n=window.innerHeight;e.top+e.height+t>n?(d.addClass(this.container,"inverted"),this.isInverted=!0):(d.removeClass(this.container,"inverted"),this.isInverted=!1),this.optsRect=d.rect(this.tree)},h.prototype.getOptionByIndex=function(e){return this.options[e]},h.prototype.getOptionByValue=function(e){for(var t=!1,n=0,i=this.options.length;n<i;n++)if(this.options[n].value.trim()===e.toString().trim()){t=this.options[n];break}return t},e.exports=h},function(e,t,n){"use strict";n.d(t,"a",function(){return i});var u=n(0);function i(i,e,o){var t,n=3<arguments.length&&void 0!==arguments[3]&&arguments[3],r="function"==typeof(l=i).getRootNode?l.getRootNode():window,s={},a=i.getBoundingClientRect(),l=e.getBoundingClientRect(),c=document.createElement("div");function d(){if(c&&c.parentNode){for(var e in c.parentNode.removeChild(c),s)t=s,n=e,Object.prototype.hasOwnProperty.call(t,n)&&((n=s[e])&&Object(u.removeEventListener)(r,e,n),delete s[e]);"function"==typeof o&&o(i)}var t,n}function h(e){(e=e.target)===c||Object(u.isChildOf)(e,c)||d()}return c.className="jsoneditor-anchor",c.style.position="absolute",c.style.left=a.left-l.left+"px",c.style.top=a.top-l.top+"px",c.style.width=a.width-2+"px",c.style.height=a.height-2+"px",c.style.boxSizing="border-box",e.appendChild(c),s.mousedown=Object(u.addEventListener)(r,"mousedown",h),s.mousewheel=Object(u.addEventListener)(r,"mousewheel",h),n&&(t=null,c.onmouseover=function(){clearTimeout(t),t=null},c.onmouseout=function(){t=t||setTimeout(d,200)}),c.destroy=d,c}},function(e,t){e.exports=function t(e,n){"use strict";function i(e){return t.insensitive&&(""+e).toLowerCase()||""+e}var o,r,s=/(^([+\-]?(?:0|[1-9]\d*)(?:\.\d*)?(?:[eE][+\-]?\d+)?)?$|^0x[0-9a-f]+$|\d+)/gi,a=/(^[ ]*|[ ]*$)/g,l=/(^([\w ]+,?[\w ]+)?[\w ]+,?[\w ]+\d+:\d+(:\d+)?[\w ]?|^\d{1,4}[\/\-]\d{1,4}[\/\-]\d{1,4}|^\w+, \w+ \d+, \d{4})/,c=/^0x[0-9a-f]+$/i,d=/^0/,e=i(e).replace(a,"")||"",a=i(n).replace(a,"")||"",h=e.replace(s,"\0$1\0").replace(/\0$/,"").replace(/^\0/,"").split("\0"),u=a.replace(s,"\0$1\0").replace(/\0$/,"").replace(/^\0/,"").split("\0"),e=parseInt(e.match(c),16)||1!==h.length&&e.match(l)&&Date.parse(e),a=parseInt(a.match(c),16)||e&&a.match(l)&&Date.parse(a)||null;if(a){if(e<a)return-1;if(a<e)return 1}for(var p=0,f=Math.max(h.length,u.length);p<f;p++){if(o=!(h[p]||"").match(d)&&parseFloat(h[p])||h[p]||0,r=!(u[p]||"").match(d)&&parseFloat(u[p])||u[p]||0,isNaN(o)!==isNaN(r))return isNaN(o)?1:-1;if(typeof o!=typeof r&&(o+="",r+=""),o<r)return-1;if(r<o)return 1}return 0}},function(e,t,n){var i;if(window.Picker)i=window.Picker;else try{i=n(!function(){var e=new Error("Cannot find module 'vanilla-picker'");throw e.code="MODULE_NOT_FOUND",e}())}catch(e){}e.exports=i},function(e,t,n){var i,o;!function(){"use strict";i=[],void 0===(o="function"==typeof(o=function(){"use strict";function S(e){if(typeof Node==="object")return e instanceof Node;else return e&&typeof e==="object"&&typeof e.nodeType==="number"}function e(e){return"string"==typeof e}function j(){var r=[];return{watch:r.push.bind(r),trigger:function(e,t){var n=true;var i={detail:t,preventDefault:function e(){n=false}};for(var o=0;o<r.length;o++)r[o](e,i);return n}}}function k(e){return window.getComputedStyle(e).display==="none"}function N(e){this.elem=e}function t(e,t){return N.make((i=a)("parent")).clazz("pico-overlay").clazz(i("overlayClass","")).stylize({display:"none",position:"fixed",top:"0px",left:"0px",height:"100%",width:"100%",zIndex:1e4}).stylize(i("overlayStyles",{opacity:.5,background:"#000"})).onClick(function(){i("overlayClose",!0)&&o()})}N.make=function(e,t){if(typeof e==="string")e=document.querySelector(e);var n=document.createElement(t||"div");(e||document.body).appendChild(n);return new N(n)},N.prototype={child:function(e){return N.make(this.elem,e)},stylize:function(e){e=e||{};if(typeof e.opacity!=="undefined")e.filter="alpha(opacity="+e.opacity*100+")";for(var t in e)if(e.hasOwnProperty(t))this.elem.style[t]=e[t];return this},clazz:function(e){this.elem.className+=" "+e;return this},html:function(e){if(S(e))this.elem.appendChild(e);else this.elem.innerHTML=e;return this},onClick:function(e){this.elem.addEventListener("click",e);return this},destroy:function(){this.elem.parentNode.removeChild(this.elem)},hide:function(){this.elem.style.display="none"},show:function(){this.elem.style.display="block"},attr:function(e,t){if(t!==undefined)this.elem.setAttribute(e,t);return this},anyAncestor:function(e){var t=this.elem;while(t)if(e(new N(t)))return true;else t=t.parentNode;return false},isVisible:function(){return!k(this.elem)}};var O=1;function n(e,t){var n=e("width","auto");if("number"==typeof n)n+="px";var i=e("modalId","pico-"+O++);return N.make(e("parent")).clazz("pico-content").clazz(e("modalClass","")).stylize({display:"none",position:"fixed",zIndex:10001,left:"50%",top:"38.1966%",maxHeight:"90%",boxSizing:"border-box",width:n,"-ms-transform":"translate(-50%,-38.1966%)","-moz-transform":"translate(-50%,-38.1966%)","-webkit-transform":"translate(-50%,-38.1966%)","-o-transform":"translate(-50%,-38.1966%)",transform:"translate(-50%,-38.1966%)"}).stylize(e("modalStyles",{overflow:"auto",backgroundColor:"white",padding:"20px",borderRadius:"5px"})).html(e("content")).attr("id",i).attr("role","dialog").attr("aria-labelledby",e("ariaLabelledBy")).attr("aria-describedby",e("ariaDescribedBy",i)).onClick(function(e){new N(e.target).anyAncestor(function(e){return/\bpico-close\b/.test(e.elem.className)})&&t()})}function i(e,t){if(t("closeButton",!0))return e.child("button").html(t("closeHtml","&#xD7;")).clazz("pico-close").clazz(t("closeClass","")).stylize(t("closeStyles",{borderRadius:"2px",border:0,padding:0,cursor:"pointer",height:"15px",width:"15px",position:"absolute",top:"5px",right:"5px",fontSize:"16px",textAlign:"center",lineHeight:"15px",background:"#CCC"})).attr("aria-label",t("close-label","Close"))}function I(e){return function(){return e().elem}}var D=j(),A=j();function o(e,t){function _(e,t){return(e.msMatchesSelector||e.webkitMatchesSelector||e.matches).call(e,t)}function T(e){return!(k(e)||_(e,":disabled")||e.hasAttribute("contenteditable"))&&(e.hasAttribute("tabindex")||_(e,"input,select,textarea,button,a[href],area[href],iframe"))}function w(e){for(var t=e.getElementsByTagName("*"),n=0;n<t.length;n++)if(T(t[n]))return t[n]}function r(e){for(var t=e.getElementsByTagName("*"),n=t.length;n--;)if(T(t[n]))return t[n]}var e;d.beforeShow(function(){e=document.activeElement}),d.afterShow(function(){var e;!h()||(e=w(d.modalElem()))&&e.focus()}),d.afterClose(function(){h()&&e&&e.focus(),e=null}),A.watch(function(e){var t,n;h()&&d.isVisible()&&(t=w(d.modalElem()),n=function(e){for(var t=e.getElementsByTagName("*"),n=t.length;n--;)if(T(t[n]))return t[n]}(d.modalElem()),(e.shiftKey?t:n)===document.activeElement&&((e.shiftKey?n:t).focus(),e.preventDefault()))})}function r(e,t){var f,m=new N(document.body);u.beforeShow(function(){f=m.elem.style.overflow,p()&&m.stylize({overflow:"hidden"})}),u.afterClose(function(){m.stylize({overflow:f})})}return document.documentElement.addEventListener("keydown",function(e){var t=e.which||e.keyCode;27===t?D.trigger():9===t&&A.trigger(e)}),function(n){"string"!=typeof n&&!S(n)||(n={content:n});var r=j(),t=j(),i=j(),o=j(),s=j();function a(e,t){e=n[e];return"function"==typeof e&&(e=e(t)),void 0===e?t:e}var l,c,d,h,e,u,p,f,m,g=E.bind(window,"modal"),v=E.bind(window,"overlay"),y=E.bind(window,"close");function b(e){v().hide(),g().hide(),s.trigger(l,e)}function x(e){o.trigger(l,e)&&b(e)}function C(e){return function(){return e.apply(this,arguments),l}}function E(e,t){var n,i,o;return c||(n=function(e,t){var n=e("width","auto");"number"==typeof n&&(n+="px");var i=e("modalId","pico-"+O++);return N.make(e("parent")).clazz("pico-content").clazz(e("modalClass","")).stylize({display:"none",position:"fixed",zIndex:10001,left:"50%",top:"38.1966%",maxHeight:"90%",boxSizing:"border-box",width:n,"-ms-transform":"translate(-50%,-38.1966%)","-moz-transform":"translate(-50%,-38.1966%)","-webkit-transform":"translate(-50%,-38.1966%)","-o-transform":"translate(-50%,-38.1966%)",transform:"translate(-50%,-38.1966%)"}).stylize(e("modalStyles",{overflow:"auto",backgroundColor:"white",padding:"20px",borderRadius:"5px"})).html(e("content")).attr("id",i).attr("role","dialog").attr("aria-labelledby",e("ariaLabelledBy")).attr("aria-describedby",e("ariaDescribedBy",i)).onClick(function(e){new N(e.target).anyAncestor(function(e){return/\bpico-close\b/.test(e.elem.className)})&&t()})}(a,x),c={modal:n,overlay:(o=x,N.make((i=a)("parent")).clazz("pico-overlay").clazz(i("overlayClass","")).stylize({display:"none",position:"fixed",top:"0px",left:"0px",height:"100%",width:"100%",zIndex:1e4}).stylize(i("overlayStyles",{opacity:.5,background:"#000"})).onClick(function(){i("overlayClose",!0)&&o()})),close:function(e,t){if(t("closeButton",!0))return e.child("button").html(t("closeHtml","&#xD7;")).clazz("pico-close").clazz(t("closeClass","")).stylize(t("closeStyles",{borderRadius:"2px",border:0,padding:0,cursor:"pointer",height:"15px",width:"15px",position:"absolute",top:"5px",right:"5px",fontSize:"16px",textAlign:"center",lineHeight:"15px",background:"#CCC"})).attr("aria-label",t("close-label","Close"))}(n,a)},r.trigger(l,t)),c[e]}function _(e,t){return(e.msMatchesSelector||e.webkitMatchesSelector||e.matches).call(e,t)}function T(e){return!(k(e)||_(e,":disabled")||e.hasAttribute("contenteditable"))&&(e.hasAttribute("tabindex")||_(e,"input,select,textarea,button,a[href],area[href],iframe"))}function w(e){for(var t=e.getElementsByTagName("*"),n=0;n<t.length;n++)if(T(t[n]))return t[n]}return l={modalElem:I(g),closeElem:I(y),overlayElem:I(v),buildDom:C(E.bind(null,null)),isVisible:function(){return!!(c&&g&&g().isVisible())},show:function(e){return t.trigger(l,e)&&(v().show(),y(),g().show(),i.trigger(l,e)),this},close:C(x),forceClose:C(b),destroy:function(){g().destroy(),v().destroy(),v=g=y=void 0},options:function(t){Object.keys(t).map(function(e){n[e]=t[e]})},afterCreate:C(r.watch),beforeShow:C(t.watch),afterShow:C(i.watch),beforeClose:C(o.watch),afterClose:C(s.watch)},d=l,h=a.bind(null,"focus",!0),d.beforeShow(function(){e=document.activeElement}),d.afterShow(function(){var e;!h()||(e=w(d.modalElem()))&&e.focus()}),d.afterClose(function(){h()&&e&&e.focus(),e=null}),A.watch(function(e){var t,n;h()&&d.isVisible()&&(t=w(d.modalElem()),n=function(e){for(var t=e.getElementsByTagName("*"),n=t.length;n--;)if(T(t[n]))return t[n]}(d.modalElem()),(e.shiftKey?t:n)===document.activeElement&&((e.shiftKey?n:t).focus(),e.preventDefault()))}),u=l,p=a.bind(null,"bodyOverflow",!0),m=new N(document.body),u.beforeShow(function(){f=m.elem.style.overflow,p()&&m.stylize({overflow:"hidden"})}),u.afterClose(function(){m.stylize({overflow:f})}),D.watch(function(){a("escCloses",!0)&&l.isVisible()&&l.close()}),l}})?o.apply(t,i):o)||(e.exports=o)}()},function(e,t,n){"use strict";function o(e,t){for(var n=0;n<t.length;n++){var i=t[n];i.enumerable=i.enumerable||!1,i.configurable=!0,"value"in i&&(i.writable=!0),Object.defineProperty(e,i.key,i)}}n.d(t,"a",function(){return i});var i=function(){function n(e){!function(e){if(!(e instanceof n))throw new TypeError("Cannot call a class as a function")}(this),this.errorTableVisible=e.errorTableVisible,this.onToggleVisibility=e.onToggleVisibility,this.onFocusLine=e.onFocusLine||function(){},this.onChangeHeight=e.onChangeHeight,this.dom={};var t=document.createElement("div");t.className="jsoneditor-validation-errors-container",this.dom.validationErrorsContainer=t;e=document.createElement("div");e.style.display="none",e.className="jsoneditor-additional-errors fadein",e.textContent="Scroll for more ▿",this.dom.additionalErrorsIndication=e,t.appendChild(e);e=document.createElement("span");e.className="jsoneditor-validation-error-icon",e.style.display="none",this.dom.validationErrorIcon=e;e=document.createElement("span");e.className="jsoneditor-validation-error-count",e.style.display="none",this.dom.validationErrorCount=e,this.dom.parseErrorIndication=document.createElement("span"),this.dom.parseErrorIndication.className="jsoneditor-parse-error-icon",this.dom.parseErrorIndication.style.display="none"}var e,t,i;return e=n,(t=[{key:"getErrorTable",value:function(){return this.dom.validationErrorsContainer}},{key:"getErrorCounter",value:function(){return this.dom.validationErrorCount}},{key:"getWarningIcon",value:function(){return this.dom.validationErrorIcon}},{key:"getErrorIcon",value:function(){return this.dom.parseErrorIndication}},{key:"toggleTableVisibility",value:function(){this.errorTableVisible=!this.errorTableVisible,this.onToggleVisibility(this.errorTableVisible)}},{key:"setErrors",value:function(e,a){var t,l,c=this;this.dom.validationErrors&&(this.dom.validationErrors.parentNode.removeChild(this.dom.validationErrors),this.dom.validationErrors=null,this.dom.additionalErrorsIndication.style.display="none"),this.errorTableVisible&&0<e.length?((n=document.createElement("div")).className="jsoneditor-validation-errors",(t=document.createElement("table")).className="jsoneditor-text-errors",n.appendChild(t),l=document.createElement("tbody"),t.appendChild(l),e.forEach(function(t){var e;isNaN(t.line)?!t.dataPath||(o=a.find(function(e){return e.path===t.dataPath}))&&(e=o.line+1):e=t.line;var n=document.createElement("tr");n.className=isNaN(e)?"":"jump-to-line","error"===t.type?n.className+=" parse-error":n.className+=" validation-error";var i=document.createElement("td"),o=document.createElement("button");o.className="jsoneditor-schema-error",i.appendChild(o),n.appendChild(i);var r,s,i=document.createElement("td");i.style="white-space: nowrap;",i.textContent=isNaN(e)?"":"Ln "+e,n.appendChild(i),"string"==typeof t?((r=document.createElement("td")).colSpan=2,(s=document.createElement("pre")).appendChild(document.createTextNode(t)),r.appendChild(s),n.appendChild(r)):((s=document.createElement("td")).appendChild(document.createTextNode(t.dataPath||"")),n.appendChild(s),r=document.createElement("td"),(s=document.createElement("pre")).appendChild(document.createTextNode(t.message)),r.appendChild(s),n.appendChild(r)),n.onclick=function(){c.onFocusLine(e)},l.appendChild(n)}),this.dom.validationErrors=n,this.dom.validationErrorsContainer.appendChild(n),this.dom.additionalErrorsIndication.title=e.length+" errors total",this.dom.validationErrorsContainer.clientHeight<this.dom.validationErrorsContainer.scrollHeight?(this.dom.additionalErrorsIndication.style.display="block",this.dom.validationErrorsContainer.onscroll=function(){c.dom.additionalErrorsIndication.style.display=0<c.dom.validationErrorsContainer.clientHeight&&0===c.dom.validationErrorsContainer.scrollTop?"block":"none"}):this.dom.validationErrorsContainer.onscroll=void 0,n=this.dom.validationErrorsContainer.clientHeight+(this.dom.statusBar?this.dom.statusBar.clientHeight:0),this.onChangeHeight(n)):this.onChangeHeight(0);var n=e.filter(function(e){return"error"!==e.type}).length;0<n?(this.dom.validationErrorCount.style.display="inline",this.dom.validationErrorCount.innerText=n,this.dom.validationErrorCount.onclick=this.toggleTableVisibility.bind(this),this.dom.validationErrorIcon.style.display="inline",this.dom.validationErrorIcon.title=n+" schema validation error(s) found",this.dom.validationErrorIcon.onclick=this.toggleTableVisibility.bind(this)):(this.dom.validationErrorCount.style.display="none",this.dom.validationErrorIcon.style.display="none"),e.some(function(e){return"error"===e.type})?(e=e[0].line,this.dom.parseErrorIndication.style.display="block",this.dom.parseErrorIndication.title=isNaN(e)?"parse error - check that the json is valid":"parse error on line "+e,this.dom.parseErrorIndication.onclick=this.toggleTableVisibility.bind(this)):this.dom.parseErrorIndication.style.display="none"}}])&&o(e.prototype,t),i&&o(e,i),n}()},function(e,t,n){var i;if(window.ace)i=window.ace;else try{i=n(!function(){var e=new Error("Cannot find module 'ace-builds/src-noconflict/ace'");throw e.code="MODULE_NOT_FOUND",e}()),n(!function(){var e=new Error("Cannot find module 'ace-builds/src-noconflict/mode-json'");throw e.code="MODULE_NOT_FOUND",e}()),n(!function(){var e=new Error("Cannot find module 'ace-builds/src-noconflict/ext-searchbox'");throw e.code="MODULE_NOT_FOUND",e}());var o=n(!function(){var e=new Error("Cannot find module '../generated/worker-json-data-url'");throw e.code="MODULE_NOT_FOUND",e}());i.config.setModuleUrl("ace/mode/json_worker",o)}catch(e){}e.exports=i},function(e,t,n){"use strict";n.r(t),n.d(t,"textModeMixins",function(){return l});var t=n(7),i=n.n(t),t=n(16),h=n.n(t),s=n(2),u=n(15),p=n(8),f=n(1),m=n(4),g=n(9),o=n(5),a=n(6),v=n(22),y=n(0);function b(e){return(b="function"==typeof Symbol&&"symbol"==typeof Symbol.iterator?function(e){return typeof e}:function(e){return e&&"function"==typeof Symbol&&e.constructor===Symbol&&e!==Symbol.prototype?"symbol":typeof e})(e)}var n={},x="ace/theme/jsoneditor";function r(){try{this.format()}catch(e){}}n.create=function(e){var t=this,n=1<arguments.length&&void 0!==arguments[1]?arguments[1]:{};void 0===n.statusBar&&(n.statusBar=!0),n.mainMenuBar=!1!==n.mainMenuBar,n.enableSort=!1!==n.enableSort,n.enableTransform=!1!==n.enableTransform,n.createQuery=n.createQuery||m.a,n.executeQuery=n.executeQuery||m.b,"number"==typeof(this.options=n).indentation?this.indentation=Number(n.indentation):this.indentation=2,Object(f.b)(this.options.languages),Object(f.a)(this.options.language);var i=n.ace||h.a;this.mode="code"===n.mode?"code":"text","code"===this.mode&&void 0===i&&(this.mode="text",console.warn("Failed to load Ace editor, falling back to plain text mode. Please use a JSONEditor bundle including Ace, or pass Ace as via the configuration option `ace`.")),this.theme=n.theme||x,this.theme===x&&i&&Object(v.tryRequireThemeJsonEditor)(),n.onTextSelectionChange&&this.onTextSelectionChange(n.onTextSelectionChange);var o=this;this.container=e,this.dom={},this.aceEditor=void 0,this.textarea=void 0,this.validateSchema=null,this.annotations=[],this.lastSchemaErrors=void 0,this._debouncedValidate=Object(y.debounce)(this.validate.bind(this),this.DEBOUNCE_INTERVAL),this.width=e.clientWidth,this.height=e.clientHeight,this.frame=document.createElement("div"),this.frame.className="jsoneditor jsoneditor-mode-"+this.options.mode,this.frame.onclick=function(e){e.preventDefault()},this.frame.onkeydown=function(e){o._onKeyDown(e)};var r,s,e={target:this.frame,onFocus:this.options.onFocus||null,onBlur:this.options.onBlur||null};this.frameFocusTracker=new p.a(e),this.content=document.createElement("div"),this.content.className="jsoneditor-outer",this.options.mainMenuBar&&(Object(y.addClassName)(this.content,"has-main-menu-bar"),this.menu=document.createElement("div"),this.menu.className="jsoneditor-menu",this.frame.appendChild(this.menu),(e=document.createElement("button")).type="button",e.className="jsoneditor-format",e.title=Object(f.c)("formatTitle"),this.menu.appendChild(e),e.onclick=function(){try{o.format(),o._onChange()}catch(e){o._onError(e)}},(e=document.createElement("button")).type="button",e.className="jsoneditor-compact",e.title=Object(f.c)("compactTitle"),this.menu.appendChild(e),e.onclick=function(){try{o.compact(),o._onChange()}catch(e){o._onError(e)}},this.options.enableSort&&((e=document.createElement("button")).type="button",e.className="jsoneditor-sort",e.title=Object(f.c)("sortTitleShort"),e.onclick=function(){o._showSortModal()},this.menu.appendChild(e)),this.options.enableTransform&&((r=document.createElement("button")).type="button",r.title=Object(f.c)("transformTitleShort"),r.className="jsoneditor-transform",r.onclick=function(){o._showTransformModal()},this.menu.appendChild(r)),(r=document.createElement("button")).type="button",r.className="jsoneditor-repair",r.title=Object(f.c)("repairTitle"),this.menu.appendChild(r),r.onclick=function(){try{o.repair(),o._onChange()}catch(e){o._onError(e)}},"code"===this.mode&&((d=document.createElement("button")).type="button",d.className="jsoneditor-undo jsoneditor-separator",d.title=Object(f.c)("undo"),d.onclick=function(){t.aceEditor.getSession().getUndoManager().undo()},this.menu.appendChild(d),this.dom.undo=d,(d=document.createElement("button")).type="button",d.className="jsoneditor-redo",d.title=Object(f.c)("redo"),d.onclick=function(){t.aceEditor.getSession().getUndoManager().redo()},this.menu.appendChild(d),this.dom.redo=d),this.options&&this.options.modes&&this.options.modes.length&&(this.modeSwitcher=new g.a(this.menu,this.options.modes,this.options.mode,function(e){o.setMode(e),o.modeSwitcher.focus()})),"code"===this.mode&&((s=document.createElement("a")).appendChild(document.createTextNode("powered by ace")),s.href="https://ace.c9.io/",s.target="_blank",s.className="jsoneditor-poweredBy",s.onclick=function(){window.open(s.href,s.target,"noopener")},this.menu.appendChild(s)));var a,l,c,d=this.options.onEditable&&b("function"===this.options.onEditable)&&!this.options.onEditable({});this.frame.appendChild(this.content),this.container.appendChild(this.frame),"code"===this.mode?(this.editorDom=document.createElement("div"),this.editorDom.style.height="100%",this.editorDom.style.width="100%",this.content.appendChild(this.editorDom),i=(l=i.edit(this.editorDom)).getSession(),l.$blockScrolling=1/0,l.setTheme(this.theme),l.setOptions({readOnly:d}),l.setShowPrintMargin(!1),l.setFontSize("13px"),i.setMode("ace/mode/json"),i.setTabSize(this.indentation),i.setUseSoftTabs(!0),i.setUseWrapMode(!0),a=i.setAnnotations,i.setAnnotations=function(e){a.call(this,e&&e.length?e:o.annotations)},l.commands.bindKey("Ctrl-L",null),l.commands.bindKey("Command-L",null),l.commands.bindKey("Ctrl-\\",null),l.commands.bindKey("Command-\\",null),l.commands.bindKey("Ctrl-Shift-\\",null),l.commands.bindKey("Command-Shift-\\",null),(this.aceEditor=l).on("change",this._onChange.bind(this)),l.on("changeSelection",this._onSelect.bind(this))):((c=document.createElement("textarea")).className="jsoneditor-text",c.spellcheck=!1,this.content.appendChild(c),this.textarea=c,this.textarea.readOnly=d,null===this.textarea.oninput?this.textarea.oninput=this._onChange.bind(this):this.textarea.onchange=this._onChange.bind(this),c.onselect=this._onSelect.bind(this),c.onmousedown=this._onMouseDown.bind(this),c.onblur=this._onBlur.bind(this)),this._updateHistoryButtons(),this.errorTable=new u.a({errorTableVisible:"text"===this.mode,onToggleVisibility:function(){o.validate()},onFocusLine:function(e){o.isFocused=!0,isNaN(e)||o.setTextSelection({row:e,column:1},{row:e,column:1e3})},onChangeHeight:function(e){e=e+(o.dom.statusBar?o.dom.statusBar.clientHeight:0)+1;o.content.style.marginBottom=-e+"px",o.content.style.paddingBottom=e+"px"}}),this.frame.appendChild(this.errorTable.getErrorTable()),n.statusBar&&(Object(y.addClassName)(this.content,"has-status-bar"),this.curserInfoElements={},l=document.createElement("div"),(this.dom.statusBar=l).className="jsoneditor-statusbar",this.frame.appendChild(l),(d=document.createElement("span")).className="jsoneditor-curserinfo-label",d.innerText="Ln:",(c=document.createElement("span")).className="jsoneditor-curserinfo-val",c.innerText="1",l.appendChild(d),l.appendChild(c),(n=document.createElement("span")).className="jsoneditor-curserinfo-label",n.innerText="Col:",(d=document.createElement("span")).className="jsoneditor-curserinfo-val",d.innerText="1",l.appendChild(n),l.appendChild(d),this.curserInfoElements.colVal=d,this.curserInfoElements.lnVal=c,(d=document.createElement("span")).className="jsoneditor-curserinfo-label",d.innerText="characters selected",d.style.display="none",(c=document.createElement("span")).className="jsoneditor-curserinfo-count",c.innerText="0",c.style.display="none",this.curserInfoElements.countLabel=d,this.curserInfoElements.countVal=c,l.appendChild(c),l.appendChild(d),l.appendChild(this.errorTable.getErrorCounter()),l.appendChild(this.errorTable.getWarningIcon()),l.appendChild(this.errorTable.getErrorIcon())),this.setSchema(this.options.schema,this.options.schemaRefs)},n._onChange=function(){var e=this;if(!this.onChangeDisabled){if(setTimeout(function(){return e._updateHistoryButtons()}),this._debouncedValidate(),this.options.onChange)try{this.options.onChange()}catch(e){console.error("Error in onChange callback: ",e)}if(this.options.onChangeText)try{this.options.onChangeText(this.getText())}catch(e){console.error("Error in onChangeText callback: ",e)}}},n._updateHistoryButtons=function(){var e;this.aceEditor&&this.dom.undo&&this.dom.redo&&((e=this.aceEditor.getSession().getUndoManager())&&e.hasUndo&&e.hasRedo&&(this.dom.undo.disabled=!e.hasUndo(),this.dom.redo.disabled=!e.hasRedo()))},n._showSortModal=function(){var n=this,e=this.options.modalAnchor||s.a,i=this.get();Object(o.showSortModal)(e,i,function(e){var t;Array.isArray(i)&&(t=Object(y.sort)(i,e.path,e.direction),n.sortedBy=e,n.update(t)),Object(y.isObject)(i)&&(t=Object(y.sortObjectKeys)(i,e.direction),n.sortedBy=e,n.update(t))},n.sortedBy)},n._showTransformModal=function(){var t=this,e=this.options,n=e.modalAnchor,i=e.createQuery,o=e.executeQuery,e=e.queryDescription,r=this.get();Object(a.showTransformModal)({container:n||s.a,json:r,queryDescription:e,createQuery:i,executeQuery:o,onTransform:function(e){e=o(r,e);t.update(e)}})},n._onSelect=function(){this._updateCursorInfo(),this._emitSelectionChange()},n._onKeyDown=function(e){var t=!1;220===(e.which||e.keyCode)&&e.ctrlKey&&(e.shiftKey?this.compact():this.format(),this._onChange(),t=!0),t&&(e.preventDefault(),e.stopPropagation()),this._updateCursorInfo(),this._emitSelectionChange()},n._onMouseDown=function(){this._updateCursorInfo(),this._emitSelectionChange()},n._onBlur=function(){var e=this;setTimeout(function(){e.isFocused||(e._updateCursorInfo(),e._emitSelectionChange()),e.isFocused=!1})},n._updateCursorInfo=function(){var e,t,n,i,o,r=this;function s(){r.curserInfoElements.countVal.innerText!==o&&(r.curserInfoElements.countVal.innerText=o,r.curserInfoElements.countVal.style.display=o?"inline":"none",r.curserInfoElements.countLabel.style.display=o?"inline":"none"),r.curserInfoElements.lnVal.innerText=n,r.curserInfoElements.colVal.innerText=i}this.textarea?setTimeout(function(){var e=Object(y.getInputSelection)(r.textarea);e.startIndex!==e.endIndex&&(o=e.endIndex-e.startIndex),i=o&&r.cursorInfo&&r.cursorInfo.line===e.end.row&&r.cursorInfo.column===e.end.column?(n=e.start.row,e.start.column):(n=e.end.row,e.end.column),r.cursorInfo={line:n,column:i,count:o},r.options.statusBar&&s()},0):this.aceEditor&&this.curserInfoElements&&(e=this.aceEditor.getCursorPosition(),t=this.aceEditor.getSelectedText(),n=e.row+1,i=e.column+1,o=t.length,r.cursorInfo={line:n,column:i,count:o},this.options.statusBar&&s())},n._emitSelectionChange=function(){var e;this._selectionChangedHandler&&(e=this.getTextSelection(),this._selectionChangedHandler(e.start,e.end,e.text))},n._refreshAnnotations=function(){var e,t=this.aceEditor&&this.aceEditor.getSession();t&&(e=t.getAnnotations().filter(function(e){return"error"===e.type}),t.setAnnotations(e))},n.destroy=function(){this.aceEditor&&(this.aceEditor.destroy(),this.aceEditor=null),this.frame&&this.container&&this.frame.parentNode===this.container&&this.container.removeChild(this.frame),this.modeSwitcher&&(this.modeSwitcher.destroy(),this.modeSwitcher=null),this.textarea=null,this._debouncedValidate=null,this.frameFocusTracker.destroy()},n.compact=function(){var e=this.get(),e=JSON.stringify(e);this.updateText(e)},n.format=function(){var e=this.get(),e=JSON.stringify(e,null,this.indentation);this.updateText(e)},n.repair=function(){var e=this.getText();try{var t=i()(e);this.updateText(t)}catch(e){}},n.focus=function(){this.textarea&&this.textarea.focus(),this.aceEditor&&this.aceEditor.focus()},n.resize=function(){this.aceEditor&&this.aceEditor.resize(!1)},n.set=function(e){this.setText(JSON.stringify(e,null,this.indentation))},n.update=function(e){this.updateText(JSON.stringify(e,null,this.indentation))},n.get=function(){var e=this.getText();return Object(y.parse)(e)},n.getText=function(){return this.textarea?this.textarea.value:this.aceEditor?this.aceEditor.getValue():""},n._setText=function(e,t){var n,i=this,e=!0===this.options.escapeUnicode?Object(y.escapeUnicodeChars)(e):e;this.textarea&&(this.textarea.value=e),this.aceEditor&&(this.onChangeDisabled=!0,this.aceEditor.setValue(e,-1),this.onChangeDisabled=!1,t&&(n=this,setTimeout(function(){n.aceEditor&&n.aceEditor.session.getUndoManager().reset()})),setTimeout(function(){return i._updateHistoryButtons()})),this._debouncedValidate()},n.setText=function(e){this._setText(e,!0)},n.updateText=function(e){this.getText()!==e&&this._setText(e,!1)},n.validate=function(){var t,n,i=this,o=[],r=[];try{var e=this.get();this.validateSchema&&(this.validateSchema(e)||(o=this.validateSchema.errors.map(function(e){return e.type="validation",Object(y.improveSchemaError)(e)}))),this.validationSequence=(this.validationSequence||0)+1;var s=this,a=this.validationSequence;(function(e,t){if(!t)return Promise.resolve([]);try{var n=t(e);return(Object(y.isPromise)(n)?n:Promise.resolve(n)).then(function(e){return Array.isArray(e)?e.filter(function(e){var t=Object(y.isValidValidationError)(e);return t||console.warn('Ignoring a custom validation error with invalid structure. Expected structure: {path: [...], message: "..."}. Actual error:',e),t}).map(function(e){return{dataPath:Object(y.stringifyPath)(e.path),message:e.message,type:"customValidation"}}):[]})}catch(e){return Promise.reject(e)}})(e,this.options.onValidate).then(function(e){a===s.validationSequence&&(e=o.concat(r).concat(e),s._renderErrors(e),"function"==typeof i.options.onValidationError&&(Object(y.isValidationErrorChanged)(e,i.lastSchemaErrors)&&i.options.onValidationError.call(i,e),i.lastSchemaErrors=e))}).catch(function(e){console.error("Custom validation function did throw an error",e)})}catch(e){this.getText()&&((t=/\w*line\s*(\d+)\w*/g.exec(e.message))&&(n=+t[1]),r=[{type:"error",message:e.message.replace(/\n/g,"<br>"),line:n}]),this._renderErrors(r),"function"==typeof this.options.onValidationError&&(Object(y.isValidationErrorChanged)(r,this.lastSchemaErrors)&&this.options.onValidationError.call(this,r),this.lastSchemaErrors=r)}},n._renderErrors=function(i){var e=this.getText(),t=[];i.reduce(function(e,t){return"string"==typeof t.dataPath&&-1===e.indexOf(t.dataPath)&&e.push(t.dataPath),e},t);t=Object(y.getPositionForPath)(e,t);this.aceEditor&&(this.annotations=t.map(function(t){var e=i.filter(function(e){return e.dataPath===t.path}),n=e.map(function(e){return e.message}).join("\n");return n?{row:t.line,column:t.column,text:"Schema validation error"+(1!==e.length?"s":"")+": \n"+n,type:"warning",source:"jsoneditor"}:{}}),this._refreshAnnotations()),this.errorTable.setErrors(i,t),this.aceEditor&&this.aceEditor.resize(!1)},n.getTextSelection=function(){var e={};if(this.textarea){var t=Object(y.getInputSelection)(this.textarea);return this.cursorInfo&&this.cursorInfo.line===t.end.row&&this.cursorInfo.column===t.end.column?(e.start=t.end,e.end=t.start):e=t,{start:e.start,end:e.end,text:this.textarea.value.substring(t.startIndex,t.endIndex)}}if(this.aceEditor){var n=this.aceEditor.getSelection(),i=this.aceEditor.getSelectedText(),t=n.getRange(),n=n.getSelectionLead();return n.row===t.end.row&&n.column===t.end.column?e=t:(e.start=t.end,e.end=t.start),{start:{row:e.start.row+1,column:e.start.column+1},end:{row:e.end.row+1,column:e.end.column+1},text:i}}},n.onTextSelectionChange=function(e){"function"==typeof e&&(this._selectionChangedHandler=Object(y.debounce)(e,this.DEBOUNCE_INTERVAL))},n.setTextSelection=function(e,t){var n,i,o;e&&t&&(this.textarea?(n=Object(y.getIndexForPosition)(this.textarea,e.row,e.column),i=Object(y.getIndexForPosition)(this.textarea,t.row,t.column),-1<n&&-1<i&&(this.textarea.setSelectionRange?(this.textarea.focus(),this.textarea.setSelectionRange(n,i)):this.textarea.createTextRange&&((o=this.textarea.createTextRange()).collapse(!0),o.moveEnd("character",i),o.moveStart("character",n),o.select()),o=(this.textarea.value.match(/\n/g)||[]).length+1,o=this.textarea.scrollHeight/o,o=e.row*o,this.textarea.scrollTop=o>this.textarea.clientHeight?o-this.textarea.clientHeight/2:0)):this.aceEditor&&(t={start:{row:e.row-1,column:e.column-1},end:{row:t.row-1,column:t.column-1}},this.aceEditor.selection.setRange(t),this.aceEditor.scrollToLine(e.row-1,!0)))};var l=[{mode:"text",mixin:n,data:"text",load:r},{mode:"code",mixin:n,data:"text",load:r}]},function(e,t,n){var i,i=((i={trace:function(){},yy:{},symbols_:{error:2,JSONString:3,STRING:4,JSONNumber:5,NUMBER:6,JSONNullLiteral:7,NULL:8,JSONBooleanLiteral:9,TRUE:10,FALSE:11,JSONText:12,JSONValue:13,EOF:14,JSONObject:15,JSONArray:16,"{":17,"}":18,JSONMemberList:19,JSONMember:20,":":21,",":22,"[":23,"]":24,JSONElementList:25,$accept:0,$end:1},terminals_:{2:"error",4:"STRING",6:"NUMBER",8:"NULL",10:"TRUE",11:"FALSE",14:"EOF",17:"{",18:"}",21:":",22:",",23:"[",24:"]"},productions_:[0,[3,1],[5,1],[7,1],[9,1],[9,1],[12,2],[13,1],[13,1],[13,1],[13,1],[13,1],[13,1],[15,2],[15,3],[20,3],[19,1],[19,3],[16,2],[16,3],[25,1],[25,3]],performAction:function(e,t,n,i,o,r){var s=r.length-1;switch(o){case 1:this.$=e.replace(/\\(\\|")/g,"$1").replace(/\\n/g,"\n").replace(/\\r/g,"\r").replace(/\\t/g,"\t").replace(/\\v/g,"\v").replace(/\\f/g,"\f").replace(/\\b/g,"\b");break;case 2:this.$=Number(e);break;case 3:this.$=null;break;case 4:this.$=!0;break;case 5:this.$=!1;break;case 6:return this.$=r[s-1];case 13:this.$={};break;case 14:this.$=r[s-1];break;case 15:this.$=[r[s-2],r[s]];break;case 16:this.$={},this.$[r[s][0]]=r[s][1];break;case 17:this.$=r[s-2],r[s-2][r[s][0]]=r[s][1];break;case 18:this.$=[];break;case 19:this.$=r[s-1];break;case 20:this.$=[r[s]];break;case 21:this.$=r[s-2],r[s-2].push(r[s])}},table:[{3:5,4:[1,12],5:6,6:[1,13],7:3,8:[1,9],9:4,10:[1,10],11:[1,11],12:1,13:2,15:7,16:8,17:[1,14],23:[1,15]},{1:[3]},{14:[1,16]},{14:[2,7],18:[2,7],22:[2,7],24:[2,7]},{14:[2,8],18:[2,8],22:[2,8],24:[2,8]},{14:[2,9],18:[2,9],22:[2,9],24:[2,9]},{14:[2,10],18:[2,10],22:[2,10],24:[2,10]},{14:[2,11],18:[2,11],22:[2,11],24:[2,11]},{14:[2,12],18:[2,12],22:[2,12],24:[2,12]},{14:[2,3],18:[2,3],22:[2,3],24:[2,3]},{14:[2,4],18:[2,4],22:[2,4],24:[2,4]},{14:[2,5],18:[2,5],22:[2,5],24:[2,5]},{14:[2,1],18:[2,1],21:[2,1],22:[2,1],24:[2,1]},{14:[2,2],18:[2,2],22:[2,2],24:[2,2]},{3:20,4:[1,12],18:[1,17],19:18,20:19},{3:5,4:[1,12],5:6,6:[1,13],7:3,8:[1,9],9:4,10:[1,10],11:[1,11],13:23,15:7,16:8,17:[1,14],23:[1,15],24:[1,21],25:22},{1:[2,6]},{14:[2,13],18:[2,13],22:[2,13],24:[2,13]},{18:[1,24],22:[1,25]},{18:[2,16],22:[2,16]},{21:[1,26]},{14:[2,18],18:[2,18],22:[2,18],24:[2,18]},{22:[1,28],24:[1,27]},{22:[2,20],24:[2,20]},{14:[2,14],18:[2,14],22:[2,14],24:[2,14]},{3:20,4:[1,12],20:29},{3:5,4:[1,12],5:6,6:[1,13],7:3,8:[1,9],9:4,10:[1,10],11:[1,11],13:30,15:7,16:8,17:[1,14],23:[1,15]},{14:[2,19],18:[2,19],22:[2,19],24:[2,19]},{3:5,4:[1,12],5:6,6:[1,13],7:3,8:[1,9],9:4,10:[1,10],11:[1,11],13:31,15:7,16:8,17:[1,14],23:[1,15]},{18:[2,17],22:[2,17]},{18:[2,15],22:[2,15]},{22:[2,21],24:[2,21]}],defaultActions:{16:[2,6]},parseError:function(e){throw new Error(e)},parse:function(e){var t=this,n=[0],i=[null],o=[],r=this.table,s="",a=0,l=0,c=0;this.lexer.setInput(e),this.lexer.yy=this.yy,this.yy.lexer=this.lexer,void 0===this.lexer.yylloc&&(this.lexer.yylloc={});var d=this.lexer.yylloc;function h(){var e=t.lexer.lex()||1;return"number"!=typeof e&&(e=t.symbols_[e]||e),e}o.push(d),"function"==typeof this.yy.parseError&&(this.parseError=this.yy.parseError);for(var u,p,f,m,g,v,y,b,x,C={};;){if(f=n[n.length-1],void 0===(m=this.defaultActions[f]||(null==u&&(u=h()),r[f]&&r[f][u]))||!m.length||!m[0]){if(!c){for(v in b=[],r[f])this.terminals_[v]&&2<v&&b.push("'"+this.terminals_[v]+"'");var E="",E=this.lexer.showPosition?"Parse error on line "+(a+1)+":\n"+this.lexer.showPosition()+"\nExpecting "+b.join(", ")+", got '"+this.terminals_[u]+"'":"Parse error on line "+(a+1)+": Unexpected "+(1==u?"end of input":"'"+(this.terminals_[u]||u)+"'");this.parseError(E,{text:this.lexer.match,token:this.terminals_[u]||u,line:this.lexer.yylineno,loc:d,expected:b})}if(3==c){if(1==u)throw new Error(E||"Parsing halted.");l=this.lexer.yyleng,s=this.lexer.yytext,a=this.lexer.yylineno,d=this.lexer.yylloc,u=h()}for(;!(2..toString()in r[f]);){if(0==f)throw new Error(E||"Parsing halted.");x=1,n.length=n.length-2*x,i.length=i.length-x,o.length=o.length-x,f=n[n.length-1]}p=u,u=2,m=r[f=n[n.length-1]]&&r[f][2],c=3}if(m[0]instanceof Array&&1<m.length)throw new Error("Parse Error: multiple actions possible at state: "+f+", token: "+u);switch(m[0]){case 1:n.push(u),i.push(this.lexer.yytext),o.push(this.lexer.yylloc),n.push(m[1]),u=null,p?(u=p,p=null):(l=this.lexer.yyleng,s=this.lexer.yytext,a=this.lexer.yylineno,d=this.lexer.yylloc,0<c&&c--);break;case 2:if(y=this.productions_[m[1]][1],C.$=i[i.length-y],C._$={first_line:o[o.length-(y||1)].first_line,last_line:o[o.length-1].last_line,first_column:o[o.length-(y||1)].first_column,last_column:o[o.length-1].last_column},void 0!==(g=this.performAction.call(C,s,l,a,this.yy,m[1],i,o)))return g;y&&(n=n.slice(0,-1*y*2),i=i.slice(0,-1*y),o=o.slice(0,-1*y)),n.push(this.productions_[m[1]][0]),i.push(C.$),o.push(C._$),y=r[n[n.length-2]][n[n.length-1]],n.push(y);break;case 3:return!0}}return!0}}).lexer={EOF:1,parseError:function(e,t){if(!this.yy.parseError)throw new Error(e);this.yy.parseError(e,t)},setInput:function(e){return this._input=e,this._more=this._less=this.done=!1,this.yylineno=this.yyleng=0,this.yytext=this.matched=this.match="",this.conditionStack=["INITIAL"],this.yylloc={first_line:1,first_column:0,last_line:1,last_column:0},this},input:function(){var e=this._input[0];return this.yytext+=e,this.yyleng++,this.match+=e,this.matched+=e,e.match(/\n/)&&this.yylineno++,this._input=this._input.slice(1),e},unput:function(e){return this._input=e+this._input,this},more:function(){return this._more=!0,this},less:function(e){this._input=this.match.slice(e)+this._input},pastInput:function(){var e=this.matched.substr(0,this.matched.length-this.match.length);return(20<e.length?"...":"")+e.substr(-20).replace(/\n/g,"")},upcomingInput:function(){var e=this.match;return e.length<20&&(e+=this._input.substr(0,20-e.length)),(e.substr(0,20)+(20<e.length?"...":"")).replace(/\n/g,"")},showPosition:function(){var e=this.pastInput(),t=new Array(e.length+1).join("-");return e+this.upcomingInput()+"\n"+t+"^"},next:function(){if(this.done)return this.EOF;var e,t,n,i;this._input||(this.done=!0),this._more||(this.yytext="",this.match="");for(var o=this._currentRules(),r=0;r<o.length&&(!(t=this._input.match(this.rules[o[r]]))||e&&!(t[0].length>e[0].length)||(e=t,n=r,this.options.flex));r++);return e?((i=e[0].match(/\n.*/g))&&(this.yylineno+=i.length),this.yylloc={first_line:this.yylloc.last_line,last_line:this.yylineno+1,first_column:this.yylloc.last_column,last_column:i?i[i.length-1].length-1:this.yylloc.last_column+e[0].length},this.yytext+=e[0],this.match+=e[0],this.yyleng=this.yytext.length,this._more=!1,this._input=this._input.slice(e[0].length),this.matched+=e[0],i=this.performAction.call(this,this.yy,this,o[n],this.conditionStack[this.conditionStack.length-1]),this.done&&this._input&&(this.done=!1),i||void 0):""===this._input?this.EOF:void this.parseError("Lexical error on line "+(this.yylineno+1
)+". Unrecognized text.\n"+this.showPosition(),{text:"",token:null,line:this.yylineno})},lex:function(){var e=this.next();return void 0!==e?e:this.lex()},begin:function(e){this.conditionStack.push(e)},popState:function(){return this.conditionStack.pop()},_currentRules:function(){return this.conditions[this.conditionStack[this.conditionStack.length-1]].rules},topState:function(){return this.conditionStack[this.conditionStack.length-2]},pushState:function(e){this.begin(e)},options:{},performAction:function(e,t,n){switch(n){case 0:break;case 1:return 6;case 2:return t.yytext=t.yytext.substr(1,t.yyleng-2),4;case 3:return 17;case 4:return 18;case 5:return 23;case 6:return 24;case 7:return 22;case 8:return 21;case 9:return 10;case 10:return 11;case 11:return 8;case 12:return 14;case 13:return"INVALID"}},rules:[/^(?:\s+)/,/^(?:(-?([0-9]|[1-9][0-9]+))(\.[0-9]+)?([eE][-+]?[0-9]+)?\b)/,/^(?:"(?:\\[\\"bfnrt/]|\\u[a-fA-F0-9]{4}|[^\\\0-\x09\x0a-\x1f"])*")/,/^(?:\{)/,/^(?:\})/,/^(?:\[)/,/^(?:\])/,/^(?:,)/,/^(?::)/,/^(?:true\b)/,/^(?:false\b)/,/^(?:null\b)/,/^(?:$)/,/^(?:.)/],conditions:{INITIAL:{rules:[0,1,2,3,4,5,6,7,8,9,10,11,12,13],inclusive:!0}}},i);t.parser=i,t.parse=i.parse.bind(i)},function(e,t){function n(e){"remove"in e||Object.defineProperty(e,"remove",{configurable:!0,enumerable:!0,writable:!0,value:function(){void 0!==this.parentNode&&this.parentNode.removeChild(this)}})}"undefined"!=typeof Element&&(void 0!==window.Element&&n(window.Element.prototype),void 0!==window.CharacterData&&n(window.CharacterData.prototype),void 0!==window.DocumentType&&n(window.DocumentType.prototype)),Array.prototype.findIndex||Object.defineProperty(Array.prototype,"findIndex",{value:function(e){for(var t=0;t<this.length;t++){var n=this[t];if(e.call(this,n,t,this))return t}return-1},configurable:!0,writable:!0}),Array.prototype.find||Object.defineProperty(Array.prototype,"find",{value:function(e){e=this.findIndex(e);return this[e]},configurable:!0,writable:!0}),String.prototype.trim||(String.prototype.trim=function(){return this.replace(/^[\s\uFEFF\xA0]+|[\s\uFEFF\xA0]+$/g,"")})},function(e,t,n){"use strict";var C={b:"\b",f:"\f",n:"\n",r:"\r",t:"\t",'"':'"',"/":"/","\\":"\\"},E="a".charCodeAt();t.parse=function(o,e,t){var i={},n=0,r=0,s=0,a=t&&t.bigint&&"undefined"!=typeof BigInt;return{data:l("",!0),pointers:i};function l(e,t){var n;c(),m(e,"value");var i=u();switch(i){case"t":h("rue"),n=!0;break;case"f":h("alse"),n=!1;break;case"n":h("ull"),n=null;break;case'"':n=d();break;case"[":n=function(e){c();var t=[],n=0;if("]"==u())return t;p();for(;;){var i=e+"/"+n;t.push(l(i)),c();i=u();if("]"==i)break;","!=i&&b(),c(),n++}return t}(e);break;case"{":n=function(e){c();var t={};if("}"==u())return t;p();for(;;){var n=v();'"'!=u()&&b();var i=d(),o=e+"/"+_(i);g(o,"key",n),m(o,"keyEnd"),c(),":"!=u()&&b(),c(),t[i]=l(o),c();o=u();if("}"==o)break;","!=o&&b(),c()}return t}(e);break;default:p(),0<="-0123456789".indexOf(i)?n=function(){var e="",t=!0;"-"==o[s]&&(e+=u());e+=("0"==o[s]?u:f)(),"."==o[s]&&(e+=u()+f(),t=!1);"e"!=o[s]&&"E"!=o[s]||(e+=u(),"+"!=o[s]&&"-"!=o[s]||(e+=u()),e+=f(),t=!1);var n=+e;return a&&t&&(n>Number.MAX_SAFE_INTEGER||n<Number.MIN_SAFE_INTEGER)?BigInt(e):n}():y()}return m(e,"valueEnd"),c(),t&&s<o.length&&y(),n}function c(){e:for(;s<o.length;){switch(o[s]){case" ":r++;break;case"\t":r+=4;break;case"\r":r=0;break;case"\n":r=0,n++;break;default:break e}s++}}function d(){for(var e,t="";'"'!=(e=u());)"\\"==e?(e=u())in C?t+=C[e]:"u"==e?t+=function(){var e=4,t=0;for(;e--;){t<<=4;var n=u().toLowerCase();"a"<=n&&n<="f"?t+=n.charCodeAt()-E+10:"0"<=n&&n<="9"?t+=+n:b()}return String.fromCharCode(t)}():b():t+=e;return t}function h(e){for(var t=0;t<e.length;t++)u()!==e[t]&&b()}function u(){x();var e=o[s];return s++,r++,e}function p(){s--,r--}function f(){for(var e="";"0"<=o[s]&&o[s]<="9";)e+=u();if(e.length)return e;x(),y()}function m(e,t){g(e,t,v())}function g(e,t,n){i[e]=i[e]||{},i[e][t]=n}function v(){return{line:n,column:r,pos:s}}function y(){throw new SyntaxError("Unexpected token "+o[s]+" in JSON at position "+s)}function b(){p(),y()}function x(){if(s>=o.length)throw new SyntaxError("Unexpected end of JSON input")}},t.stringify=function(e,t,n){if(b(e)){var i=0;switch(typeof(u="object"==typeof n?n.space:n)){case"number":var o=10<u?10:u<0?0:Math.floor(u),u=o&&y(o," "),r=o,s=o;break;case"string":u=u.slice(0,10);for(var a=s=r=0;a<u.length;a++){switch(u[a]){case" ":s++;break;case"\t":s+=4;break;case"\r":s=0;break;case"\n":s=0,i++;break;default:throw new Error("whitespace characters not allowed in JSON")}r++}break;default:u=void 0}var l="",c={},d=0,h=0,p=0,f=n&&n.es6&&"function"==typeof Map;return function l(c,d,h){v(h,"value");switch(typeof c){case"number":case"bigint":case"boolean":m(""+c);break;case"string":m(x(c));break;case"object":null===c?m("null"):"function"==typeof c.toJSON?m(x(c.toJSON())):Array.isArray(c)?e():f?c.constructor.BYTES_PER_ELEMENT?e():c instanceof Map?n():c instanceof Set?n(!0):t():t()}v(h,"valueEnd");function e(){if(c.length){m("[");for(var e=d+1,t=0;t<c.length;t++){t&&m(","),g(e);var n=b(c[t])?c[t]:null,i=h+"/"+t;l(n,e,i)}g(d),m("]")}else m("[]")}function t(){var e=Object.keys(c);if(e.length){m("{");for(var t=d+1,n=0;n<e.length;n++){var i,o=e[n],r=c[o];b(r)&&(n&&m(","),i=h+"/"+_(o),g(t),v(i,"key"),m(x(o)),v(i,"keyEnd"),m(":"),u&&m(" "),l(r,t,i))}g(d),m("}")}else m("{}")}function n(e){if(c.size){m("{");for(var t=d+1,n=!0,i=c.entries(),o=i.next();!o.done;){var r=o.value,s=r[0],a=!!e||r[1];b(a)&&(n||m(","),n=!1,r=h+"/"+_(s),g(t),v(r,"key"),m(x(s)),v(r,"keyEnd"),m(":"),u&&m(" "),l(a,t,r)),o=i.next()}g(d),m("}")}else m("{}")}}(e,0,""),{json:l,pointers:c}}function m(e){h+=e.length,p+=e.length,l+=e}function g(e){if(u){for(l+="\n"+y(e,u),d++,h=0;e--;)i?(d+=i,h=s):h+=s,p+=r;p+=1}}function v(e,t){c[e]=c[e]||{},c[e][t]={line:d,column:h,pos:p}}function y(e,t){return Array(e+1).join(t)}};var i=["number","bigint","boolean","string","object"];function b(e){return 0<=i.indexOf(typeof e)}var o=/"|\\/g,r=/[\b]/g,s=/\f/g,a=/\n/g,l=/\r/g,c=/\t/g;function x(e){return'"'+(e=e.replace(o,"\\$&").replace(s,"\\f").replace(r,"\\b").replace(a,"\\n").replace(l,"\\r").replace(c,"\\t"))+'"'}var d=/~/g,h=/\//g;function _(e){return e.replace(d,"~0").replace(h,"~1")}},function(e,t,n){!function(e){"use strict";function _(e){return null!==e&&"[object Array]"===Object.prototype.toString.call(e)}function T(e){return null!==e&&"[object Object]"===Object.prototype.toString.call(e)}function w(e,t){if(e===t)return!0;if(Object.prototype.toString.call(e)!==Object.prototype.toString.call(t))return!1;if(!0===_(e)){if(e.length!==t.length)return!1;for(var n=0;n<e.length;n++)if(!1===w(e[n],t[n]))return!1;return!0}if(!0!==T(e))return!1;var i,o,r={};for(i in e)if(hasOwnProperty.call(e,i)){if(!1===w(e[i],t[i]))return!1;r[i]=!0}for(o in t)if(hasOwnProperty.call(t,o)&&!0!==r[o])return!1;return!0}function S(e){if(""===e||!1===e||null===e)return!0;if(_(e)&&0===e.length)return!0;if(T(e)){for(var t in e)if(e.hasOwnProperty(t))return!1;return!0}return!1}var o="function"==typeof String.prototype.trimLeft?function(e){return e.trimLeft()}:function(e){return e.match(/^\s*(.*)/)[1]},c=0,r=1,d=2,s=3,t=4,n=6,a=8,l=9,h="UnquotedIdentifier",u="QuotedIdentifier",p="Rbracket",f="Rparen",m="Comma",g="Colon",i="Rbrace",v="Number",j="Current",k="Expref",N="Pipe",O="GTE",I="LTE",D="Flatten",y="Star",b="Filter",x="Dot",C="Lbrace",E="Lbracket",A="Lparen",P="Literal",F={".":x,"*":y,",":m,":":g,"{":C,"}":i,"]":p,"(":A,")":f,"@":j},M={"<":!0,">":!0,"=":!0,"!":!0},V={" ":!0,"\t":!0,"\n":!0};function B(e){return"0"<=e&&e<="9"||"-"===e}function L(){}L.prototype={tokenize:function(e){var t,n,i,o,r=[];for(this._current=0;this._current<e.length;)if("a"<=(o=e[this._current])&&o<="z"||"A"<=o&&o<="Z"||"_"===o)t=this._current,n=this._consumeUnquotedIdentifier(e),r.push({type:h,value:n,start:t});else if(void 0!==F[e[this._current]])r.push({type:F[e[this._current]],value:e[this._current],start:this._current}),this._current++;else if(B(e[this._current]))i=this._consumeNumber(e),r.push(i);else if("["===e[this._current])i=this._consumeLBracket(e),r.push(i);else if('"'===e[this._current])t=this._current,n=this._consumeQuotedIdentifier(e),r.push({type:u,value:n,start:t});else if("'"===e[this._current])t=this._current,n=this._consumeRawStringLiteral(e),r.push({type:P,value:n,start:t});else if("`"===e[this._current]){t=this._current;var s=this._consumeLiteral(e);r.push({type:P,value:s,start:t})}else if(void 0!==M[e[this._current]])r.push(this._consumeOperator(e));else if(void 0!==V[e[this._current]])this._current++;else if("&"===e[this._current])t=this._current,this._current++,"&"===e[this._current]?(this._current++,r.push({type:"And",value:"&&",start:t})):r.push({type:k,value:"&",start:t});else{if("|"!==e[this._current]){s=new Error("Unknown character:"+e[this._current]);throw s.name="LexerError",s}t=this._current,this._current++,"|"===e[this._current]?(this._current++,r.push({type:"Or",value:"||",start:t})):r.push({type:N,value:"|",start:t})}return r},_consumeUnquotedIdentifier:function(e){var t,n=this._current;for(this._current++;this._current<e.length&&("a"<=(t=e[this._current])&&t<="z"||"A"<=t&&t<="Z"||"0"<=t&&t<="9"||"_"===t);)this._current++;return e.slice(n,this._current)},_consumeQuotedIdentifier:function(e){var t=this._current;this._current++;for(var n=e.length;'"'!==e[this._current]&&this._current<n;){var i=this._current;"\\"!==e[i]||"\\"!==e[i+1]&&'"'!==e[i+1]?i++:i+=2,this._current=i}return this._current++,JSON.parse(e.slice(t,this._current))},_consumeRawStringLiteral:function(e){var t=this._current;this._current++;for(var n=e.length;"'"!==e[this._current]&&this._current<n;){var i=this._current;"\\"!==e[i]||"\\"!==e[i+1]&&"'"!==e[i+1]?i++:i+=2,this._current=i}return this._current++,e.slice(t+1,this._current-1).replace("\\'","'")},_consumeNumber:function(e){var t=this._current;this._current++;for(var n=e.length;B(e[this._current])&&this._current<n;)this._current++;var i=parseInt(e.slice(t,this._current));return{type:v,value:i,start:t}},_consumeLBracket:function(e){var t=this._current;return this._current++,"?"===e[this._current]?(this._current++,{type:b,value:"[?",start:t}):"]"===e[this._current]?(this._current++,{type:D,value:"[]",start:t}):{type:E,value:"[",start:t}},_consumeOperator:function(e){var t=this._current,n=e[t];return this._current++,"!"===n?"="===e[this._current]?(this._current++,{type:"NE",value:"!=",start:t}):{type:"Not",value:"!",start:t}:"<"===n?"="===e[this._current]?(this._current++,{type:I,value:"<=",start:t}):{type:"LT",value:"<",start:t}:">"===n?"="===e[this._current]?(this._current++,{type:O,value:">=",start:t}):{type:"GT",value:">",start:t}:"="===n&&"="===e[this._current]?(this._current++,{type:"EQ",value:"==",start:t}):void 0},_consumeLiteral:function(e){this._current++;for(var t=this._current,n=e.length;"`"!==e[this._current]&&this._current<n;){var i=this._current;"\\"!==e[i]||"\\"!==e[i+1]&&"`"!==e[i+1]?i++:i+=2,this._current=i}var t=(t=o(e.slice(t,this._current))).replace("\\`","`"),t=this._looksLikeJSON(t)?JSON.parse(t):JSON.parse('"'+t+'"');return this._current++,t},_looksLikeJSON:function(e){if(""===e)return!1;if(0<='[{"'.indexOf(e[0]))return!0;if(0<=["true","false","null"].indexOf(e))return!0;if(!(0<="-0123456789".indexOf(e[0])))return!1;try{return JSON.parse(e),!0}catch(e){return!1}}};var R={};function z(){}function H(e){this.runtime=e}function U(e){this._interpreter=e,this.functionTable={abs:{_func:this._functionAbs,_signature:[{types:[c]}]},avg:{_func:this._functionAvg,_signature:[{types:[a]}]},ceil:{_func:this._functionCeil,_signature:[{types:[c]}]},contains:{_func:this._functionContains,_signature:[{types:[d,s]},{types:[r]}]},ends_with:{_func:this._functionEndsWith,_signature:[{types:[d]},{types:[d]}]},floor:{_func:this._functionFloor,_signature:[{types:[c]}]},length:{_func:this._functionLength,_signature:[{types:[d,s,t]}]},map:{_func:this._functionMap,_signature:[{types:[n]},{types:[s]}]},max:{_func:this._functionMax,_signature:[{types:[a,l]}]},merge:{_func:this._functionMerge,_signature:[{types:[t],variadic:!0}]},max_by:{_func:this._functionMaxBy,_signature:[{types:[s]},{types:[n]}]},sum:{_func:this._functionSum,_signature:[{types:[a]}]},starts_with:{_func:this._functionStartsWith,_signature:[{types:[d]},{types:[d]}]},min:{_func:this._functionMin,_signature:[{types:[a,l]}]},min_by:{_func:this._functionMinBy,_signature:[{types:[s]},{types:[n]}]},type:{_func:this._functionType,_signature:[{types:[r]}]},keys:{_func:this._functionKeys,_signature:[{types:[t]}]},values:{_func:this._functionValues,_signature:[{types:[t]}]},sort:{_func:this._functionSort,_signature:[{types:[l,a]}]},sort_by:{_func:this._functionSortBy,_signature:[{types:[s]},{types:[n]}]},join:{_func:this._functionJoin,_signature:[{types:[d]},{types:[l]}]},reverse:{_func:this._functionReverse,_signature:[{types:[d,s]}]},to_array:{_func:this._functionToArray,_signature:[{types:[r]}]},to_string:{_func:this._functionToString,_signature:[{types:[r]}]},to_number:{_func:this._functionToNumber,_signature:[{types:[r]}]},not_null:{_func:this._functionNotNull,_signature:[{types:[r],variadic:!0}]}}}R.EOF=0,R[h]=0,R[u]=0,R[p]=0,R[f]=0,R[m]=0,R[i]=0,R[v]=0,R[j]=0,R[k]=0,R[N]=1,R.Or=2,R.And=3,R.EQ=5,R.GT=5,R.LT=5,R.GTE=5,R.LTE=5,R.NE=5,R[D]=9,R[y]=20,R[b]=21,R.Dot=40,R.Not=45,R[C]=50,R[E]=55,R[A]=60,z.prototype={parse:function(e){this._loadTokens(e),this.index=0;e=this.expression(0);if("EOF"===this._lookahead(0))return e;e=this._lookaheadToken(0),e=new Error("Unexpected token type: "+e.type+", value: "+e.value);throw e.name="ParserError",e},_loadTokens:function(e){var t=(new L).tokenize(e);t.push({type:"EOF",value:"",start:e.length}),this.tokens=t},expression:function(e){var t=this._lookaheadToken(0);this._advance();for(var n=this.nud(t),i=this._lookahead(0);e<R[i];)this._advance(),n=this.led(i,n),i=this._lookahead(0);return n},_lookahead:function(e){return this.tokens[this.index+e].type},_lookaheadToken:function(e){return this.tokens[this.index+e]},_advance:function(){this.index++},nud:function(e){var t,n;switch(e.type){case P:return{type:"Literal",value:e.value};case h:return{type:"Field",name:e.value};case u:var i={type:"Field",name:e.value};if(this._lookahead(0)===A)throw new Error("Quoted identifier not allowed for function names.");return i;case"Not":return{type:"NotExpression",children:[t=this.expression(R.Not)]};case y:return t=null,{type:"ValueProjection",children:[{type:"Identity"},t=this._lookahead(0)===p?{type:"Identity"}:this._parseProjectionRHS(R.Star)]};case b:return this.led(e.type,{type:"Identity"});case C:return this._parseMultiselectHash();case D:return{type:"Projection",children:[{type:D,children:[{type:"Identity"}]},t=this._parseProjectionRHS(R.Flatten)]};case E:return this._lookahead(0)===v||this._lookahead(0)===g?(t=this._parseIndexExpression(),this._projectIfSlice({type:"Identity"},t)):this._lookahead(0)===y&&this._lookahead(1)===p?(this._advance(),this._advance(),{type:"Projection",children:[{type:"Identity"},t=this._parseProjectionRHS(R.Star)]}):this._parseMultiselectList();case j:return{type:j};case k:return{type:"ExpressionReference",children:[n=this.expression(R.Expref)]};case A:for(var o=[];this._lookahead(0)!==f;)this._lookahead(0)===j?(n={type:j},this._advance()):n=this.expression(0),o.push(n);return this._match(f),o[0];default:this._errorToken(e)}},led:function(e,t){var n;switch(e){case x:var i=R.Dot;return this._lookahead(0)!==y?{type:"Subexpression",children:[t,n=this._parseDotRHS(i)]}:(this._advance(),{type:"ValueProjection",children:[t,n=this._parseProjectionRHS(i)]});case N:return n=this.expression(R.Pipe),{type:N,children:[t,n]};case"Or":return{type:"OrExpression",children:[t,n=this.expression(R.Or)]};case"And":return{type:"AndExpression",children:[t,n=this.expression(R.And)]};case A:for(var o,i=t.name,r=[];this._lookahead(0)!==f;)this._lookahead(0)===j?(o={type:j},this._advance()):o=this.expression(0),this._lookahead(0)===m&&this._match(m),r.push(o);return this._match(f),{type:"Function",name:i,children:r};case b:var s=this.expression(0);return this._match(p),{type:"FilterProjection",children:[t,n=this._lookahead(0)===D?{type:"Identity"}:this._parseProjectionRHS(R.Filter),s]};case D:return{type:"Projection",children:[{type:D,children:[t]},this._parseProjectionRHS(R.Flatten)]};case"EQ":case"NE":case"GT":case O:case"LT":case I:return this._parseComparator(t,e);case E:s=this._lookaheadToken(0);return s.type===v||s.type===g?(n=this._parseIndexExpression(),this._projectIfSlice(t,n)):(this._match(y),this._match(p),{type:"Projection",children:[t,n=this._parseProjectionRHS(R.Star)]});default:this._errorToken(this._lookaheadToken(0))}},_match:function(e){if(this._lookahead(0)!==e){var t=this._lookaheadToken(0),t=new Error("Expected "+e+", got: "+t.type);throw t.name="ParserError",t}this._advance()},_errorToken:function(e){e=new Error("Invalid token ("+e.type+'): "'+e.value+'"');throw e.name="ParserError",e},_parseIndexExpression:function(){if(this._lookahead(0)===g||this._lookahead(1)===g)return this._parseSliceExpression();var e={type:"Index",value:this._lookaheadToken(0).value};return this._advance(),this._match(p),e},_projectIfSlice:function(e,t){e={type:"IndexExpression",children:[e,t]};return"Slice"===t.type?{type:"Projection",children:[e,this._parseProjectionRHS(R.Star)]}:e},_parseSliceExpression:function(){for(var e=[null,null,null],t=0,n=this._lookahead(0);n!==p&&t<3;){if(n===g)t++,this._advance();else{if(n!==v){var i=this._lookahead(0),i=new Error("Syntax error, unexpected token: "+i.value+"("+i.type+")");throw i.name="Parsererror",i}e[t]=this._lookaheadToken(0).value,this._advance()}n=this._lookahead(0)}return this._match(p),{type:"Slice",children:e}},_parseComparator:function(e,t){return{type:"Comparator",name:t,children:[e,this.expression(R[t])]}},_parseDotRHS:function(e){var t=this._lookahead(0);return 0<=[h,u,y].indexOf(t)?this.expression(e):t===E?(this._match(E),this._parseMultiselectList()):t===C?(this._match(C),this._parseMultiselectHash()):void 0},_parseProjectionRHS:function(e){var t;if(R[this._lookahead(0)]<10)t={type:"Identity"};else if(this._lookahead(0)===E)t=this.expression(e);else if(this._lookahead(0)===b)t=this.expression(e);else{if(this._lookahead(0)!==x){var n=this._lookaheadToken(0),n=new Error("Sytanx error, unexpected token: "+n.value+"("+n.type+")");throw n.name="ParserError",n}this._match(x),t=this._parseDotRHS(e)}return t},_parseMultiselectList:function(){for(var e=[];this._lookahead(0)!==p;){var t=this.expression(0);if(e.push(t),this._lookahead(0)===m&&(this._match(m),this._lookahead(0)===p))throw new Error("Unexpected token Rbracket")}return this._match(p),{type:"MultiSelectList",children:e}},_parseMultiselectHash:function(){for(var e,t=[],n=[h,u];;){if(e=this._lookaheadToken(0),n.indexOf(e.type)<0)throw new Error("Expecting an identifier token, got: "+e.type);if(e=e.value,this._advance(),this._match(g),e={type:"KeyValuePair",name:e,value:this.expression(0)},t.push(e),this._lookahead(0)===m)this._match(m);else if(this._lookahead(0)===i){this._match(i);break}}return{type:"MultiSelectHash",children:t}}},H.prototype={search:function(e,t){return this.visit(e,t)},visit:function(e,t){var n,i,o,r;switch(e.type){case"Field":return null===t||!T(t)||void 0===(a=t[e.name])?null:a;case"Subexpression":for(d=this.visit(e.children[0],t),p=1;p<e.children.length;p++)if(null===(d=this.visit(e.children[1],d)))return null;return d;case"IndexExpression":return E=this.visit(e.children[0],t),this.visit(e.children[1],E);case"Index":if(!_(t))return null;var s=e.value;return s<0&&(s=t.length+s),void 0===(d=t[s])&&(d=null),d;case"Slice":if(!_(t))return null;var a=e.children.slice(0),s=this.computeSliceParams(t.length,a),a=s[0],l=s[1],c=s[2],d=[];if(0<c)for(p=a;p<l;p+=c)d.push(t[p]);else for(p=a;l<p;p+=c)d.push(t[p]);return d;case"Projection":var h=this.visit(e.children[0],t);if(!_(h))return null;for(x=[],p=0;p<h.length;p++)null!==(i=this.visit(e.children[1],h[p]))&&x.push(i);return x;case"ValueProjection":if(!T(h=this.visit(e.children[0],t)))return null;x=[];for(var u=function(e){for(var t=Object.keys(e),n=[],i=0;i<t.length;i++)n.push(e[t[i]]);return n}(h),p=0;p<u.length;p++)null!==(i=this.visit(e.children[1],u[p]))&&x.push(i);return x;case"FilterProjection":if(!_(h=this.visit(e.children[0],t)))return null;var f=[],m=[];for(p=0;p<h.length;p++)S(n=this.visit(e.children[2],h[p]))||f.push(h[p]);for(var g=0;g<f.length;g++)null!==(i=this.visit(e.children[1],f[g]))&&m.push(i);return m;case"Comparator":switch(o=this.visit(e.children[0],t),r=this.visit(e.children[1],t),e.name){case"EQ":d=w(o,r);break;case"NE":d=!w(o,r);break;case"GT":d=r<o;break;case O:d=r<=o;break;case"LT":d=o<r;break;case I:d=o<=r;break;default:throw new Error("Unknown comparator: "+e.name)}return d;case D:var v=this.visit(e.children[0],t);if(!_(v))return null;var y=[];for(p=0;p<v.length;p++)_(i=v[p])?y.push.apply(y,i):y.push(i);return y;case"Identity":return t;case"MultiSelectList":if(null===t)return null;for(x=[],p=0;p<e.children.length;p++)x.push(this.visit(e.children[p],t));return x;case"MultiSelectHash":if(null===t)return null;var b,x={};for(p=0;p<e.children.length;p++)x[(b=e.children[p]).name]=this.visit(b.value,t);return x;case"OrExpression":return S(n=this.visit(e.children[0],t))&&(n=this.visit(e.children[1],t)),n;case"AndExpression":return!0===S(o=this.visit(e.children[0],t))?o:this.visit(e.children[1],t);case"NotExpression":return S(o=this.visit(e.children[0],t));case"Literal":return e.value;case N:return E=this.visit(e.children[0],t),this.visit(e.children[1],E);case j:return t;case"Function":var C=[];for(p=0;p<e.children.length;p++)C.push(this.visit(e.children[p],t));return this.runtime.callFunction(e.name,C);case"ExpressionReference":var E=e.children[0];return E.jmespathType=k,E;default:throw new Error("Unknown node type: "+e.type)}},computeSliceParams:function(e,t){var n=t[0],i=t[1],o=t[2],t=[null,null,null];if(null===o)o=1;else if(0===o){var r=new Error("Invalid slice, step cannot be 0");throw r.name="RuntimeError",r}r=o<0,n=null===n?r?e-1:0:this.capSliceRange(e,n,o),i=null===i?r?-1:e:this.capSliceRange(e,i,o);return t[0]=n,t[1]=i,t[2]=o,t},capSliceRange:function(e,t,n){return t<0?(t+=e)<0&&(t=n<0?-1:0):e<=t&&(t=n<0?e-1:e),t}},U.prototype={callFunction:function(e,t){var n=this.functionTable[e];if(void 0===n)throw new Error("Unknown function: "+e+"()");return this._validateArgs(e,t,n._signature),n._func.call(this,t)},_validateArgs:function(e,t,n){var i,o,r,s;if(n[n.length-1].variadic){if(t.length<n.length)throw i=1===n.length?" argument":" arguments",new Error("ArgumentError: "+e+"() takes at least"+n.length+i+" but received "+t.length)}else if(t.length!==n.length)throw i=1===n.length?" argument":" arguments",new Error("ArgumentError: "+e+"() takes "+n.length+i+" but received "+t.length);for(var a=0;a<n.length;a++){s=!1,o=n[a].types,r=this._getTypeName(t[a]);for(var l=0;l<o.length;l++)if(this._typeMatches(r,o[l],t[a])){s=!0;break}if(!s)throw new Error("TypeError: "+e+"() expected argument "+(a+1)+" to be type "+o+" but received type "+r+" instead.")}},_typeMatches:function(e,t,n){if(t===r)return!0;if(t!==l&&t!==a&&t!==s)return e===t;if(t===s)return e===s;if(e===s){var i;t===a?i=c:t===l&&(i=d);for(var o=0;o<n.length;o++)if(!this._typeMatches(this._getTypeName(n[o]),i,n[o]))return!1;return!0}},_getTypeName:function(e){switch(Object.prototype.toString.call(e)){case"[object String]":return d;case"[object Number]":return c;case"[object Array]":return s;case"[object Boolean]":return 5;case"[object Null]":return 7;case"[object Object]":return e.jmespathType===k?n:t}},_functionStartsWith:function(e){return 0===e[0].lastIndexOf(e[1])},_functionEndsWith:function(e){var t=e[0],e=e[1];return-1!==t.indexOf(e,t.length-e.length)},_functionReverse:function(e){if(this._getTypeName(e[0])===d){for(var t=e[0],n="",i=t.length-1;0<=i;i--)n+=t[i];return n}e=e[0].slice(0);return e.reverse(),e},_functionAbs:function(e){return Math.abs(e[0])},_functionCeil:function(e){return Math.ceil(e[0])},_functionAvg:function(e){for(var t=0,n=e[0],i=0;i<n.length;i++)t+=n[i];return t/n.length},_functionContains:function(e){return 0<=e[0].indexOf(e[1])},_functionFloor:function(e){return Math.floor(e[0])},_functionLength:function(e){return(T(e[0])?Object.keys(e[0]):e[0]).length},_functionMap:function(e){for(var t=[],n=this._interpreter,i=e[0],o=e[1],r=0;r<o.length;r++)t.push(n.visit(i,o[r]));return t},_functionMerge:function(e){for(var t={},n=0;n<e.length;n++){var i,o=e[n];for(i in o)t[i]=o[i]}return t},_functionMax:function(e){if(0<e[0].length){if(this._getTypeName(e[0][0])===c)return Math.max.apply(Math,e[0]);for(var t=e[0],n=t[0],i=1;i<t.length;i++)n.localeCompare(t[i])<0&&(n=t[i]);return n}return null},_functionMin:function(e){if(0<e[0].length){if(this._getTypeName(e[0][0])===c)return Math.min.apply(Math,e[0]);for(var t=e[0],n=t[0],i=1;i<t.length;i++)t[i].localeCompare(n)<0&&(n=t[i]);return n}return null},_functionSum:function(e){for(var t=0,n=e[0],i=0;i<n.length;i++)t+=n[i];return t},_functionType:function(e){switch(this._getTypeName(e[0])){case c:return"number";case d:return"string";case s:return"array";case t:return"object";case 5:return"boolean";case n:return"expref";case 7:return"null"}},_functionKeys:function(e){return Object.keys(e[0])},_functionValues:function(e){for(var t=e[0],n=Object.keys(t),i=[],o=0;o<n.length;o++)i.push(t[n[o]]);return i},_functionJoin:function(e){var t=e[0];return e[1].join(t)},_functionToArray:function(e){return this._getTypeName(e[0])===s?e[0]:[e[0]]},_functionToString:function(e){return this._getTypeName(e[0])===d?e[0]:JSON.stringify(e[0])},_functionToNumber:function(e){var t,n=this._getTypeName(e[0]);return n===c?e[0]:n!==d||(t=+e[0],isNaN(t))?null:t},_functionNotNull:function(e){for(var t=0;t<e.length;t++)if(7!==this._getTypeName(e[t]))return e[t];return null},_functionSort:function(e){e=e[0].slice(0);return e.sort(),e},_functionSortBy:function(e){var t=e[0].slice(0);if(0===t.length)return t;var o=this._interpreter,r=e[1],s=this._getTypeName(o.visit(r,t[0]));if([c,d].indexOf(s)<0)throw new Error("TypeError");for(var a=this,n=[],i=0;i<t.length;i++)n.push([i,t[i]]);n.sort(function(e,t){var n=o.visit(r,e[1]),i=o.visit(r,t[1]);if(a._getTypeName(n)!==s)throw new Error("TypeError: expected "+s+", received "+a._getTypeName(n));if(a._getTypeName(i)!==s)throw new Error("TypeError: expected "+s+", received "+a._getTypeName(i));return i<n?1:n<i?-1:e[0]-t[0]});for(var l=0;l<n.length;l++)t[l]=n[l][1];return t},_functionMaxBy:function(e){for(var t,n,i=e[1],o=e[0],r=this.createKeyFunction(i,[c,d]),s=-1/0,a=0;a<o.length;a++)s<(n=r(o[a]))&&(s=n,t=o[a]);return t},_functionMinBy:function(e){for(var t,n,i=e[1],o=e[0],r=this.createKeyFunction(i,[c,d]),s=1/0,a=0;a<o.length;a++)(n=r(o[a]))<s&&(s=n,t=o[a]);return t},createKeyFunction:function(n,i){var o=this,r=this._interpreter;return function(e){var t=r.visit(n,e);if(i.indexOf(o._getTypeName(t))<0){e="TypeError: expected one of "+i+", received "+o._getTypeName(t);throw new Error(e)}return t}}},e.tokenize=function(e){return(new L).tokenize(e)},e.compile=function(e){return(new z).parse(e)},e.search=function(e,t){var n=new z,i=new U,o=new H(i);return i._interpreter=o,t=n.parse(t),o.search(t,e)},e.strictDeepEqual=w}(t)},function(e,t,n){t.tryRequireThemeJsonEditor=function(){try{n(24)}catch(e){console.error(e)}}},function(e,t,o){"use strict";var n=o(16),i=o(13),r=o(26).treeModeMixins,s=o(17).textModeMixins,a=o(27).previewModeMixins,l=o(0),c=l.clear,d=l.extend,h=l.getInnerText,u=l.getInternetExplorerVersion,p=l.parse,f=o(25).tryRequireAjv,m=o(6).showTransformModal,l=o(5).showSortModal,g=f();function v(e,t,n){if(!(this instanceof v))throw new Error('JSONEditor constructor called without "new".');var i=u();if(-1!==i&&i<9)throw new Error("Unsupported browser, IE9 or newer required. Please install the newest version of your browser.");t&&(t.error&&(console.warn('Option "error" has been renamed to "onError"'),t.onError=t.error,delete t.error),t.change&&(console.warn('Option "change" has been renamed to "onChange"'),t.onChange=t.change,delete t.change),t.editable&&(console.warn('Option "editable" has been renamed to "onEditable"'),t.onEditable=t.editable,delete t.editable),t.onChangeJSON&&("text"!==t.mode&&"code"!==t.mode&&(!t.modes||-1===t.modes.indexOf("text")&&-1===t.modes.indexOf("code"))||console.warn('Option "onChangeJSON" is not applicable to modes "text" and "code". Use "onChangeText" or "onChange" instead.')),t&&Object.keys(t).forEach(function(e){-1===v.VALID_OPTIONS.indexOf(e)&&console.warn('Unknown option "'+e+'". This option will be ignored')})),arguments.length&&this._create(e,t,n)}"undefined"==typeof Promise&&console.error("Promise undefined. Please load a Promise polyfill in the browser in order to use JSONEditor"),v.modes={},v.prototype.DEBOUNCE_INTERVAL=150,v.VALID_OPTIONS=["ajv","schema","schemaRefs","templates","ace","theme","autocomplete","onChange","onChangeJSON","onChangeText","onEditable","onError","onEvent","onModeChange","onNodeName","onValidate","onCreateMenu","onSelectionChange","onTextSelectionChange","onClassName","onFocus","onBlur","colorPicker","onColorPicker","timestampTag","timestampFormat","escapeUnicode","history","search","mode","modes","name","indentation","sortObjectKeys","navigationBar","statusBar","mainMenuBar","languages","language","enableSort","enableTransform","limitDragging","maxVisibleChilds","onValidationError","modalAnchor","popupAnchor","createQuery","executeQuery","queryDescription"],v.prototype._create=function(e,t,n){this.container=e,this.options=t||{},this.json=n||{};n=this.options.mode||this.options.modes&&this.options.modes[0]||"tree";this.setMode(n)},v.prototype.destroy=function(){},v.prototype.set=function(e){this.json=e},v.prototype.get=function(){return this.json},v.prototype.setText=function(e){this.json=p(e)},v.prototype.getText=function(){return JSON.stringify(this.json)},v.prototype.setName=function(e){this.options||(this.options={}),this.options.name=e},v.prototype.getName=function(){return this.options&&this.options.name},v.prototype.setMode=function(e){if(e!==this.options.mode||!this.create){var t=this.container,n=d({},this.options),i=n.mode;n.mode=e;var o=v.modes[e];if(!o)throw new Error('Unknown mode "'+n.mode+'"');try{var r="text"===o.data,s=this.getName(),a=this[r?"getText":"get"]();if(this.destroy(),c(this),d(this,o.mixin),this.create(t,n),this.setName(s),this[r?"setText":"set"](a),"function"==typeof o.load)try{o.load.call(this)}catch(e){console.error(e)}if("function"==typeof n.onModeChange&&e!==i)try{n.onModeChange(e,i)}catch(e){console.error(e)}}catch(e){this._onError(e)}}},v.prototype.getMode=function(){return this.options.mode},v.prototype._onError=function(e){if(!this.options||"function"!=typeof this.options.onError)throw e;this.options.onError(e)},v.prototype.setSchema=function(e,t){if(e){var n;try{this.options.ajv?n=this.options.ajv:((n=g({allErrors:!0,verbose:!0,schemaId:"auto",$data:!0})).addMetaSchema(o(!function(){var e=new Error("Cannot find module 'ajv/lib/refs/json-schema-draft-04.json'");throw e.code="MODULE_NOT_FOUND",e}())),n.addMetaSchema(o(!function(){var e=new Error("Cannot find module 'ajv/lib/refs/json-schema-draft-06.json'");throw e.code="MODULE_NOT_FOUND",e}())))}catch(e){console.warn("Failed to create an instance of Ajv, JSON Schema validation is not available. Please use a JSONEditor bundle including Ajv, or pass an instance of Ajv as via the configuration option `ajv`.")}if(n){if(t){for(var i in t)n.removeSchema(i),t[i]&&n.addSchema(t[i],i);this.options.schemaRefs=t}this.validateSchema=n.compile(e),this.options.schema=e,this.validate()}this.refresh()}else this.validateSchema=null,this.options.schema=null,this.options.schemaRefs=null,this.validate(),this.refresh()},v.prototype.validate=function(){},v.prototype.refresh=function(){},v.registerMode=function(e){var t;if(Array.isArray(e))for(o=0;o<e.length;o++)v.registerMode(e[o]);else{if(!("mode"in e))throw new Error('Property "mode" missing');if(!("mixin"in e))throw new Error('Property "mixin" missing');if(!("data"in e))throw new Error('Property "data" missing');var n=e.mode;if(n in v.modes)throw new Error('Mode "'+n+'" already registered');if("function"!=typeof e.mixin.create)throw new Error('Required function "create" missing on mixin');for(var i=["setMode","registerMode","modes"],o=0;o<i.length;o++)if((t=i[o])in e.mixin)throw new Error('Reserved property "'+t+'" not allowed in mixin');v.modes[n]=e}},v.registerMode(r),v.registerMode(s),v.registerMode(a),v.ace=n,v.Ajv=g,v.VanillaPicker=i,v.showTransformModal=m,v.showSortModal=l,v.getInnerText=h,v.default=v,e.exports=v},function(e,t){window.ace.define("ace/theme/jsoneditor",["require","exports","module","ace/lib/dom"],function(e,t,n){t.isDark=!1,t.cssClass="ace-jsoneditor",t.cssText='.ace-jsoneditor .ace_gutter {\nbackground: #ebebeb;\ncolor: #333\n}\n\n.ace-jsoneditor.ace_editor {\nfont-family: "dejavu sans mono", "droid sans mono", consolas, monaco, "lucida console", "courier new", courier, monospace, sans-serif;\nline-height: 1.3;\nbackground-color: #fff;\n}\n.ace-jsoneditor .ace_print-margin {\nwidth: 1px;\nbackground: #e8e8e8\n}\n.ace-jsoneditor .ace_scroller {\nbackground-color: #FFFFFF\n}\n.ace-jsoneditor .ace_text-layer {\ncolor: gray\n}\n.ace-jsoneditor .ace_variable {\ncolor: #1a1a1a\n}\n.ace-jsoneditor .ace_cursor {\nborder-left: 2px solid #000000\n}\n.ace-jsoneditor .ace_overwrite-cursors .ace_cursor {\nborder-left: 0px;\nborder-bottom: 1px solid #000000\n}\n.ace-jsoneditor .ace_marker-layer .ace_selection {\nbackground: lightgray\n}\n.ace-jsoneditor.ace_multiselect .ace_selection.ace_start {\nbox-shadow: 0 0 3px 0px #FFFFFF;\nborder-radius: 2px\n}\n.ace-jsoneditor .ace_marker-layer .ace_step {\nbackground: rgb(255, 255, 0)\n}\n.ace-jsoneditor .ace_marker-layer .ace_bracket {\nmargin: -1px 0 0 -1px;\nborder: 1px solid #BFBFBF\n}\n.ace-jsoneditor .ace_marker-layer .ace_active-line {\nbackground: #FFFBD1\n}\n.ace-jsoneditor .ace_gutter-active-line {\nbackground-color : #dcdcdc\n}\n.ace-jsoneditor .ace_marker-layer .ace_selected-word {\nborder: 1px solid lightgray\n}\n.ace-jsoneditor .ace_invisible {\ncolor: #BFBFBF\n}\n.ace-jsoneditor .ace_keyword,\n.ace-jsoneditor .ace_meta,\n.ace-jsoneditor .ace_support.ace_constant.ace_property-value {\ncolor: #AF956F\n}\n.ace-jsoneditor .ace_keyword.ace_operator {\ncolor: #484848\n}\n.ace-jsoneditor .ace_keyword.ace_other.ace_unit {\ncolor: #96DC5F\n}\n.ace-jsoneditor .ace_constant.ace_language {\ncolor: darkorange\n}\n.ace-jsoneditor .ace_constant.ace_numeric {\ncolor: red\n}\n.ace-jsoneditor .ace_constant.ace_character.ace_entity {\ncolor: #BF78CC\n}\n.ace-jsoneditor .ace_invalid {\ncolor: #FFFFFF;\nbackground-color: #FF002A;\n}\n.ace-jsoneditor .ace_fold {\nbackground-color: #AF956F;\nborder-color: #000000\n}\n.ace-jsoneditor .ace_storage,\n.ace-jsoneditor .ace_support.ace_class,\n.ace-jsoneditor .ace_support.ace_function,\n.ace-jsoneditor .ace_support.ace_other,\n.ace-jsoneditor .ace_support.ace_type {\ncolor: #C52727\n}\n.ace-jsoneditor .ace_string {\ncolor: green\n}\n.ace-jsoneditor .ace_comment {\ncolor: #BCC8BA\n}\n.ace-jsoneditor .ace_entity.ace_name.ace_tag,\n.ace-jsoneditor .ace_entity.ace_other.ace_attribute-name {\ncolor: #606060\n}\n.ace-jsoneditor .ace_markup.ace_underline {\ntext-decoration: underline\n}\n.ace-jsoneditor .ace_indent-guide {\nbackground: url("data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAEAAAACCAYAAACZgbYnAAAAE0lEQVQImWP4////f4bLly//BwAmVgd1/w11/gAAAABJRU5ErkJggg==") right repeat-y\n}',e("../lib/dom").importCssString(t.cssText,t.cssClass)})},function(e,t,n){t.tryRequireAjv=function(){try{return n(!function(){var e=new Error("Cannot find module 'ajv'");throw e.code="MODULE_NOT_FOUND",e}())}catch(e){}}},function(e,t,n){"use strict";n.r(t),n.d(t,"treeModeMixins",function(){return V});var _={start:function(e,t){return 0===t.indexOf(e)},contain:function(e,t){return-1<t.indexOf(e)}};var s=n(3),a=n(8);function o(e,t){for(var n=0;n<t.length;n++){var i=t[n];i.enumerable=i.enumerable||!1,i.configurable=!0,"value"in i&&(i.writable=!0),Object.defineProperty(e,i.key,i)}}var i=function(){function t(){!function(e){if(!(e instanceof t))throw new TypeError("Cannot call a class as a function")}(this),this.locked=!1}var e,n,i;return e=t,(n=[{key:"highlight",value:function(e){this.locked||(this.node!==e&&(this.node&&this.node.setHighlight(!1),this.node=e,this.node.setHighlight(!0)),this._cancelUnhighlight())}},{key:"unhighlight",value:function(){var e;this.locked||(e=this).node&&(this._cancelUnhighlight(),this.unhighlightTimer=setTimeout(function(){e.node.setHighlight(!1),e.node=void 0,e.unhighlightTimer=void 0},0))}},{key:"_cancelUnhighlight",value:function(){this.unhighlightTimer&&(clearTimeout(this.unhighlightTimer),this.unhighlightTimer=void 0)}},{key:"lock",value:function(){this.locked=!0}},{key:"unlock",value:function(){this.locked=!1}}])&&o(e.prototype,n),i&&o(e,i),t}(),l=n(1),r=n(4),c=n(9),t=n(12),d=n.n(t),h=n(11),N=n(0);var u=n(5),p=n(6),f=n(2);function m(e,t){var n;if("undefined"==typeof Symbol||null==e[Symbol.iterator]){if(Array.isArray(e)||(n=function(e,t){if(!e)return;if("string"==typeof e)return g(e,t);var n=Object.prototype.toString.call(e).slice(8,-1);"Object"===n&&e.constructor&&(n=e.constructor.name);if("Map"===n||"Set"===n)return Array.from(e);if("Arguments"===n||/^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n))return g(e,t)}(e))||t&&e&&"number"==typeof e.length){n&&(e=n);var i=0,t=function(){};return{s:t,n:function(){return i>=e.length?{done:!0}:{done:!1,value:e[i++]}},e:function(e){throw e},f:t}}throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.")}var o,r=!0,s=!1;return{s:function(){n=e[Symbol.iterator]()},n:function(){var e=n.next();return r=e.done,e},e:function(e){s=!0,o=e},f:function(){try{r||null==n.return||n.return()}finally{if(s)throw o}}}}function g(e,t){(null==t||t>e.length)&&(t=e.length);for(var n=0,i=new Array(t);n<t;n++)i[n]=e[n];return i}function v(e){return(v="function"==typeof Symbol&&"symbol"==typeof Symbol.iterator?function(e){return typeof e}:function(e){return e&&"function"==typeof Symbol&&e.constructor===Symbol&&e!==Symbol.prototype?"symbol":typeof e})(e)}function y(e,t){for(var n=0;n<t.length;n++){var i=t[n];i.enumerable=i.enumerable||!1,i.configurable=!0,"value"in i&&(i.writable=!0),Object.defineProperty(e,i.key,i)}}var E=function(){function k(e,t){!function(e){if(!(e instanceof k))throw new TypeError("Cannot call a class as a function")}(this),this.editor=e,this.dom={},this.expanded=!1,t&&t instanceof Object?(this.setField(t.field,t.fieldEditable),"value"in t&&this.setValue(t.value,t.type),"internalValue"in t&&this.setInternalValue(t.internalValue)):(this.setField(""),this.setValue(null)),this._debouncedOnChangeValue=Object(N.debounce)(this._onChangeValue.bind(this),k.prototype.DEBOUNCE_INTERVAL),this._debouncedOnChangeField=Object(N.debounce)(this._onChangeField.bind(this),k.prototype.DEBOUNCE_INTERVAL),this.visibleChilds=this.getMaxVisibleChilds()}var e,t,n;return e=k,(t=[{key:"getMaxVisibleChilds",value:function(){return this.editor&&this.editor.options&&this.editor.options.maxVisibleChilds?this.editor.options.maxVisibleChilds:b}},{key:"_updateEditability",value:function(){var e;this.editable={field:!0,value:!0},this.editor&&(this.editable.field="tree"===this.editor.options.mode,this.editable.value="view"!==this.editor.options.mode,"tree"!==this.editor.options.mode&&"form"!==this.editor.options.mode||"function"!=typeof this.editor.options.onEditable||("boolean"==typeof(e=this.editor.options.onEditable({field:this.field,value:this.value,path:this.getPath()}))?(this.editable.field=e,this.editable.value=e):"object"===v(e)&&null!==e?("boolean"==typeof e.field&&(this.editable.field=e.field),"boolean"==typeof e.value&&(this.editable.value=e.value)):(console.error("Invalid return value for function onEditable.","Actual value:",e,".","Either a boolean or object { field: boolean, value: boolean } expected."),this.editable.field=!1,this.editable.value=!1)))}},{key:"getPath",value:function(){for(var e=this,t=[];e;){var n=e.getName();void 0!==n&&t.unshift(n),e=e.parent}return t}},{key:"getInternalPath",value:function(){for(var e=this,t=[];e;)e.parent&&t.unshift(e.getIndex()),e=e.parent;return t}},{key:"getName",value:function(){return this.parent?"array"!==this.parent.type?this.field:this.index:void 0}},{key:"findNodeByPath",value:function(e){if(e){if(0===e.length)return this;if(e.length&&this.childs&&this.childs.length)for(var t=0;t<this.childs.length;++t)if(""+e[0]==""+this.childs[t].getName())return this.childs[t].findNodeByPath(e.slice(1))}}},{key:"findNodeByInternalPath",value:function(e){if(e){for(var t=this,n=0;n<e.length&&t;n++)var i=e[n],t=t.childs[i];return t}}},{key:"serialize",value:function(){return{value:this.getValue(),path:this.getPath()}}},{key:"findNode",value:function(e){for(var n=Object(N.parsePath)(e),i=this;i&&0<n.length;)!function(){var t=n.shift();if("number"==typeof t){if("array"!==i.type)throw new Error("Cannot get child node at index "+t+": node is no array");i=i.childs[t]}else{if("object"!==i.type)throw new Error("Cannot get child node "+t+": node is no object");i=i.childs.filter(function(e){return e.field===t})[0]}}();return i}},{key:"findParents",value:function(){for(var e=[],t=this.parent;t;)e.unshift(t),t=t.parent;return e}},{key:"setError",value:function(e,t){this.error=e,this.errorChild=t,this.dom&&this.dom.tr&&this.updateError()}},{key:"updateError",value:function(){var n=this,i=this.fieldError||this.valueError||this.error,e=this.dom.tdError;if(i&&this.dom&&this.dom.tr){Object(N.addClassName)(this.dom.tr,"jsoneditor-validation-error"),e||(e=document.createElement("td"),this.dom.tdError=e,this.dom.tdValue.parentNode.appendChild(e));var o=document.createElement("button");o.type="button",o.className="jsoneditor-button jsoneditor-schema-error";var t=function(){n.dom.popupAnchor&&n.dom.popupAnchor.destroy()},r=function(){delete n.dom.popupAnchor},s=function(e){var t=n.editor.frame;n.dom.popupAnchor=Object(h.a)(o,n.editor.getPopupAnchor(),r,e);e=o.getBoundingClientRect(),t=120<t.getBoundingClientRect().width-e.x?"jsoneditor-above":"jsoneditor-left",e=document.createElement("div");e.className="jsoneditor-popover "+t,e.appendChild(document.createTextNode(i.message)),n.dom.popupAnchor.appendChild(e)};o.onmouseover=function(){n.dom.popupAnchor||s(!0)},o.onfocus=function(){t(),s(!1)},o.onblur=function(){t()};var a=this.errorChild;for(a&&(o.onclick=function(){a.findParents().forEach(function(e){e.expand(!1)}),a.scrollTo(function(){a.focus()})});e.firstChild;)e.removeChild(e.firstChild);e.appendChild(o)}else this.dom.tr&&Object(N.removeClassName)(this.dom.tr,"jsoneditor-validation-error"),e&&(this.dom.tdError.parentNode.removeChild(this.dom.tdError),delete this.dom.tdError)}},{key:"getIndex",value:function(){if(this.parent){var e=this.parent.childs.indexOf(this);return-1!==e?e:null}return-1}},{key:"setParent",value:function(e){this.parent=e}},{key:"setField",value:function(e,t){this.field=e,this.previousField=e,this.fieldEditable=!0===t}},{key:"getField",value:function(){return void 0===this.field&&this._getDomField(),this.field}},{key:"setValue",value:function(e,t){var n,i,o,r,s,a,l,c=this.childs;if(this.type=this._getType(e),t&&t!==this.type){if("string"!==t||"auto"!==this.type)throw new Error('Type mismatch: cannot cast value of type "'+this.type+' to the specified type "'+t+'"');this.type=t}if("array"===this.type){for(this.childs||(this.childs=[]),i=0;i<e.length;i++)void 0===(s=e[i])||s instanceof Function||(i<this.childs.length?((n=this.childs[i]).fieldEditable=!1,n.index=i,n.setValue(s)):(n=new k(this.editor,{value:s}),r=i<this.getMaxVisibleChilds(),this.appendChild(n,r,!1)));for(o=this.childs.length;o>=e.length;o--)this.removeChild(this.childs[o],!1)}else if("object"===this.type){for(this.childs||(this.childs=[]),o=this.childs.length-1;0<=o;o--)C(e,this.childs[o].field)||this.removeChild(this.childs[o],!1);for(var d in i=0,e)C(e,d)&&(void 0===(s=e[d])||s instanceof Function||((l=this.findChildByProperty(d))?(l.setField(d,!0),l.setValue(s)):(a=new k(this.editor,{field:d,value:s}),l=i<this.getMaxVisibleChilds(),this.appendChild(a,l,!1))),i++);!(this.value="")===this.editor.options.sortObjectKeys&&this.sort([],"asc",!1)}else this.hideChilds(),delete this.append,delete this.showMore,delete this.expanded,delete this.childs,this.value=e;Array.isArray(c)!==Array.isArray(this.childs)&&this.recreateDom(),this.updateDom({updateIndexes:!0}),this.previousValue=this.value}},{key:"setInternalValue",value:function(e){var t,n,i,o,r,s=this.childs;if(this.type=e.type,"array"===e.type){for(this.childs||(this.childs=[]),o=0;o<e.childs.length;o++)void 0===(t=e.childs[o])||t instanceof Function||(o<this.childs.length?((n=this.childs[o]).fieldEditable=!1,n.index=o,n.setInternalValue(t)):(n=new k(this.editor,{internalValue:t}),i=o<this.getMaxVisibleChilds(),this.appendChild(n,i,!1)));for(r=this.childs.length;r>=e.childs.length;r--)this.removeChild(this.childs[r],!1)}else if("object"===e.type){for(this.childs||(this.childs=[]),o=0;o<e.childs.length;o++)void 0===(t=e.childs[o])||t instanceof Function||(o<this.childs.length?(delete(n=this.childs[o]).index,n.setField(t.field,!0),n.setInternalValue(t.value)):(n=new k(this.editor,{field:t.field,internalValue:t.value}),i=o<this.getMaxVisibleChilds(),this.appendChild(n,i,!1)));for(r=this.childs.length;r>=e.childs.length;r--)this.removeChild(this.childs[r],!1)}else this.hideChilds(),delete this.append,delete this.showMore,delete this.expanded,delete this.childs,this.value=e.value;Array.isArray(s)!==Array.isArray(this.childs)&&this.recreateDom(),this.updateDom({updateIndexes:!0}),this.previousValue=this.value}},{key:"recreateDom",value:function(){var e;this.dom&&this.dom.tr&&this.dom.tr.parentNode?(e=this._detachFromDom(),this.clearDom(),this._attachToDom(e)):this.clearDom()}},{key:"getValue",value:function(){if("array"===this.type){var t=[];return this.childs.forEach(function(e){t.push(e.getValue())}),t}if("object"!==this.type)return void 0===this.value&&this._getDomValue(),this.value;var n={};return this.childs.forEach(function(e){n[e.getField()]=e.getValue()}),n}},{key:"getInternalValue",value:function(){return"array"===this.type?{type:this.type,childs:this.childs.map(function(e){return e.getInternalValue()})}:"object"===this.type?{type:this.type,childs:this.childs.map(function(e){return{field:e.getField(),value:e.getInternalValue()}})}:(void 0===this.value&&this._getDomValue(),{type:this.type,value:this.value})}},{key:"getLevel",value:function(){return this.parent?this.parent.getLevel()+1:0}},{key:"getNodePath",value:function(){var e=this.parent?this.parent.getNodePath():[];return e.push(this),e}},{key:"clone",value:function(){var t,n=new k(this.editor);return n.type=this.type,n.field=this.field,n.fieldInnerText=this.fieldInnerText,n.fieldEditable=this.fieldEditable,n.previousField=this.previousField,n.value=this.value,n.valueInnerText=this.valueInnerText,n.previousValue=this.previousValue,n.expanded=this.expanded,n.visibleChilds=this.visibleChilds,this.childs?(t=[],this.childs.forEach(function(e){e=e.clone();e.setParent(n),t.push(e)}),n.childs=t):n.childs=void 0,n}},{key:"expand",value:function(t){this.childs&&(this.expanded=!0,this.dom.expand&&(this.dom.expand.className="jsoneditor-button jsoneditor-expanded"),this.showChilds(),!1!==t&&this.childs.forEach(function(e){e.expand(t)}),this.updateDom({recurse:!1}))}},{key:"collapse",value:function(t){this.childs&&(this.hideChilds(),!1!==t&&this.childs.forEach(function(e){e.collapse(t)}),this.dom.expand&&(this.dom.expand.className="jsoneditor-button jsoneditor-collapsed"),this.expanded=!1,this.updateDom({recurse:!1}))}},{key:"showChilds",value:function(){var e=this.childs;if(e&&this.expanded){var t=this.dom.tr,n=t?t.parentNode:void 0;if(n){e=this.getAppendDom();e.parentNode||((o=t.nextSibling)?n.insertBefore(e,o):n.appendChild(e));for(var i=Math.min(this.childs.length,this.visibleChilds),o=this._getNextTr(),r=0;r<i;r++){var s=this.childs[r];s.getDom().parentNode||n.insertBefore(s.getDom(),o),s.showChilds()}e=this.getShowMoreDom();o=this._getNextTr(),e.parentNode||n.insertBefore(e,o),this.showMore.updateDom()}}}},{key:"_getNextTr",value:function(){return this.showMore&&this.showMore.getDom().parentNode?this.showMore.getDom():this.append&&this.append.getDom().parentNode?this.append.getDom():void 0}},{key:"hide",value:function(e){var t=this.dom.tr,n=t?t.parentNode:void 0;n&&n.removeChild(t),this.dom.popupAnchor&&this.dom.popupAnchor.destroy(),this.hideChilds(e)}},{key:"hideChilds",value:function(e){var t;this.childs&&this.expanded&&((t=this.getAppendDom()).parentNode&&t.parentNode.removeChild(t),this.childs.forEach(function(e){e.hide()}),(t=this.getShowMoreDom()).parentNode&&t.parentNode.removeChild(t),e&&!e.resetVisibleChilds||(this.visibleChilds=this.getMaxVisibleChilds()))}},{key:"_updateCssClassName",value:function(){var e;this.dom.field&&this.editor&&this.editor.options&&"function"==typeof this.editor.options.onClassName&&this.dom.tree&&(Object(N.removeAllClassNames)(this.dom.tree),e=this.editor.options.onClassName({path:this.getPath(),field:this.field,value:this.value})||"",Object(N.addClassName)(this.dom.tree,"jsoneditor-values "+e))}},{key:"recursivelyUpdateCssClassesOnNodes",value:function(){if(this._updateCssClassName(),Array.isArray(this.childs))for(var e=0;e<this.childs.length;e++)this.childs[e].recursivelyUpdateCssClassesOnNodes()}},{key:"expandTo",value:function(){for(var e=this.parent;e;)e.expanded||e.expand(),e=e.parent}},{key:"appendChild",value:function(e,t,n){var i,o;this._hasChilds()&&(e.setParent(this),e.fieldEditable="object"===this.type,"array"===this.type&&(e.index=this.childs.length),"object"===this.type&&void 0===e.field&&e.setField(""),this.childs.push(e),this.expanded&&!1!==t&&(i=e.getDom(),t=(o=this._getNextTr())?o.parentNode:void 0,o&&t&&t.insertBefore(i,o),e.showChilds(),this.visibleChilds++),!1!==n&&(this.updateDom({updateIndexes:!0}),e.updateDom({recurse:!0})))}},{key:"moveBefore",value:function(e,t,n){var i,o,r;this._hasChilds()&&((i=this.dom.tr?this.dom.tr.parentNode:void 0)&&((o=document.createElement("tr")).style.height=i.clientHeight+"px",i.appendChild(o)),e.parent&&e.parent.removeChild(e),t instanceof I||!t?this.childs.length+1>this.visibleChilds?(r=this.childs[this.visibleChilds-1],this.insertBefore(e,r,n)):this.appendChild(e,!0,n):this.insertBefore(e,t,n),i&&o&&i.removeChild(o))}},{key:"insertBefore",value:function(e,t,n){if(this._hasChilds()){if(this.visibleChilds++,"object"===this.type&&void 0===e.field&&e.setField(""),t===this.append)e.setParent(this),e.fieldEditable="object"===this.type,this.childs.push(e);else{var i=this.childs.indexOf(t);if(-1===i)throw new Error("Node not found");e.setParent(this),e.fieldEditable="object"===this.type,this.childs.splice(i,0,e)}var o;this.expanded&&(o=e.getDom(),t=(i=t.getDom())?i.parentNode:void 0,i&&t&&t.insertBefore(o,i),e.showChilds(),this.showChilds()),!1!==n&&(this.updateDom({updateIndexes:!0}),e.updateDom({recurse:!0}))}}},{key:"insertAfter",value:function(e,t){this._hasChilds()&&(t=this.childs.indexOf(t),(t=this.childs[t+1])?this.insertBefore(e,t):this.appendChild(e))}},{key:"search",value:function(t,n){Array.isArray(n)||(n=[]);var e=t?t.toLowerCase():void 0;return delete this.searchField,delete this.searchValue,void 0!==this.field&&n.length<=this.MAX_SEARCH_RESULTS&&(-1!==String(this.field).toLowerCase().indexOf(e)&&(this.searchField=!0,n.push({node:this,elem:"field"})),this._updateDomField()),this._hasChilds()?this.childs&&this.childs.forEach(function(e){e.search(t,n)}):void 0!==this.value&&n.length<=this.MAX_SEARCH_RESULTS&&(-1!==String(this.value).toLowerCase().indexOf(e)&&(this.searchValue=!0,n.push({node:this,elem:"value"})),this._updateDomValue()),n}},{key:"scrollTo",value:function(e){this.expandPathToNode(),this.dom.tr&&this.dom.tr.parentNode&&this.editor.scrollTo(this.dom.tr.offsetTop,e)}},{key:"expandPathToNode",value:function(){for(var e=this;e&&e.parent;){for(var t="array"===e.parent.type?e.index:e.parent.childs.indexOf(e);e.parent.visibleChilds<t+1;)e.parent.visibleChilds+=this.getMaxVisibleChilds();e.parent.expand(!1),e=e.parent}}},{key:"focus",value:function(e){if(k.focusElement=e,this.dom.tr&&this.dom.tr.parentNode){var t=this.dom;switch(e){case"drag":(t.drag||t.menu).focus();break;case"menu":t.menu.focus();break;case"expand":this._hasChilds()?t.expand.focus():t.field&&this.fieldEditable?(t.field.focus(),Object(N.selectContentEditable)(t.field)):t.value&&!this._hasChilds()?(t.value.focus(),Object(N.selectContentEditable)(t.value)):t.menu.focus();break;case"field":t.field&&this.fieldEditable?(t.field.focus(),Object(N.selectContentEditable)(t.field)):t.value&&!this._hasChilds()?(t.value.focus(),Object(N.selectContentEditable)(t.value)):(this._hasChilds()?t.expand:t.menu).focus();break;case"value":default:t.select?t.select.focus():t.value&&!this._hasChilds()?(t.value.focus(),Object(N.selectContentEditable)(t.value)):t.field&&this.fieldEditable?(t.field.focus(),Object(N.selectContentEditable)(t.field)):(this._hasChilds()?t.expand:t.menu).focus()}}}},{key:"containsNode",value:function(e){if(this===e)return!0;var t=this.childs;if(t)for(var n=0,i=t.length;n<i;n++)if(t[n].containsNode(e))return!0;return!1}},{key:"removeChild",value:function(e,t){if(this.childs){var n=this.childs.indexOf(e);if(-1!==n){n<this.visibleChilds&&this.expanded&&this.visibleChilds--,e.hide(),delete e.searchField,delete e.searchValue;n=this.childs.splice(n,1)[0];return n.parent=null,!1!==t&&this.updateDom({updateIndexes:!0}),n}}}},{key:"_remove",value:function(e){this.removeChild(e)}},{key:"changeType",value:function(e){var t,n=this.type;n!==e&&("string"!==e&&"auto"!==e||"string"!==n&&"auto"!==n?(t=this._detachFromDom(),this.clearDom(),"object"===(this.type=e)?(this.childs||(this.childs=[]),this.childs.forEach(function(e){e.clearDom(),delete e.index,e.fieldEditable=!0,void 0===e.field&&(e.field="")}),"string"!==n&&"auto"!==n||(this.expanded=!0)):"array"===e?(this.childs||(this.childs=[]),this.childs.forEach(function(e,t){e.clearDom(),e.fieldEditable=!1,e.index=t}),"string"!==n&&"auto"!==n||(this.expanded=!0)):this.expanded=!1,this._attachToDom(t)):this.type=e,"auto"!==e&&"string"!==e||(this.value="string"===e?String(this.value):Object(N.parseString)(String(this.value)),this.focus()),this.updateDom({updateIndexes:!0}))}},{key:"deepEqual",value:function(e){var t;if("array"===this.type){if(!Array.isArray(e))return!1;if(this.childs.length!==e.length)return!1;for(t=0;t<this.childs.length;t++)if(!this.childs[t].deepEqual(e[t]))return!1}else if("object"===this.type){if("object"!==v(e)||!e)return!1;var n=Object.keys(e);if(this.childs.length!==n.length)return!1;for(t=0;t<n.length;t++){var i=this.childs[t];if(i.field!==n[t]||!i.deepEqual(e[i.field]))return!1}}else if(this.value!==e)return!1;return!0}},{key:"_getDomValue",value:function(){if(this._clearValueError(),this.dom.value&&"array"!==this.type&&"object"!==this.type&&(this.valueInnerText=Object(N.getInnerText)(this.dom.value),""===this.valueInnerText&&""!==this.dom.value.innerHTML&&(this.dom.value.textContent="")),void 0!==this.valueInnerText)try{var e;(e="string"===this.type?this._unescapeHTML(this.valueInnerText):(e=this._unescapeHTML(this.valueInnerText),Object(N.parseString)(e)))!==this.value&&(this.value=e,this._debouncedOnChangeValue())}catch(e){this._setValueError(Object(l.c)("cannotParseValueError"))}}},{key:"_setValueError",value:function(e){this.valueError={message:e},this.updateError()}},{key:"_clearValueError",value:function(){this.valueError&&(this.valueError=null,this.updateError())}},{key:"_setFieldError",value:function(e){this.fieldError={message:e},this.updateError()}},{key:"_clearFieldError",value:function(){this.fieldError&&(this.fieldError=null,this.updateError())}},{key:"_onChangeValue",value:function(){var e=this.editor.getDomSelection();e.range&&(t=Object(N.textDiff)(String(this.value),String(this.previousValue)),e.range.startOffset=t.start,e.range.endOffset=t.end);var t,n=this.editor.getDomSelection();n.range&&(t=Object(N.textDiff)(String(this.previousValue),String(this.value)),n.range.startOffset=t.start,n.range.endOffset=t.end),this.editor._onAction("editValue",{path:this.getInternalPath(),oldValue:this.previousValue,newValue:this.value,oldSelection:e,newSelection:n}),this.previousValue=this.value}},{key:"_onChangeField",value:function(){var e=this.editor.getDomSelection(),t=this.previousField||"";e.range&&(n=Object(N.textDiff)(this.field,t),e.range.startOffset=n.start,e.range.endOffset=n.end);var n=this.editor.getDomSelection();n.range&&(t=Object(N.textDiff)(t,this.field),n.range.startOffset=t.start,n.range.endOffset=t.end),this.editor._onAction("editField",{parentPath:this.parent.getInternalPath(),index:this.getIndex(),oldValue:this.previousField,newValue:this.field,oldSelection:e,newSelection:n}),this.previousField=this.field}},{key:"_updateDomValue",value:function(){var e=this.dom.value;if(e){var t=["jsoneditor-value"],n=this.value,i="auto"===this.type?Object(N.getType)(n):this.type,o="string"===i&&Object(N.isUrl)(n);if(t.push("jsoneditor-"+i),o&&t.push("jsoneditor-url"),""===String(this.value)&&"array"!==this.type&&"object"!==this.type&&t.push("jsoneditor-empty"),this.searchValueActive&&t.push("jsoneditor-highlight-active"),this.searchValue&&t.push("jsoneditor-highlight"),e.className=t.join(" "),"array"===i||"object"===i?(t=this.childs?this.childs.length:0,e.title=this.type+" containing "+t+" items"):o&&this.editable.value?e.title=Object(l.c)("openUrl"):e.title="","boolean"===i&&this.editable.value?(this.dom.checkbox||(this.dom.checkbox=document.createElement("input"),this.dom.checkbox.type="checkbox",this.dom.tdCheckbox=document.createElement("td"),this.dom.tdCheckbox.className="jsoneditor-tree",this.dom.tdCheckbox.appendChild(this.dom.checkbox),this.dom.tdValue.parentNode.insertBefore(this.dom.tdCheckbox,this.dom.tdValue)),this.dom.checkbox.checked=this.value):this.dom.tdCheckbox&&(this.dom.tdCheckbox.parentNode.removeChild(this.dom.tdCheckbox),delete this.dom.tdCheckbox,delete this.dom.checkbox),this.enum&&this.editable.value){if(!this.dom.select){this.dom.select=document.createElement("select"),this.id=this.field+"_"+(new Date).getUTCMilliseconds(),this.dom.select.id=this.id,this.dom.select.name=this.dom.select.id;var r=document.createElement("option");r.value="",r.textContent="--",this.dom.select.appendChild(r);for(var s=0;s<this.enum.length;s++){var a=document.createElement("option");a.value=this.enum[s],a.textContent=this.enum[s],this.dom.select.appendChild(a)}this.dom.tdSelect=document.createElement("td"),this.dom.tdSelect.className="jsoneditor-tree",this.dom.tdSelect.appendChild(this.dom.select),this.dom.tdValue.parentNode.insertBefore(this.dom.tdSelect,this.dom.tdValue)}this.dom.select.value=-1!==this.enum.indexOf(this.value)?this.value:"",!this.schema||C(this.schema,"oneOf")||C(this.schema,"anyOf")||C(this.schema,"allOf")?delete this.valueFieldHTML:(this.valueFieldHTML=this.dom.tdValue.innerHTML,this.dom.tdValue.style.visibility="hidden",this.dom.tdValue.textContent="")}else this.dom.tdSelect&&(this.dom.tdSelect.parentNode.removeChild(this.dom.tdSelect),delete this.dom.tdSelect,delete this.dom.select,this.dom.tdValue.innerHTML=this.valueFieldHTML,this.dom.tdValue.style.visibility="",delete this.valueFieldHTML);if(this.editable.value&&this.editor.options.colorPicker&&"string"==typeof n&&Object(N.isValidColor)(n)?(this.dom.color||(this.dom.color=document.createElement("div"),this.dom.color.className="jsoneditor-color",this.dom.tdColor=document.createElement("td"),this.dom.tdColor.className="jsoneditor-tree",this.dom.tdColor.appendChild(this.dom.color),this.dom.tdValue.parentNode.insertBefore(this.dom.tdColor,this.dom.tdValue)),Object(N.addClassName)(this.dom.value,"jsoneditor-color-value"),this.dom.color.style.backgroundColor=n):this._deleteDomColor(),this._showTimestampTag()){this.dom.date||(this.dom.date=document.createElement("div"),this.dom.date.className="jsoneditor-date",this.dom.value.parentNode.appendChild(this.dom.date));r=null;if("function"==typeof this.editor.options.timestampFormat&&(r=this.editor.options.timestampFormat({field:this.field,value:this.value,path:this.getPath()})),r){for(;this.dom.date.firstChild;)this.dom.date.removeChild(this.dom.date.firstChild);this.dom.date.appendChild(document.createTextNode(r))}else this.dom.date.textContent=new Date(n).toISOString();this.dom.date.title=new Date(n).toString()}else this.dom.date&&(this.dom.date.parentNode.removeChild(this.dom.date),delete this.dom.date);Object(N.stripFormatting)(e),this._updateDomDefault()}}},{key:"_deleteDomColor",value:function(){this.dom.color&&(this.dom.tdColor.parentNode.removeChild(this.dom.tdColor),delete this.dom.tdColor,delete this.dom.color,Object(N.removeClassName)(this.dom.value,"jsoneditor-color-value"))}},{key:"_updateDomField",value:function(){var e,t=this.dom.field;t&&((e=Object(N.makeFieldTooltip)(this.schema,this.editor.options.language))&&(t.title=e),(""===String(this.field)&&this.parent&&"array"!==this.parent.type?Object(N.addClassName):Object(N.removeClassName))(t,"jsoneditor-empty"),(this.searchFieldActive?Object(N.addClassName):Object(N.removeClassName))(t,"jsoneditor-highlight-active"),(this.searchField?Object(N.addClassName):Object(N.removeClassName))(t,"jsoneditor-highlight"),Object(N.stripFormatting)(t))}},{key:"_getDomField",value:function(e){if(this._clearFieldError(),this.dom.field&&this.fieldEditable&&(this.fieldInnerText=Object(N.getInnerText)(this.dom.field),""===this.fieldInnerText&&""!==this.dom.field.innerHTML&&(this.dom.field.textContent="")),void 0!==this.fieldInnerText)try{var t=this._unescapeHTML(this.fieldInnerText),n=this.parent.getFieldNames(this);-1!==n.indexOf(t)?e?(t=Object(N.findUniqueName)(t,n))!==this.field&&(this.field=t,this._debouncedOnChangeField()):this._setFieldError(Object(l.c)("duplicateFieldError")):t!==this.field&&(this.field=t,this._debouncedOnChangeField())}catch(e){this._setFieldError(Object(l.c)("cannotParseFieldError"))}}},{key:"_updateDomDefault",value:function(){var e;!this.schema||void 0===this.schema.default||this._hasChilds()||(e=this.dom.select||this.dom.value)&&(this.value===this.schema.default?(e.title=Object(l.c)("default"),Object(N.addClassName)(e,"jsoneditor-is-default"),Object(N.removeClassName)(e,"jsoneditor-is-not-default")):(e.removeAttribute("title"),Object(N.removeClassName)(e,"jsoneditor-is-default"),Object(N.addClassName)(e,"jsoneditor-is-not-default")))}},{key:"_showTimestampTag",value:function(){if("number"!=typeof this.value)return!1;var e=this.editor.options.timestampTag;if("function"!=typeof e)return!0===e&&Object(N.isTimestamp)(this.field,this.value);e=e({field:this.field,value:this.value,path:this.getPath()});return"boolean"==typeof e?e:Object(N.isTimestamp)(this.field,this.value)}},{key:"clearDom",value:function(){this.dom={}}},{key:"getDom",value:function(){var e,t=this.dom;if(t.tr)return t.tr;this._updateEditability(),t.tr=document.createElement("tr"),"tree"===(t.tr.node=this).editor.options.mode&&(e=document.createElement("td"),this.editable.field&&this.parent&&((n=document.createElement("button")).type="button",(t.drag=n).className="jsoneditor-button jsoneditor-dragarea",n.title=Object(l.c)("drag"),e.appendChild(n)),t.tr.appendChild(e),n=document.createElement("td"),(e=document.createElement("button")).type="button",(t.menu=e).className="jsoneditor-button jsoneditor-contextmenu-button",e.title=Object(l.c)("actionsMenu"),n.appendChild(t.menu),t.tr.appendChild(n));var n=document.createElement("td");return t.tr.appendChild(n),t.tree=this._createDomTree(),n.appendChild(t.tree),this.updateDom({updateIndexes:!0}),t.tr}},{key:"isVisible",value:function(){return this.dom&&this.dom.tr&&this.dom.tr.parentNode||!1}},{
key:"isDescendantOf",value:function(e){for(var t=this.parent;t;){if(t===e)return!0;t=t.parent}return!1}},{key:"_createDomField",value:function(){return document.createElement("div")}},{key:"setHighlight",value:function(t){this.dom.tr&&((t?Object(N.addClassName):Object(N.removeClassName))(this.dom.tr,"jsoneditor-highlight"),this.append&&this.append.setHighlight(t),this.childs&&this.childs.forEach(function(e){e.setHighlight(t)}))}},{key:"setSelected",value:function(t,e){this.selected=t,this.dom.tr&&((t?Object(N.addClassName):Object(N.removeClassName))(this.dom.tr,"jsoneditor-selected"),(e?Object(N.addClassName):Object(N.removeClassName))(this.dom.tr,"jsoneditor-first"),this.append&&this.append.setSelected(t),this.showMore&&this.showMore.setSelected(t),this.childs&&this.childs.forEach(function(e){e.setSelected(t)}))}},{key:"updateValue",value:function(e){this.value=e,this.previousValue=e,this.valueError=void 0,this.updateDom()}},{key:"updateField",value:function(e){this.field=e,this.previousField=e,this.fieldError=void 0,this.updateDom()}},{key:"updateDom",value:function(t){var e=this.dom.tree;e&&(e.style.marginLeft=24*this.getLevel()+"px");e=this.dom.field;e&&(this.fieldEditable?(e.contentEditable=this.editable.field,e.spellcheck=!1,e.className="jsoneditor-field"):(e.contentEditable=!1,e.className="jsoneditor-readonly"),n=void 0!==this.index?this.index:void 0!==this.field?this.field:(n=this.editor.options.schema?k._findSchema(this.editor.options.schema,this.editor.options.schemaRefs||{},this.getPath()):void 0)&&n.title?n.title:this._hasChilds()?this.type:"",n=this._escapeHTML(n),document.activeElement===e&&n===this._unescapeHTML(Object(N.getInnerText)(e))||(e.innerHTML=n),this._updateSchema());var n=this.dom.value;n&&("array"===this.type||"object"===this.type?this.updateNodeName():(i=this._escapeHTML(this.value),document.activeElement===n&&i===this._unescapeHTML(Object(N.getInnerText)(n))||(n.innerHTML=i)));var i=this.dom.tr;i&&("array"===this.type||"object"===this.type?(Object(N.addClassName)(i,"jsoneditor-expandable"),this.expanded?(Object(N.addClassName)(i,"jsoneditor-expanded"),Object(N.removeClassName)(i,"jsoneditor-collapsed")):(Object(N.addClassName)(i,"jsoneditor-collapsed"),Object(N.removeClassName)(i,"jsoneditor-expanded"))):(Object(N.removeClassName)(i,"jsoneditor-expandable"),Object(N.removeClassName)(i,"jsoneditor-expanded"),Object(N.removeClassName)(i,"jsoneditor-collapsed"))),this._updateDomField(),this._updateDomValue(),t&&!0===t.updateIndexes&&this._updateDomIndexes(),t&&!0===t.recurse&&this.childs&&this.childs.forEach(function(e){e.updateDom(t)}),this.error&&this.updateError(),this.append&&this.append.updateDom(),this.showMore&&this.showMore.updateDom(),this._updateCssClassName()}},{key:"_updateSchema",value:function(){this.editor&&this.editor.options&&(this.schema=this.editor.options.schema?k._findSchema(this.editor.options.schema,this.editor.options.schemaRefs||{},this.getPath()):null,this.schema?this.enum=k._findEnum(this.schema):delete this.enum)}},{key:"_updateDomIndexes",value:function(){var e=this.dom.value,t=this.childs;e&&t&&("array"===this.type?t.forEach(function(e,t){e.index=t;e=e.dom.field;e&&(e.textContent=t)}):"object"===this.type&&t.forEach(function(e){void 0!==e.index&&(delete e.index,void 0===e.field&&(e.field=""))}))}},{key:"_createDomValue",value:function(){var e;return"array"===this.type?(e=document.createElement("div")).textContent="[...]":"object"===this.type?(e=document.createElement("div")).textContent="{...}":(!this.editable.value&&Object(N.isUrl)(this.value)?(e=document.createElement("a")).href=this.value:((e=document.createElement("div")).contentEditable=this.editable.value,e.spellcheck=!1),e.innerHTML=this._escapeHTML(this.value)),e}},{key:"_createDomExpandButton",value:function(){var e=document.createElement("button");return e.type="button",this._hasChilds()?(e.className=this.expanded?"jsoneditor-button jsoneditor-expanded":"jsoneditor-button jsoneditor-collapsed",e.title=Object(l.c)("expandTitle")):(e.className="jsoneditor-button jsoneditor-invisible",e.title=""),e}},{key:"_createDomTree",value:function(){var e=this.dom,t=document.createElement("table"),n=document.createElement("tbody");t.style.borderCollapse="collapse",t.className="jsoneditor-values",t.appendChild(n);var i=document.createElement("tr");n.appendChild(i);n=document.createElement("td");n.className="jsoneditor-tree",i.appendChild(n),e.expand=this._createDomExpandButton(),n.appendChild(e.expand),e.tdExpand=n;n=document.createElement("td");n.className="jsoneditor-tree",i.appendChild(n),e.field=this._createDomField(),n.appendChild(e.field),e.tdField=n;n=document.createElement("td");n.className="jsoneditor-tree",i.appendChild(n),"object"!==this.type&&"array"!==this.type&&(n.appendChild(document.createTextNode(":")),n.className="jsoneditor-separator"),e.tdSeparator=n;n=document.createElement("td");return n.className="jsoneditor-tree",i.appendChild(n),e.value=this._createDomValue(),n.appendChild(e.value),e.tdValue=n,t}},{key:"onEvent",value:function(e){var t,n=e.type,i=e.target||e.srcElement,o=this.dom,r=this,s=this._hasChilds();i!==o.drag&&i!==o.menu||("mouseover"===n?this.editor.highlighter.highlight(this):"mouseout"===n&&this.editor.highlighter.unhighlight()),"click"===n&&i===o.menu&&((t=r.editor.highlighter).highlight(r),t.lock(),Object(N.addClassName)(o.menu,"jsoneditor-selected"),this.showContextMenu(o.menu,function(){Object(N.removeClassName)(o.menu,"jsoneditor-selected"),t.unlock(),t.unhighlight()})),"click"===n&&i===o.expand&&s&&(h=e.ctrlKey,this._onExpand(h)),"click"!==n||e.target!==r.dom.tdColor&&e.target!==r.dom.color||this._showColorPicker(),"change"===n&&i===o.checkbox&&(this.dom.value.textContent=String(!this.value),this._getDomValue(),this._updateDomDefault()),"change"===n&&i===o.select&&(this.dom.value.innerHTML=this._escapeHTML(o.select.value),this._getDomValue(),this._updateDomValue());var a=o.value;if(i===a)switch(n){case"blur":case"change":this._getDomValue(),this._clearValueError(),this._updateDomValue();var l=this._escapeHTML(this.value);l!==this._unescapeHTML(Object(N.getInnerText)(a))&&(a.innerHTML=l);break;case"input":this._getDomValue(),this._updateDomValue();break;case"keydown":case"mousedown":this.editor.selection=this.editor.getDomSelection();break;case"click":e.ctrlKey&&this.editable.value&&Object(N.isUrl)(this.value)&&(e.preventDefault(),window.open(this.value,"_blank","noopener"));break;case"keyup":this._getDomValue(),this._updateDomValue();break;case"cut":case"paste":setTimeout(function(){r._getDomValue(),r._updateDomValue()},1)}var c=o.field;if(i===c)switch(n){case"blur":this._getDomField(!0),this._updateDomField();var d=this._escapeHTML(this.field);d!==this._unescapeHTML(Object(N.getInnerText)(c))&&(c.innerHTML=d);break;case"input":this._getDomField(),this._updateSchema(),this._updateDomField(),this._updateDomValue();break;case"keydown":case"mousedown":this.editor.selection=this.editor.getDomSelection();break;case"keyup":this._getDomField(),this._updateDomField();break;case"cut":case"paste":setTimeout(function(){r._getDomField(),r._updateDomField()},1)}var h=o.tree;h&&i===h.parentNode&&"click"===n&&!e.hasMoved&&((void 0!==e.offsetX?e.offsetX<24*(this.getLevel()+1):e.pageX<Object(N.getAbsoluteLeft)(o.tdSeparator))||s?c&&(Object(N.setEndOfContentEditable)(c),c.focus()):a&&!this.enum&&(Object(N.setEndOfContentEditable)(a),a.focus())),(i!==o.tdExpand||s)&&i!==o.tdField&&i!==o.tdSeparator||"click"!==n||e.hasMoved||c&&(Object(N.setEndOfContentEditable)(c),c.focus()),"keydown"===n&&this.onKeyDown(e),"function"==typeof this.editor.options.onEvent&&this._onEvent(e)}},{key:"_onEvent",value:function(e){var t=e.target,n=t===this.dom.field,t=t===this.dom.value||t===this.dom.checkbox||t===this.dom.select;(n||t)&&(n={field:this.getField(),path:this.getPath()},t&&!this._hasChilds()&&(n.value=this.getValue()),this.editor.options.onEvent(n,e))}},{key:"onKeyDown",value:function(e){var t,n,i,o,r,s,a,l,c,d,h,u,p,f,m,g,v,y=e.which||e.keyCode,b=e.target||e.srcElement,x=e.ctrlKey,C=e.shiftKey,E=e.altKey,_=!1,T="tree"===this.editor.options.mode,w=0<this.editor.multiselection.nodes.length?this.editor.multiselection.nodes:[this],S=w[0],j=w[w.length-1];13===y?b===this.dom.value?this.editable.value&&!e.ctrlKey||Object(N.isUrl)(this.value)&&(window.open(this.value,"_blank","noopener"),_=!0):b===this.dom.expand&&this._hasChilds()&&(u=e.ctrlKey,this._onExpand(u),b.focus(),_=!0):68===y?x&&T&&(k.onDuplicate(w),_=!0):69===y?x&&(this._onExpand(C),b.focus(),_=!0):77===y&&T?x&&(this.showContextMenu(b),_=!0):46===y&&T?x&&(k.onRemove(w),_=!0):45===y&&T?x&&!C?(this._onInsertBefore(),_=!0):x&&C&&(this._onInsertAfter(),_=!0):35===y?E&&((u=this._lastNode())&&u.focus(k.focusElement||this._getElementName(b)),_=!0):36===y?E&&((p=this._firstNode())&&p.focus(k.focusElement||this._getElementName(b)),_=!0):37===y?E&&!C?((p=this._previousElement(b))&&this.focus(this._getElementName(p)),_=!0):E&&C&&T&&(f=j.expanded?(f=j.getAppendDom())?f.nextSibling:void 0:j.getDom().nextSibling)&&(n=k.getNodeFromTarget(f),f=f.nextSibling,m=k.getNodeFromTarget(f),n&&n instanceof I&&1!==j.parent.childs.length&&m&&m.parent&&(i=this.editor.getDomSelection(),o=(r=S.parent).childs[j.getIndex()+1]||r.append,s=S.getIndex(),a=m.getIndex(),l=r.getInternalPath(),c=m.parent.getInternalPath(),w.forEach(function(e){m.parent.moveBefore(e,m)}),this.focus(k.focusElement||this._getElementName(b)),this.editor._onAction("moveNodes",{count:w.length,fieldNames:w.map(O),oldParentPath:r.getInternalPath(),newParentPath:S.parent.getInternalPath(),oldIndex:o.getIndex(),newIndex:S.getIndex(),oldIndexRedo:s,newIndexRedo:a,oldParentPathRedo:l,newParentPathRedo:c,oldSelection:i,newSelection:this.editor.getDomSelection()}))):38===y?E&&!C?((t=this._previousNode())&&(this.editor.deselect(!0),t.focus(k.focusElement||this._getElementName(b))),_=!0):!E&&x&&C&&T?((t=this._previousNode())&&((h=this.editor.multiselection).start=h.start||this,h.end=t,d=this.editor._findTopLevelNodes(h.start,h.end),this.editor.select(d),t.focus("field")),_=!0):E&&C&&T&&((t=S._previousNode())&&t.parent&&(i=this.editor.getDomSelection(),o=(r=S.parent).childs[j.getIndex()+1]||r.append,s=S.getIndex(),a=t.getIndex(),l=r.getInternalPath(),c=t.parent.getInternalPath(),w.forEach(function(e){t.parent.moveBefore(e,t)}),this.focus(k.focusElement||this._getElementName(b)),this.editor._onAction("moveNodes",{count:w.length,fieldNames:w.map(O),oldParentPath:r.getInternalPath(),newParentPath:S.parent.getInternalPath(),oldIndex:o.getIndex(),newIndex:S.getIndex(),oldIndexRedo:s,newIndexRedo:a,oldParentPathRedo:l,newParentPathRedo:c,oldSelection:i,newSelection:this.editor.getDomSelection()})),_=!0):39===y?E&&!C?((g=this._nextElement(b))&&this.focus(this._getElementName(g)),_=!0):E&&C&&T&&((g=S.getDom().previousSibling)&&(t=k.getNodeFromTarget(g))&&t.parent&&!t.isVisible()&&(i=this.editor.getDomSelection(),o=(r=S.parent).childs[j.getIndex()+1]||r.append,s=S.getIndex(),a=t.getIndex(),l=r.getInternalPath(),c=t.parent.getInternalPath(),w.forEach(function(e){t.parent.moveBefore(e,t)}),this.focus(k.focusElement||this._getElementName(b)),this.editor._onAction("moveNodes",{count:w.length,fieldNames:w.map(O),oldParentPath:r.getInternalPath(),newParentPath:S.parent.getInternalPath(),oldIndex:o.getIndex(),newIndex:S.getIndex(),oldIndexRedo:s,newIndexRedo:a,oldParentPathRedo:l,newParentPathRedo:c,oldSelection:i,newSelection:this.editor.getDomSelection()}))):40===y&&(E&&!C?((n=this._nextNode())&&(this.editor.deselect(!0),n.focus(k.focusElement||this._getElementName(b))),_=!0):!E&&x&&C&&T?((n=this._nextNode())&&((h=this.editor.multiselection).start=h.start||this,h.end=n,d=this.editor._findTopLevelNodes(h.start,h.end),this.editor.select(d),n.focus("field")),_=!0):E&&C&&T&&((n=j.expanded?j.append?j.append._nextNode():void 0:j._nextNode())&&!n.isVisible()&&(n=n.parent.showMore),n&&n instanceof I&&(n=j),(v=n&&(n._nextNode()||n.parent.append))&&v.parent&&(i=this.editor.getDomSelection(),o=(r=S.parent).childs[j.getIndex()+1]||r.append,s=S.getIndex(),a=v.getIndex(),l=r.getInternalPath(),c=v.parent.getInternalPath(),w.forEach(function(e){v.parent.moveBefore(e,v)}),this.focus(k.focusElement||this._getElementName(b)),this.editor._onAction("moveNodes",{count:w.length,fieldNames:w.map(O),oldParentPath:r.getInternalPath(),newParentPath:S.parent.getInternalPath(),oldParentPathRedo:l,newParentPathRedo:c,oldIndexRedo:s,newIndexRedo:a,oldIndex:o.getIndex(),newIndex:S.getIndex(),oldSelection:i,newSelection:this.editor.getDomSelection()})),_=!0)),_&&(e.preventDefault(),e.stopPropagation())}},{key:"_onExpand",value:function(e){var t,n,i;e&&(i=(n=(t=this.dom.tr.parentNode).parentNode).scrollTop,n.removeChild(t)),this.expanded?this.collapse(e):this.expand(e),e&&(n.appendChild(t),n.scrollTop=i)}},{key:"_showColorPicker",value:function(){var t,e;"function"==typeof this.editor.options.onColorPicker&&this.dom.color&&((t=this)._deleteDomColor(),t.updateDom(),e=Object(h.a)(this.dom.color,this.editor.getPopupAnchor()),this.editor.options.onColorPicker(e,this.value,function(e){"string"==typeof e&&e!==t.value&&(t._deleteDomColor(),t.value=e,t.updateDom(),t._debouncedOnChangeValue())}))}},{key:"getFieldNames",value:function(t){return"object"===this.type?this.childs.filter(function(e){return e!==t}).map(function(e){return e.field}):[]}},{key:"_onInsertBefore",value:function(e,t,n){var i=this.editor.getDomSelection(),e=new k(this.editor,{field:void 0!==e?e:"",value:void 0!==t?t:"",type:n});e.expand(!0);t=this.getInternalPath();this.parent.insertBefore(e,this),this.editor.highlighter.unhighlight(),e.focus("field");n=this.editor.getDomSelection();this.editor._onAction("insertBeforeNodes",{nodes:[e],paths:[e.getInternalPath()],beforePath:t,parentPath:this.parent.getInternalPath(),oldSelection:i,newSelection:n})}},{key:"_onInsertAfter",value:function(e,t,n){var i=this.editor.getDomSelection(),t=new k(this.editor,{field:void 0!==e?e:"",value:void 0!==t?t:"",type:n});t.expand(!0),this.parent.insertAfter(t,this),this.editor.highlighter.unhighlight(),t.focus("field");n=this.editor.getDomSelection();this.editor._onAction("insertAfterNodes",{nodes:[t],paths:[t.getInternalPath()],afterPath:this.getInternalPath(),parentPath:this.parent.getInternalPath(),oldSelection:i,newSelection:n})}},{key:"_onAppend",value:function(e,t,n){var i=this.editor.getDomSelection(),t=new k(this.editor,{field:void 0!==e?e:"",value:void 0!==t?t:"",type:n});t.expand(!0),this.parent.appendChild(t),this.editor.highlighter.unhighlight(),t.focus("field");n=this.editor.getDomSelection();this.editor._onAction("appendNodes",{nodes:[t],paths:[t.getInternalPath()],parentPath:this.parent.getInternalPath(),oldSelection:i,newSelection:n})}},{key:"_onChangeType",value:function(e){var t,n,i=this.type;e!==i&&(t=this.editor.getDomSelection(),this.changeType(e),n=this.editor.getDomSelection(),this.editor._onAction("changeType",{path:this.getInternalPath(),oldType:i,newType:e,oldSelection:t,newSelection:n}))}},{key:"sort",value:function(n,e,t){var i,o=!(2<arguments.length&&void 0!==t)||t;"string"==typeof n&&(n=Object(N.parsePath)(n)),this._hasChilds()&&(this.hideChilds(),t=this.childs,this.childs=this.childs.concat(),i="desc"===e?-1:1,"object"===this.type?this.childs.sort(function(e,t){return i*d()(e.field,t.field)}):this.childs.sort(function(e,t){e=e.getNestedChild(n),t=t.getNestedChild(n);if(!e)return i;if(!t)return-i;e=e.value,t=t.value;return"string"!=typeof e&&"string"!=typeof t?t<e?i:e<t?-i:0:i*d()(e,t)}),this._updateDomIndexes(),this.showChilds(),!0===o&&this.editor._onAction("sort",{path:this.getInternalPath(),oldChilds:t,newChilds:this.childs}))}},{key:"update",value:function(e){var t=this.getInternalValue();this.setValue(e),this.editor._onAction("transform",{path:this.getInternalPath(),oldValue:t,newValue:this.getInternalValue()})}},{key:"_detachFromDom",value:function(){var e=this.dom.tr?this.dom.tr.parentNode:void 0,t=this.expanded?this.getAppendDom():this.getDom(),t=t&&t.parentNode?t.nextSibling:void 0;return this.hide({resetVisibleChilds:!1}),{table:e,nextTr:t}}},{key:"_attachToDom",value:function(e){e.table&&(e.nextTr?e.table.insertBefore(this.getDom(),e.nextTr):e.table.appendChild(this.getDom())),this.expanded&&this.showChilds()}},{key:"transform",value:function(e){if(this._hasChilds()){this.hideChilds();try{var t=this.getInternalValue(),n=this.getValue(),n=this.editor.options.executeQuery(n,e);this.setValue(n);n=this.getInternalValue();this.editor._onAction("transform",{path:this.getInternalPath(),oldValue:t,newValue:n}),this.showChilds()}catch(e){this.showChilds(),this.editor._onError(e)}}}},{key:"extract",value:function(){this.editor.node.hideChilds(),this.hideChilds();try{var e=this.editor.node.getInternalValue();this.editor._setRoot(this);var t=this.editor.node.getInternalValue();this.editor._onAction("transform",{path:this.editor.node.getInternalPath(),oldValue:e,newValue:t})}catch(e){this.editor._onError(e)}finally{this.updateDom({recurse:!0}),this.showChilds()}}},{key:"getNestedChild",value:function(e){for(var t=0,n=this;n&&t<e.length;)n=n.findChildByProperty(e[t]),t++;return n}},{key:"findChildByProperty",value:function(t){if("object"===this.type)return this.childs.find(function(e){return e.field===t})}},{key:"getAppendDom",value:function(){return this.append||(this.append=new I(this.editor),this.append.setParent(this)),this.append.getDom()}},{key:"getShowMoreDom",value:function(){return this.showMore||(this.showMore=new w(this.editor,this)),this.showMore.getDom()}},{key:"nextSibling",value:function(){var e=this.parent.childs.indexOf(this);return this.parent.childs[e+1]||this.parent.append}},{key:"_previousNode",value:function(){var e=null,t=this.getDom();if(t&&t.parentNode)for(var n=t;n=n.previousSibling,e=k.getNodeFromTarget(n),n&&e&&e instanceof I&&!e.isVisible(););return e}},{key:"_nextNode",value:function(){var e=null,t=this.getDom();if(t&&t.parentNode)for(var n=t;n=n.nextSibling,e=k.getNodeFromTarget(n),n&&e&&e instanceof I&&!e.isVisible(););return e}},{key:"_firstNode",value:function(){var e=null,t=this.getDom();return t&&t.parentNode&&(t=t.parentNode.firstChild,e=k.getNodeFromTarget(t)),e}},{key:"_lastNode",value:function(){var e=null,t=this.getDom();if(t&&t.parentNode)for(var n=t.parentNode.lastChild,e=k.getNodeFromTarget(n);n&&e&&!e.isVisible();)n=n.previousSibling,e=k.getNodeFromTarget(n);return e}},{key:"_previousElement",value:function(e){var t=this.dom;switch(e){case t.value:if(this.fieldEditable)return t.field;case t.field:if(this._hasChilds())return t.expand;case t.expand:return t.menu;case t.menu:if(t.drag)return t.drag;default:return null}}},{key:"_nextElement",value:function(e){var t=this.dom;switch(e){case t.drag:return t.menu;case t.menu:if(this._hasChilds())return t.expand;case t.expand:if(this.fieldEditable)return t.field;case t.field:if(!this._hasChilds())return t.value;default:return null}}},{key:"_getElementName",value:function(t){var n=this;return Object.keys(this.dom).find(function(e){return n.dom[e]===t})}},{key:"_hasChilds",value:function(){return"array"===this.type||"object"===this.type}},{key:"addTemplates",value:function(t,n){var i=this,e=i.editor.options.templates;null!=e&&(e.length&&t.push({type:"separator"}),e.forEach(function(e){t.push({text:e.text,className:e.className||"jsoneditor-type-object",title:e.title,click:(n?function(e,t){i._onAppend(e,t)}:function(e,t){i._onInsertBefore(e,t)}).bind(this,e.field,e.value)})}))}},{key:"showContextMenu",value:function(e,t){var n,i,o=this,r=[];this.editable.value&&r.push({text:Object(l.c)("type"),title:Object(l.c)("typeTitle"),className:"jsoneditor-type-"+this.type,submenu:[{text:Object(l.c)("auto"),className:"jsoneditor-type-auto"+("auto"===this.type?" jsoneditor-selected":""),title:Object(l.c)("autoType"),click:function(){o._onChangeType("auto")}},{text:Object(l.c)("array"),className:"jsoneditor-type-array"+("array"===this.type?" jsoneditor-selected":""),title:Object(l.c)("arrayType"),click:function(){o._onChangeType("array")}},{text:Object(l.c)("object"),className:"jsoneditor-type-object"+("object"===this.type?" jsoneditor-selected":""),title:Object(l.c)("objectType"),click:function(){o._onChangeType("object")}},{text:Object(l.c)("string"),className:"jsoneditor-type-string"+("string"===this.type?" jsoneditor-selected":""),title:Object(l.c)("stringType"),click:function(){o._onChangeType("string")}}]}),this._hasChilds()&&(this.editor.options.enableSort&&r.push({text:Object(l.c)("sort"),title:Object(l.c)("sortTitle",{type:this.type}),className:"jsoneditor-sort-asc",click:function(){o.showSortModal()}}),this.editor.options.enableTransform&&r.push({text:Object(l.c)("transform"),title:Object(l.c)("transformTitle",{type:this.type}),className:"jsoneditor-transform",click:function(){o.showTransformModal()}}),this.parent&&r.push({text:Object(l.c)("extract"),title:Object(l.c)("extractTitle",{type:this.type}),className:"jsoneditor-extract",click:function(){o.extract()}})),this.parent&&this.parent._hasChilds()&&(r.length&&r.push({type:"separator"}),n=o.parent.childs,o===n[n.length-1]&&(i=[{text:Object(l.c)("auto"),className:"jsoneditor-type-auto",title:Object(l.c)("autoType"),click:function(){o._onAppend("","","auto")}},{text:Object(l.c)("array"),className:"jsoneditor-type-array",title:Object(l.c)("arrayType"),click:function(){o._onAppend("",[])}},{text:Object(l.c)("object"),className:"jsoneditor-type-object",title:Object(l.c)("objectType"),click:function(){o._onAppend("",{})}},{text:Object(l.c)("string"),className:"jsoneditor-type-string",title:Object(l.c)("stringType"),click:function(){o._onAppend("","","string")}}],o.addTemplates(i,!0),r.push({text:Object(l.c)("appendText"),title:Object(l.c)("appendTitle"),submenuTitle:Object(l.c)("appendSubmenuTitle"),className:"jsoneditor-append",click:function(){o._onAppend("","","auto")},submenu:i})),i=[{text:Object(l.c)("auto"),className:"jsoneditor-type-auto",title:Object(l.c)("autoType"),click:function(){o._onInsertBefore("","","auto")}},{text:Object(l.c)("array"),className:"jsoneditor-type-array",title:Object(l.c)("arrayType"),click:function(){o._onInsertBefore("",[])}},{text:Object(l.c)("object"),className:"jsoneditor-type-object",title:Object(l.c)("objectType"),click:function(){o._onInsertBefore("",{})}},{text:Object(l.c)("string"),className:"jsoneditor-type-string",title:Object(l.c)("stringType"),click:function(){o._onInsertBefore("","","string")}}],o.addTemplates(i,!1),r.push({text:Object(l.c)("insert"),title:Object(l.c)("insertTitle"),submenuTitle:Object(l.c)("insertSub"),className:"jsoneditor-insert",click:function(){o._onInsertBefore("","","auto")},submenu:i}),this.editable.field&&(r.push({text:Object(l.c)("duplicateText"),title:Object(l.c)("duplicateField"),className:"jsoneditor-duplicate",click:function(){k.onDuplicate(o)}}),r.push({text:Object(l.c)("removeText"),title:Object(l.c)("removeField"),className:"jsoneditor-remove",click:function(){k.onRemove(o)}}))),this.editor.options.onCreateMenu&&(i=o.getPath(),r=this.editor.options.onCreateMenu(r,{type:"single",path:i,paths:[i]})),new s.a(r,{close:t}).show(e,this.editor.getPopupAnchor())}},{key:"showSortModal",value:function(){var n=this,e=this.editor.options.modalAnchor||f.a,t=this.getValue();Object(u.showSortModal)(e,t,function(e){var t=e.path,t=Object(N.parsePath)(t);n.sortedBy=e,n.sort(t,e.direction)},n.sortedBy)}},{key:"showTransformModal",value:function(){var t=this,e=this.editor.options,n=e.modalAnchor,i=e.createQuery,o=e.executeQuery,r=e.queryDescription,e=this.getValue();Object(p.showTransformModal)({container:n||f.a,json:e,queryDescription:r,createQuery:i,executeQuery:o,onTransform:function(e){t.transform(e)}})}},{key:"_getType",value:function(e){return e instanceof Array?"array":e instanceof Object?"object":"string"==typeof e&&"string"!=typeof Object(N.parseString)(e)?"string":"auto"}},{key:"_escapeHTML",value:function(e){if("string"!=typeof e)return String(e);e=String(e).replace(/&/g,"&amp;").replace(/</g,"&lt;").replace(/>/g,"&gt;").replace(/ {2}/g," &nbsp;").replace(/^ /,"&nbsp;").replace(/ $/,"&nbsp;"),e=JSON.stringify(e),e=e.substring(1,e.length-1);return!0===this.editor.options.escapeUnicode&&(e=Object(N.escapeUnicodeChars)(e)),e}},{key:"_unescapeHTML",value:function(e){e='"'+this._escapeJSON(e)+'"';return Object(N.parse)(e).replace(/&lt;/g,"<").replace(/&gt;/g,">").replace(/&nbsp;|\u00A0/g," ").replace(/&amp;/g,"&")}},{key:"_escapeJSON",value:function(e){for(var t="",n=0;n<e.length;){var i=e.charAt(n);"\n"===i?t+="\\n":"\\"===i?(t+=i,n++,""!==(i=e.charAt(n))&&-1!=='"\\/bfnrtu'.indexOf(i)||(t+="\\"),t+=i):t+='"'===i?'\\"':i,n++}return t}},{key:"updateNodeName",value:function(){var e,t=this.childs?this.childs.length:0;if("object"===this.type||"array"===this.type){if(this.editor.options.onNodeName)try{e=this.editor.options.onNodeName({path:this.getPath(),size:t,type:this.type})}catch(e){console.error("Error in onNodeName callback: ",e)}this.dom.value.textContent="object"===this.type?"{"+(e||t)+"}":"["+(e||t)+"]"}}},{key:"recursivelyUpdateNodeName",value:function(){if(this.expanded&&(this.updateNodeName(),"undefined"!==this.childs))for(var e in this.childs)this.childs[e].recursivelyUpdateNodeName()}}])&&y(e.prototype,t),n&&y(e,n),k}();E.prototype.DEBOUNCE_INTERVAL=150,E.prototype.MAX_SEARCH_RESULTS=999;var b=100;function x(e){return e.getInternalPath()}function O(e){return e.getField()}function C(e,t){return Object.prototype.hasOwnProperty.call(e,t)}E.focusElement=void 0,E.select=function(e){setTimeout(function(){Object(N.selectContentEditable)(e)},0)},E.onDragStart=function(t,e){if(!Array.isArray(t))return E.onDragStart([t],e);var n,i,o,r,s;0!==t.length&&(n=t[0],i=t[t.length-1],o=n.parent,s=E.getNodeFromTarget(e.target),r=n.editor,s=Object(N.getAbsoluteTop)(s.dom.tr)-Object(N.getAbsoluteTop)(n.dom.tr),r.mousemove||(r.mousemove=Object(N.addEventListener)(e.view,"mousemove",function(e){E.onDrag(t,e)})),r.mouseup||(r.mouseup=Object(N.addEventListener)(e.view,"mouseup",function(e){E.onDragEnd(t,e)})),r.highlighter.lock(),r.drag={oldCursor:document.body.style.cursor,oldSelection:r.getDomSelection(),oldPaths:t.map(x),oldParent:o,oldNextNode:o.childs[i.getIndex()+1]||o.append,oldParentPathRedo:o.getInternalPath(),oldIndexRedo:n.getIndex(),mouseX:e.pageX,offsetY:s,level:n.getLevel()},document.body.style.cursor="move",e.preventDefault())},E.onDrag=function(e,t){if(!Array.isArray(e))return E.onDrag([e],t);if(0!==e.length){var n,i,o,r,s,a,l=e[0].editor,c=t.pageY-l.drag.offsetY,d=t.pageX,h=!1,u=e[0],p=u.dom.tr,f=Object(N.getAbsoluteTop)(p),m=p.offsetHeight;if(c<f){for(x=p;x=x.previousSibling,i=E.getNodeFromTarget(x),r=x?Object(N.getAbsoluteTop)(x):0,x&&c<r;);i&&!i.parent&&(i=void 0),i||(x=(g=p.parentNode.firstChild)?g.nextSibling:void 0,(i=E.getNodeFromTarget(x))===u&&(i=void 0)),i&&i.isVisible()&&(r=(x=i.dom.tr)?Object(N.getAbsoluteTop)(x):0)+m<c&&(i=void 0),!i||!1!==l.options.limitDragging&&i.parent!==e[0].parent||(e.forEach(function(e){i.parent.moveBefore(e,i)}),h=!0)}else{var g,v=e[e.length-1];if(m=(g=v.expanded&&v.append?v.append.getDom():v.dom.tr)?g.nextSibling:void 0){for(s=Object(N.getAbsoluteTop)(m),n=m;o=E.getNodeFromTarget(n),n&&(a=n.nextSibling?Object(N.getAbsoluteTop)(n.nextSibling):0,a=n?a-s:0,o&&o.parent.childs.length===e.length&&o.parent.childs[e.length-1]===v&&(f+=27),n=n.nextSibling),n&&f+a<c;);if(o&&o.parent){for(var m=d-l.drag.mouseX,m=Math.round(m/24/2),y=l.drag.level+m,b=o.getLevel(),x=o.dom.tr&&o.dom.tr.previousSibling;b<y&&x;){i=E.getNodeFromTarget(x);var C=e.some(function(e){return e===i||i.isDescendantOf(e)});if(!C){if(!(i instanceof I))break;C=i.parent.childs;if(C.length===e.length&&C[e.length-1]===v)break;b=(o=E.getNodeFromTarget(x)).getLevel()}x=x.previousSibling}o instanceof I&&!o.isVisible()&&o.parent.showMore.isVisible()&&(o=o._nextNode()),o&&(!1===l.options.limitDragging||o.parent===e[0].parent)&&o.dom.tr&&o.dom.tr!==g.nextSibling&&(e.forEach(function(e){o.parent.moveBefore(e,o)}),h=!0)}}}h&&(l.drag.mouseX=d,l.drag.level=u.getLevel()),l.startAutoScroll(c),t.preventDefault()}},E.onDragEnd=function(e,t){if(!Array.isArray(e))return E.onDrag([e],t);var n,i,o,r,s,a,l,c,d;0!==e.length&&(d=e[0],n=d.editor,e[0]&&e[0].dom.menu.focus(),i=n.drag.oldParent.getInternalPath(),o=d.parent.getInternalPath(),r=n.drag.oldParent===d.parent,s=n.drag.oldNextNode.getIndex(),a=d.getIndex(),l=n.drag.oldParentPathRedo,c=n.drag.oldIndexRedo,d=r&&c<a?a+e.length:a,r&&c===a||n._onAction("moveNodes",{count:e.length,fieldNames:e.map(O),oldParentPath:i,newParentPath:o,oldIndex:s,newIndex:a,oldIndexRedo:c,newIndexRedo:d,oldParentPathRedo:l,newParentPathRedo:null,oldSelection:n.drag.oldSelection,newSelection:n.getDomSelection()}),document.body.style.cursor=n.drag.oldCursor,n.highlighter.unlock(),e.forEach(function(e){e.updateDom(),t.target!==e.dom.drag&&t.target!==e.dom.menu&&n.highlighter.unhighlight()}),delete n.drag,n.mousemove&&(Object(N.removeEventListener)(t.view,"mousemove",n.mousemove),delete n.mousemove),n.mouseup&&(Object(N.removeEventListener)(t.view,"mouseup",n.mouseup),delete n.mouseup),n.stopAutoScroll(),t.preventDefault())},E._findEnum=function(e){if(e.enum)return e.enum;e=e.oneOf||e.anyOf||e.allOf;if(e){e=e.filter(function(e){return e.enum});if(0<e.length)return e[0].enum}return null},E._findSchema=function(e,t,n){var i=3<arguments.length&&void 0!==arguments[3]?arguments[3]:e,o=n.slice(1,n.length),r=n[0],s=m(i.oneOf||i.anyOf||i.allOf||[i]);try{for(s.s();!(l=s.n()).done;){if("$ref"in(i=l.value)&&"string"==typeof i.$ref){var a=i.$ref;if(a in t)i=t[a];else{if(!a.startsWith("#/"))throw Error("Unable to resolve reference ".concat(a));var l=a.substring(2).split("/"),i=e,c=m(l);try{for(c.s();!(d=c.n()).done;){var d=d.value;if(!(d in i))throw Error("Unable to resovle reference ".concat(a));i=i[d]}}catch(e){c.e(e)}finally{c.f()}}}if(void 0===r)return i;if("string"!=typeof r){if("number"==typeof r&&"object"===v(i.items)&&null!==i.items)return i=i.items,E._findSchema(e,t,o,i)}else{if("object"===v(i.properties)&&null!==i.properties&&r in i.properties)return i=i.properties[r],E._findSchema(e,t,o,i);if("object"===v(i.patternProperties)&&null!==i.patternProperties)for(var h in i.patternProperties)if(r.match(h))return i=i.patternProperties[h],E._findSchema(e,t,o,i)}}}catch(e){s.e(e)}finally{s.f()}return null},E.onRemove=function(e){if(!Array.isArray(e))return E.onRemove([e]);var t,n,i,o,r,s;e&&0<e.length&&(t=(s=e[0]).parent,n=s.editor,i=s.getIndex(),n.highlighter.unhighlight(),o=n.getDomSelection(),E.blurNodes(e),r=n.getDomSelection(),s=e.map(x),e.forEach(function(e){e.parent._remove(e)}),n._onAction("removeNodes",{nodes:e,paths:s,parentPath:t.getInternalPath(),index:i,oldSelection:o,newSelection:r}))},E.onDuplicate=function(e){if(!Array.isArray(e))return E.onDuplicate([e]);var t,i,n,o,r,s,a;e&&0<e.length&&(t=e[e.length-1],i=t.parent,(n=t.editor).deselect(n.multiselection.nodes),o=n.getDomSelection(),r=t,s=e.map(function(e){var t,n=e.clone();return"object"===e.parent.type&&(t=e.parent.getFieldNames(),n.field=Object(N.findUniqueName)(e.field,t)),i.insertAfter(n,r),r=n}),1===e.length?"object"===s[0].parent.type?(s[0].dom.field.innerHTML=e[0]._escapeHTML(e[0].field),s[0].focus("field")):s[0].focus():n.select(s),a=n.getDomSelection(),n._onAction("duplicateNodes",{paths:e.map(x),clonePaths:s.map(x),afterPath:t.getInternalPath(),parentPath:i.getInternalPath(),oldSelection:o,newSelection:a}))},E.getNodeFromTarget=function(e){for(;e;){if(e.node)return e.node;e=e.parentNode}},E.targetIsColorPicker=function(e){var t=E.getNodeFromTarget(e);if(t)for(var n=e&&e.parentNode;n;){if(n===t.dom.color)return!0;n=n.parentNode}return!1},E.blurNodes=function(e){var t,n;Array.isArray(e)?(t=(n=e[0]).parent,n=n.getIndex(),(t.childs[n+e.length]?t.childs[n+e.length]:t.childs[n-1]||t).focus()):E.blurNodes([e])};var I=((T.prototype=new E).getDom=function(){var e=this.dom;if(e.tr)return e.tr;this._updateEditability();var t=document.createElement("tr");t.className="jsoneditor-append",t.node=this,e.tr=t,"tree"===this.editor.options.mode&&(e.tdDrag=document.createElement("td"),i=document.createElement("td"),e.tdMenu=i,(n=document.createElement("button")).type="button",n.className="jsoneditor-button jsoneditor-contextmenu-button",n.title="Click to open the actions menu (Ctrl+M)",e.menu=n,i.appendChild(e.menu));var n=document.createElement("td"),i=document.createElement("div");return i.appendChild(document.createTextNode("("+Object(l.c)("empty")+")")),i.className="jsoneditor-readonly",n.appendChild(i),e.td=n,e.text=i,this.updateDom(),t},T.prototype.getPath=function(){return null},T.prototype.getIndex=function(){return null},T.prototype.updateDom=function(e){var t=this.dom,n=t.td;n&&(n.style.paddingLeft=24*this.getLevel()+26+"px");var i=t.text;i&&(i.firstChild.nodeValue="("+Object(l.c)("empty")+" "+this.parent.type+")");i=t.tr;this.isVisible()?t.tr.firstChild||(t.tdDrag&&i.appendChild(t.tdDrag),t.tdMenu&&i.appendChild(t.tdMenu),i.appendChild(n)):t.tr.firstChild&&(t.tdDrag&&i.removeChild(t.tdDrag),t.tdMenu&&i.removeChild(t.tdMenu),i.removeChild(n))},T.prototype.isVisible=function(){return 0===this.parent.childs.length},T.prototype.showContextMenu=function(e,t){var n=this,i=[{text:Object(l.c)("auto"),className:"jsoneditor-type-auto",title:Object(l.c)("autoType"),click:function(){n._onAppend("","","auto")}},{text:Object(l.c)("array"),className:"jsoneditor-type-array",title:Object(l.c)("arrayType"),click:function(){n._onAppend("",[])}},{text:Object(l.c)("object"),className:"jsoneditor-type-object",title:Object(l.c)("objectType"),click:function(){n._onAppend("",{})}},{text:Object(l.c)("string"),className:"jsoneditor-type-string",title:Object(l.c)("stringType"),click:function(){n._onAppend("","","string")}}];n.addTemplates(i,!0);var o=[{text:Object(l.c)("appendText"),title:Object(l.c)("appendTitleAuto"),submenuTitle:Object(l.c)("appendSubmenuTitle"),className:"jsoneditor-insert",click:function(){n._onAppend("","","auto")},submenu:i}];this.editor.options.onCreateMenu&&(i=n.parent.getPath(),o=this.editor.options.onCreateMenu(o,{type:"append",path:i,paths:[i]})),new s.a(o,{close:t}).show(e,this.editor.getPopupAnchor())},T.prototype.onEvent=function(e){var t,n=e.type,i=e.target||e.srcElement,o=this.dom;i===o.menu&&("mouseover"===n?this.editor.highlighter.highlight(this.parent):"mouseout"===n&&this.editor.highlighter.unhighlight()),"click"===n&&i===o.menu&&((t=this.editor.highlighter).highlight(this.parent),t.lock(),Object(N.addClassName)(o.menu,"jsoneditor-selected"),this.showContextMenu(o.menu,function(){Object(N.removeClassName)(o.menu,"jsoneditor-selected"),t.unlock(),t.unhighlight()})),"keydown"===n&&this.onKeyDown(e)},T);function T(e){this.editor=e,this.dom={}}var w=((S.prototype=new E).getDom=function(){return this.dom.tr||(this._updateEditability(),this.dom.tr||(n=(t=this).parent,(o=document.createElement("a")).appendChild(document.createTextNode(Object(l.c)("showMore"))),o.href="#",o.onclick=function(e){return n.visibleChilds=Math.floor(n.visibleChilds/n.getMaxVisibleChilds()+1)*n.getMaxVisibleChilds(),t.updateDom(),n.showChilds(),e.preventDefault(),!1},(r=document.createElement("a")).appendChild(document.createTextNode(Object(l.c)("showAll"))),r.href="#",r.onclick=function(e){return n.visibleChilds=1/0,t.updateDom(),n.showChilds(),e.preventDefault(),!1},e=document.createElement("div"),i=document.createTextNode(this._getShowMoreText()),e.className="jsoneditor-show-more",e.appendChild(i),e.appendChild(o),e.appendChild(document.createTextNode(". ")),e.appendChild(r),e.appendChild(document.createTextNode(". ")),(o=document.createElement("td")).appendChild(e),r=document.createElement("tr"),"tree"===this.editor.options.mode&&(r.appendChild(document.createElement("td")),r.appendChild(document.createElement("td"))),r.appendChild(o),r.className="jsoneditor-show-more",this.dom.tr=r,this.dom.moreContents=e,this.dom.moreText=i),this.updateDom(),this.dom.tr);var t,n,e,i,o,r},S.prototype.updateDom=function(e){var t;this.isVisible()?(this.dom.tr.node=this.parent.childs[this.parent.visibleChilds],this.dom.tr.parentNode||(t=this.parent._getNextTr())&&t.parentNode.insertBefore(this.dom.tr,t),this.dom.moreText.nodeValue=this._getShowMoreText(),this.dom.moreContents.style.marginLeft=24*(this.getLevel()+1)+"px"):this.dom.tr&&this.dom.tr.parentNode&&this.dom.tr.parentNode.removeChild(this.dom.tr)},S.prototype._getShowMoreText=function(){return Object(l.c)("showMoreStatus",{visibleChilds:this.parent.visibleChilds,totalChilds:this.parent.childs.length})+" "},S.prototype.isVisible=function(){return this.parent.expanded&&this.parent.childs.length>this.parent.visibleChilds},S.prototype.onEvent=function(e){"keydown"===e.type&&this.onKeyDown(e)},S);function S(e,t){this.editor=e,this.parent=t,this.dom={}}function j(e,t){for(var n=0;n<t.length;n++){var i=t[n];i.enumerable=i.enumerable||!1,i.configurable=!0,"value"in i&&(i.writable=!0),Object.defineProperty(e,i.key,i)}}var k=function(){function n(t){function r(e){return t.node.findNodeByInternalPath(e)}!function(e){if(!(e instanceof n))throw new TypeError("Cannot call a class as a function")}(this),this.editor=t,this.history=[],this.index=-1,this.clear(),this.actions={editField:{undo:function(e){r(e.parentPath).childs[e.index].updateField(e.oldValue)},redo:function(e){r(e.parentPath).childs[e.index].updateField(e.newValue)}},editValue:{undo:function(e){r(e.path).updateValue(e.oldValue)},redo:function(e){r(e.path).updateValue(e.newValue)}},changeType:{undo:function(e){r(e.path).changeType(e.oldType)},redo:function(e){r(e.path).changeType(e.newType)}},appendNodes:{undo:function(e){var t=r(e.parentPath);e.paths.map(r).forEach(function(e){t.removeChild(e)})},redo:function(e){var t=r(e.parentPath);e.nodes.forEach(function(e){t.appendChild(e)})}},insertBeforeNodes:{undo:function(e){var t=r(e.parentPath);e.paths.map(r).forEach(function(e){t.removeChild(e)})},redo:function(e){var t=r(e.parentPath),n=r(e.beforePath);e.nodes.forEach(function(e){t.insertBefore(e,n)})}},insertAfterNodes:{undo:function(e){var t=r(e.parentPath);e.paths.map(r).forEach(function(e){t.removeChild(e)})},redo:function(e){var t=r(e.parentPath),n=r(e.afterPath);e.nodes.forEach(function(e){t.insertAfter(e,n),n=e})}},removeNodes:{undo:function(e){var t=r(e.parentPath),n=t.childs[e.index]||t.append;e.nodes.forEach(function(e){t.insertBefore(e,n)})},redo:function(e){var t=r(e.parentPath);e.paths.map(r).forEach(function(e){t.removeChild(e)})}},duplicateNodes:{undo:function(e){var t=r(e.parentPath);e.clonePaths.map(r).forEach(function(e){t.removeChild(e)})},redo:function(e){var i=r(e.parentPath),o=r(e.afterPath);e.paths.map(r).forEach(function(e){var t,n=e.clone();"object"===i.type&&(t=i.getFieldNames(),n.field=Object(N.findUniqueName)(e.field,t)),i.insertAfter(n,o),o=n})}},moveNodes:{undo:function(n){var i=r(n.oldParentPath),e=r(n.newParentPath),o=i.childs[n.oldIndex]||i.append;e.childs.slice(n.newIndex,n.newIndex+n.count).forEach(function(e,t){e.field=n.fieldNames[t],i.moveBefore(e,o)}),null===n.newParentPathRedo&&(n.newParentPathRedo=e.getInternalPath())},redo:function(n){var e=r(n.oldParentPathRedo),i=r(n.newParentPathRedo),o=i.childs[n.newIndexRedo]||i.append;e.childs.slice(n.oldIndexRedo,n.oldIndexRedo+n.count).forEach(function(e,t){e.field=n.fieldNames[t],i.moveBefore(e,o)})}},sort:{undo:function(e){var t=r(e.path);t.hideChilds(),t.childs=e.oldChilds,t.updateDom({updateIndexes:!0}),t.showChilds()},redo:function(e){var t=r(e.path);t.hideChilds(),t.childs=e.newChilds,t.updateDom({updateIndexes:!0}),t.showChilds()}},transform:{undo:function(e){r(e.path).setInternalValue(e.oldValue)},redo:function(e){r(e.path).setInternalValue(e.newValue)}}}}var e,t,i;return e=n,(t=[{key:"onChange",value:function(){}},{key:"add",value:function(e,t){this.index++,this.history[this.index]={action:e,params:t,timestamp:new Date},this.index<this.history.length-1&&this.history.splice(this.index+1,this.history.length-this.index-1),this.onChange()}},{key:"clear",value:function(){this.history=[],this.index=-1,this.onChange()}},{key:"canUndo",value:function(){return 0<=this.index}},{key:"canRedo",value:function(){return this.index<this.history.length-1}},{key:"undo",value:function(){if(this.canUndo()){var e=this.history[this.index];if(e){var t=this.actions[e.action];if(t&&t.undo){if(t.undo(e.params),e.params.oldSelection)try{this.editor.setDomSelection(e.params.oldSelection)}catch(e){console.error(e)}}else console.error(new Error('unknown action "'+e.action+'"'))}this.index--,this.onChange()}}},{key:"redo",value:function(){if(this.canRedo()){this.index++;var e=this.history[this.index];if(e){var t=this.actions[e.action];if(t&&t.redo){if(t.redo(e.params),e.params.newSelection)try{this.editor.setDomSelection(e.params.newSelection)}catch(e){console.error(e)}}else console.error(new Error('unknown action "'+e.action+'"'))}this.onChange()}}},{key:"destroy",value:function(){this.editor=null,this.history=[],this.index=-1}}])&&j(e.prototype,t),i&&j(e,i),n}();function D(e,t){for(var n=0;n<t.length;n++){var i=t[n];i.enumerable=i.enumerable||!1,i.configurable=!0,"value"in i&&(i.writable=!0),Object.defineProperty(e,i.key,i)}}var A=function(){function o(e,t){!function(e){if(!(e instanceof o))throw new TypeError("Cannot call a class as a function")}(this);var n=this;this.editor=e,this.timeout=void 0,this.delay=200,this.lastText=void 0,this.results=null,this.dom={},this.dom.container=t;e=document.createElement("div");(this.dom.wrapper=e).className="jsoneditor-search",t.appendChild(e);t=document.createElement("div");(this.dom.results=t).className="jsoneditor-results",e.appendChild(t);t=document.createElement("div");(this.dom.input=t).className="jsoneditor-frame",t.title=Object(l.c)("searchTitle"),e.appendChild(t);e=document.createElement("button");e.type="button",e.className="jsoneditor-refresh",t.appendChild(e);var i=document.createElement("input");i.type="text",(this.dom.search=i).oninput=function(e){n._onDelayedSearch(e)},i.onchange=function(e){n._onSearch()},i.onkeydown=function(e){n._onKeyDown(e)},i.onkeyup=function(e){n._onKeyUp(e)},e.onclick=function(e){i.select()},t.appendChild(i);e=document.createElement("button");e.type="button",e.title=Object(l.c)("searchNextResultTitle"),e.className="jsoneditor-next",e.onclick=function(){n.next()},t.appendChild(e);e=document.createElement("button");e.type="button",e.title=Object(l.c)("searchPreviousResultTitle"),e.className="jsoneditor-previous",e.onclick=function(){n.previous()},t.appendChild(e)}var e,t,n;return e=o,(t=[{key:"next",value:function(e){var t;this.results&&((t=null!==this.resultIndex?this.resultIndex+1:0)>this.results.length-1&&(t=0),this._setActiveResult(t,e))}},{key:"previous",value:function(e){var t,n;this.results&&(t=this.results.length-1,(n=null!==this.resultIndex?this.resultIndex-1:t)<0&&(n=t),this._setActiveResult(n,e))}},{key:"_setActiveResult",value:function(e,t){var n;if(this.activeResult&&(n=this.activeResult.node,"field"===this.activeResult.elem?delete n.searchFieldActive:delete n.searchValueActive,n.updateDom()),!this.results||!this.results[e])return this.resultIndex=void 0,void(this.activeResult=void 0);this.resultIndex=e;var i=this.results[this.resultIndex].node,o=this.results[this.resultIndex].elem;"field"===o?i.searchFieldActive=!0:i.searchValueActive=!0,this.activeResult=this.results[this.resultIndex],i.updateDom(),i.scrollTo(function(){t&&i.focus(o)})}},{key:"_clearDelay",value:function(){void 0!==this.timeout&&(clearTimeout(this.timeout),delete this.timeout)}},{key:"_onDelayedSearch",value:function(){this._clearDelay();var t=this;this.timeout=setTimeout(function(e){t._onSearch()},this.delay)}},{key:"_onSearch",value:function(e){this._clearDelay();var t=this.dom.search.value,t=0<t.length?t:void 0;if(t!==this.lastText||e){this.lastText=t,this.results=this.editor.search(t);var e=this.results[0]?this.results[0].node.MAX_SEARCH_RESULTS:1/0,n=0;if(this.activeResult)for(var i=0;i<this.results.length;i++)if(this.results[i].node===this.activeResult.node){n=i;break}this._setActiveResult(n,!1),void 0!==t?(t=this.results.length,this.dom.results.textContent=0===t?"no results":1===t?"1 result":e<t?e+"+ results":t+" results"):this.dom.results.textContent=""}}},{key:"_onKeyDown",value:function(e){var t=e.which;27===t?(this.dom.search.value="",this._onSearch(),e.preventDefault(),e.stopPropagation()):13===t&&(e.ctrlKey?this._onSearch(!0):e.shiftKey?this.previous():this.next(),e.preventDefault(),e.stopPropagation())}},{key:"_onKeyUp",value:function(e){var t=e.keyCode;27!==t&&13!==t&&this._onDelayedSearch(e)}},{key:"clear",value:function(){this.dom.search.value="",this._onSearch()}},{key:"forceSearch",value:function(){this._onSearch(!0)}},{key:"isEmpty",value:function(){return""===this.dom.search.value}},{key:"destroy",value:function(){this.editor=null,this.dom.container.removeChild(this.dom.wrapper),this.dom=null,this.results=null,this.activeResult=null,this._clearDelay()}}])&&D(e.prototype,t),n&&D(e,n),o}();function P(e,t){for(var n=0;n<t.length;n++){var i=t[n];i.enumerable=i.enumerable||!1,i.configurable=!0,"value"in i&&(i.writable=!0),Object.defineProperty(e,i.key,i)}}var F=function(){function n(e,t){!function(e){if(!(e instanceof n))throw new TypeError("Cannot call a class as a function")}(this),e&&(this.root=t,this.path=document.createElement("div"),this.path.className="jsoneditor-treepath",this.path.setAttribute("tabindex",0),this.contentMenuClicked=!1,e.appendChild(this.path),this.reset())}var e,t,i;return e=n,(t=[{key:"reset",value:function(){this.path.textContent=Object(l.c)("selectNode")}},{key:"setPath",value:function(o){var r=this;this.path.textContent="",o&&o.length&&o.forEach(function(n,i){var e,t=document.createElement("span");t.className="jsoneditor-treepath-element",t.innerText=n.name,t.onclick=function(e){this.selectionCallback&&this.selectionCallback(e)}.bind(r,n),r.path.appendChild(t),n.children.length&&((e=document.createElement("span")).className="jsoneditor-treepath-seperator",e.textContent="►",e.onclick=function(){r.contentMenuClicked=!0;var t=[];n.children.forEach(function(e){t.push({text:e.name,className:"jsoneditor-type-modes"+(o[i+1]+1&&o[i+1].name===e.name?" jsoneditor-selected":""),click:function(e,t){this.contextMenuCallback&&this.contextMenuCallback(e,t)}.bind(r,n,e.name)})}),new s.a(t,{limitHeight:!0}).show(e,r.root,!0)},r.path.appendChild(e)),i===o.length-1&&(t=(e||t).getBoundingClientRect().right,r.path.offsetWidth<t&&(r.path.scrollLeft=t),r.path.scrollLeft&&((t=document.createElement("span")).className="jsoneditor-treepath-show-all-btn",t.title="show all path",t.textContent="...",t.onclick=function(e){r.contentMenuClicked=!1,Object(N.addClassName)(r.path,"show-all"),r.path.style.width=r.path.parentNode.getBoundingClientRect().width-10+"px",r.path.onblur=function(){if(r.contentMenuClicked)return r.contentMenuClicked=!1,void r.path.focus();Object(N.removeClassName)(r.path,"show-all"),r.path.onblur=void 0,r.path.style.width="",r.setPath(e)}}.bind(r,o),r.path.insertBefore(t,r.path.firstChild)))})}},{key:"onSectionSelected",value:function(e){"function"==typeof e&&(this.selectionCallback=e)}},{key:"onContextMenuItemSelected",value:function(e){"function"==typeof e&&(this.contextMenuCallback=e)}}])&&P(e.prototype,t),i&&P(e,i),n}(),t=n(13),M=n.n(t),t={};t.create=function(e,t){if(!e)throw new Error("No container element provided.");this.container=e,this.dom={},this.highlighter=new i,this.selection=void 0,this.multiselection={nodes:[]},this.validateSchema=null,this.validationSequence=0,this.errorNodes=[],this.lastSchemaErrors=void 0,this.node=null,this.focusTarget=null,this._setOptions(t),t.autocomplete&&(this.autocomplete=function(s){(s=s||{}).filter=s.filter||"start",s.trigger=s.trigger||"keydown",s.confirmKeys=s.confirmKeys||[39,35,9],s.caseSensitive=s.caseSensitive||!1;var o="",r="",a=document.createElement("div");a.style.position="relative",a.style.outline="0",a.style.border="0",a.style.margin="0",a.style.padding="0";var t,l,c=document.createElement("div");function d(e){var t,n;document.createRange?((t=document.createRange()).selectNodeContents(e),t.collapse(!1),(n=window.getSelection()).removeAllRanges(),n.addRange(t)):document.selection&&((t=document.body.createTextRange()).moveToElementText(e),t.collapse(!1),t.select())}function h(e){return void 0===t&&((t=document.createElement("span")).style.visibility="hidden",t.style.position="fixed",t.style.outline="0",t.style.margin="0",t.style.padding="0",t.style.border="0",t.style.left="0",t.style.whiteSpace="pre",t.style.fontSize=o,t.style.fontFamily=r,t.style.fontWeight="normal",document.body.appendChild(t)),t.textContent=e,t.getBoundingClientRect().right}c.className="autocomplete dropdown",c.style.position="absolute",c.style.visibility="hidden";var u,p,f,n,m,g={onArrowDown:function(){},onArrowUp:function(){},onEnter:function(){},onTab:function(){},startFrom:0,options:[],element:null,elementHint:null,elementStyle:null,wrapper:a,show:function(e,t,n){var i=this;this.startFrom=t,this.wrapper.remove(),this.elementHint&&(this.elementHint.remove(),this.elementHint=null),""===o&&(o=window.getComputedStyle(e).getPropertyValue("font-size")),""===r&&(r=window.getComputedStyle(e).getPropertyValue("font-family")),c.style.marginLeft="0",c.style.marginTop=e.getBoundingClientRect().height+"px",this.options=n.map(String),this.element!==e&&(this.element=e,this.elementStyle={zIndex:this.element.style.zIndex,position:this.element.style.position,backgroundColor:this.element.style.backgroundColor,borderColor:this.element.style.borderColor}),this.element.style.zIndex=3,this.element.style.position="relative",this.element.style.backgroundColor="transparent",this.element.style.borderColor="transparent",this.elementHint=e.cloneNode(),this.elementHint.className="autocomplete hint",this.elementHint.style.zIndex=2,this.elementHint.style.position="absolute",this.elementHint.onfocus=function(){i.element.focus()},this.element.addEventListener&&(this.element.removeEventListener("keydown",C),this.element.addEventListener("keydown",C,!1),this.element.removeEventListener("blur",E),this.element.addEventListener("blur",E,!1)),a.appendChild(this.elementHint),a.appendChild(c),e.parentElement.appendChild(a),this.repaint(e)},setText:function(e){this.element.innerText=e},getText:function(){return this.element.innerText},hideDropDown:function(){this.wrapper.remove(),this.elementHint&&(this.elementHint.remove(),this.elementHint=null,v.hide(),this.element.style.zIndex=this.elementStyle.zIndex,this.element.style.position=this.elementStyle.position,this.element.style.backgroundColor=this.elementStyle.backgroundColor,this.element.style.borderColor=this.elementStyle.borderColor)},repaint:function(e){var e=(e=e.innerText).replace("\n",""),t=this.options.length,n=e.substring(this.startFrom);l=e.substring(0,this.startFrom);for(var i=0;i<t;i++){var o=this.options[i];if(!s.caseSensitive&&0===o.toLowerCase().indexOf(n.toLowerCase())||s.caseSensitive&&0===o.indexOf(n)){this.elementHint.innerText=l+n+o.substring(n.length),this.elementHint.realInnerText=l+o;break}}c.style.left=h(l)+"px",v.refresh(n,this.options),this.elementHint.style.width=h(this.elementHint.innerText)+10+"px","hidden"===c.style.visibility||(this.elementHint.style.width=h(this.elementHint.innerText)+c.clientWidth+"px")}},v=(u=c,p=[],f=0,n=-1,m={rs:g,hide:function(){u.style.visibility="hidden"},refresh:function(i,e){u.style.visibility="hidden",f=0,u.textContent="";var t=window.innerHeight||document.documentElement.clientHeight,n=u.parentNode.getBoundingClientRect(),o=n.top-6,n=t-n.bottom-6;p=[];var r="function"==typeof s.filter?s.filter:_[s.filter],e=r?e.filter(function(e){return r(s.caseSensitive?i:i.toLowerCase(),s.caseSensitive?e:e.toLowerCase(),s)}):[];0!==(p=e.map(function(e){var t=document.createElement("div");t.className="item",t.onmouseover=y,t.onmouseout=b,t.onmousedown=x,t.__hint=e,t.textContent="",t.appendChild(document.createTextNode(e.substring(0,i.length)));var n=document.createElement("b");return n.appendChild(document.createTextNode(e.substring(i.length))),t.appendChild(n),u.appendChild(t),t})).length&&(1===p.length&&(i.toLowerCase()===p[0].__hint.toLowerCase()&&!s.caseSensitive||i===p[0].__hint&&s.caseSensitive)||p.length<2||(m.highlight(0),3*n<o?(u.style.maxHeight=o+"px",u.style.top="",u.style.bottom="100%"):(u.style.top="100%",u.style.bottom="",u.style.maxHeight=n+"px"),u.style.visibility="visible"))},highlight:function(e){-1!==n&&p[n]&&(p[n].className="item"),p[e].className="item hover",n=e},move:function(e){return"hidden"===u.style.visibility?"":(f+e===-1||f+e===p.length||(f+=e,m.highlight(f)),p[f].__hint)},onmouseselection:function(){}});function y(){this.style.backgroundColor="#ddd"}function b(){this.style.backgroundColor=""}function x(){m.hide(),m.onmouseselection(this.__hint,m.rs)}var C=function(e){var t=(e=e||window.event).keyCode;if(null!=this.elementHint&&33!==t&&34!==t){if(27===t)return g.hideDropDown(),g.element.focus(),e.preventDefault(),void e.stopPropagation();var n=(n=this.element.innerText).replace("\n","");if(0<=s.confirmKeys.indexOf(t))return 9===t&&0===this.elementHint.innerText.length&&g.onTab(),void(0<this.elementHint.innerText.length&&this.element.innerText!==this.elementHint.realInnerText&&(this.element.innerText=this.elementHint.realInnerText,g.hideDropDown(),d(this.element),9===t&&(g.element.focus(),e.preventDefault(),e.stopPropagation())));if(13!==t){if(40===t){var i=n.substring(this.startFrom),o=v.move(1);return""===o&&g.onArrowDown(),this.elementHint.innerText=l+i+o.substring(i.length),this.elementHint.realInnerText=l+o,e.preventDefault(),void e.stopPropagation()}38===t&&(n=n.substring(this.startFrom),""===(r=v.move(-1))&&g.onArrowUp(),this.elementHint.innerText=l+n+r.substring(n.length),this.elementHint.realInnerText=l+r,e.preventDefault(),e.stopPropagation())}else if(0===this.elementHint.innerText.length)g.onEnter();else{var r="hidden"===c.style.visibility;if(v.hide(),r)return g.hideDropDown(),g.element.focus(),void g.onEnter();this.element.innerText=this.elementHint.realInnerText,g.hideDropDown(),d(this.element),e.preventDefault(),e.stopPropagation()}}}.bind(g),E=function(){g.hideDropDown()};return v.onmouseselection=function(e,t){t.element.innerText=t.elementHint.innerText=l+e,t.hideDropDown(),window.setTimeout(function(){t.element.focus(),d(t.element)},1)},g}(t.autocomplete)),this.options.history&&"view"!==this.options.mode&&(this.history=new k(this)),this._createFrame(),this._createTable()},t.destroy=function(){this.frame&&this.container&&this.frame.parentNode===this.container&&(this.container.removeChild(this.frame),this.frame=null),this.container=null,this.dom=null,this.clear(),this.node=null,this.focusTarget=null,this.selection=null,this.multiselection=null,this.errorNodes=null,this.validateSchema=null,this._debouncedValidate=null,this.history&&(this.history.destroy(),this.history=null),this.searchBox&&(this.searchBox.destroy(),this.searchBox=null),this.modeSwitcher&&(this.modeSwitcher.destroy(),this.modeSwitcher=null),this.frameFocusTracker.destroy()},t._setOptions=function(t){var n=this;this.options={search:!0,history:!0,mode:"tree",name:void 0,schema:null,schemaRefs:null,autocomplete:null,navigationBar:!0,mainMenuBar:!0,limitDragging:!1,onSelectionChange:null,colorPicker:!0,onColorPicker:function(e,t,n){var i;M.a?(i=e.getBoundingClientRect().top,i=Object(N.getWindow)(e).innerHeight-i<300&&300<i,new M.a({parent:e,color:t,popup:i?"top":"bottom",onDone:function(e){e=1===e.rgba[3]?e.hex.substr(0,7):e.hex;n(e)}}).show()):console.warn("Cannot open color picker: the `vanilla-picker` library is not included in the bundle. Either use the full bundle or implement your own color picker using `onColorPicker`.")},timestampTag:!0,timestampFormat:null,createQuery:r.a,executeQuery:r.b,onEvent:null,enableSort:!0,enableTransform:!0},t&&(Object.keys(t).forEach(function(e){n.options[e]=t[e]}),null==t.limitDragging&&null!=t.schema&&(this.options.limitDragging=!0)),this.setSchema(this.options.schema,this.options.schemaRefs),this._debouncedValidate=Object(N.debounce)(this.validate.bind(this),this.DEBOUNCE_INTERVAL),t.onSelectionChange&&this.onSelectionChange(t.onSelectionChange),Object(l.b)(this.options.languages),Object(l.a)(this.options.language)},t.set=function(e){e instanceof Function||void 0===e?this.clear():(this.content.removeChild(this.table),e={field:this.options.name,value:e},e=new E(this,e),this._setRoot(e),this.validate(),this.node.expand(!1),this.content.appendChild(this.table)),this.history&&this.history.clear(),this.searchBox&&this.searchBox.clear()},t.update=function(e){var t,n;this.node.deepEqual(e)||(t=this.getSelection(),this.onChangeDisabled=!0,this.node.update(e),this.onChangeDisabled=!1,this.validate(),this.searchBox&&!this.searchBox.isEmpty()&&this.searchBox.forceSearch(),t&&t.start&&t.end?(n=this.node.findNodeByPath(t.start.path),e=this.node.findNodeByPath(t.end.path),n&&e?this.setSelection(t.start,t.end):this.setSelection({},{})):this.setSelection({},{}))},t.get=function(){if(this.node)return this.node.getValue()},t.getText=function(){return JSON.stringify(this.get())},t.setText=function(t){try{this.set(Object(N.parse)(t))}catch(e){var n=Object(N.trySimpleJsonRepair)(t);this.set(Object(N.parse)(n))}},t.updateText=function(t){try{this.update(Object(N.parse)(t))}catch(e){var n=Object(N.trySimpleJsonRepair)(t);this.update(Object(N.parse)(n))}},t.setName=function(e){this.options.name=e,this.node&&this.node.updateField(this.options.name)},t.getName=function(){return this.options.name},t.focus=function(){var e=this.scrollableContent.querySelector("[contenteditable=true]");e?e.focus():this.node.dom.expand?this.node.dom.expand.focus():this.node.dom.menu?this.node.dom.menu.focus():(e=this.frame.querySelector("button"))&&e.focus()},t.clear=function(){this.node&&(this.node.hide(),delete this.node),this.treePath&&this.treePath.reset()},t._setRoot=function(e){this.clear(),(this.node=e).setParent(null),e.setField(this.getName(),!1),delete e.index,this.tbody.appendChild(e.getDom())},t.search=function(e){var t;return this.node?(this.content.removeChild(this.table),t=this.node.search(e),this.content.appendChild(this.table)):t=[],t},t.expandAll=function(){this.node&&(this.content.removeChild(this.table),this.node.expand(),this.content.appendChild(this.table))},t.collapseAll=function(){this.node&&(this.content.removeChild(this.table),this.node.collapse(),this.content.appendChild(this.table))},t._onAction=function(e,t){this.history&&this.history.add(e,t),this._onChange()},t._onChange=function(){if(!this.onChangeDisabled){var e;if(this.selection=this.getDomSelection(),this._debouncedValidate(),this.treePath&&((e=this.node&&this.selection?this.node.findNodeByInternalPath(this.selection.path):this.multiselection?this.multiselection.nodes[0]:void 0)?this._updateTreePath(e.getNodePath()):this.treePath.reset()),this.options.onChange)try{this.options.onChange()}catch(e){console.error("Error in onChange callback: ",e)}if(this.options.onChangeJSON)try{this.options.onChangeJSON(this.get())}catch(e){console.error("Error in onChangeJSON callback: ",e)}if(this.options.onChangeText)try{this.options.onChangeText(this.getText())}catch(e){console.error("Error in onChangeText callback: ",e)}if(this.options.onClassName&&this.node.recursivelyUpdateCssClassesOnNodes(),this.options.onNodeName&&this.node.childs)try{this.node.recursivelyUpdateNodeName()}catch(e){console.error("Error in onNodeName callback: ",e)}}},t.validate=function(){var t=this,n=this.node;if(n){var e=n.getValue(),i=[];this.validateSchema&&(this.validateSchema(e)||(i=this.validateSchema.errors.map(function(e){return Object(N.improveSchemaError)(e)}).map(function(e){return{node:n.findNode(e.dataPath),error:e,type:"validation"}}).filter(function(e){return null!=e.node})));try{this.validationSequence++;var o=this,r=this.validationSequence;this._validateCustom(e).then(function(e){r===o.validationSequence&&(e=[].concat(i,e||[]),o._renderValidationErrors(e),"function"==typeof t.options.onValidationError&&(Object(N.isValidationErrorChanged)(e,t.lastSchemaErrors)&&t.options.onValidationError.call(t,e),t.lastSchemaErrors=e))}).catch(function(e){console.error(e)})}catch(e){console.error(e)}}},t._renderValidationErrors=function(e){this.errorNodes&&this.errorNodes.forEach(function(e){e.setError(null)});var t=e.reduce(function(e,t){return t.node.findParents().filter(function(t){return!e.some(function(e){return e[0]===t})}).map(function(e){return[e,t.node]}).concat(e)},[]);this.errorNodes=t.map(function(e){return{node:e[0],child:e[1],error:{message:"object"===e[0].type?Object(l.c)("containsInvalidProperties"):Object(l.c)("containsInvalidItems")}}}).concat(e).map(function(e){return e.node.setError(e.error,e.child),e.node})},t._validateCustom=function(e){try{if(this.options.onValidate){var n=this.node,t=this.options.onValidate(e);return(Object(N.isPromise)(t)?t:Promise.resolve(t)).then(function(e){return Array.isArray(e)?e.filter(function(e){var t=Object(N.isValidValidationError)(e);return t||console.warn('Ignoring a custom validation error with invalid structure. Expected structure: {path: [...], message: "..."}. Actual error:',e),t}).map(function(e){var t;try{t=e&&e.path?n.findNodeByPath(e.path):null}catch(e){}return t||console.warn("Ignoring validation error: node not found. Path:",e.path,"Error:",e),{node:t,error:e,type:"customValidation"}}).filter(function(e){return e&&e.node&&e.error&&e.error.message}):null})}}catch(e){return Promise.reject(e)}return Promise.resolve(null)},t.refresh=function(){this.node&&this.node.updateDom({recurse:!0})},t.startAutoScroll=function(e){var t=this,n=this.scrollableContent,i=Object(N.getAbsoluteTop)(n),o=n.clientHeight,r=i+o;e<i+24&&0<n.scrollTop?this.autoScrollStep=(i+24-e)/3:r-24<e&&o+n.scrollTop<n.scrollHeight?this.autoScrollStep=(r-24-e)/3:this.autoScrollStep=void 0,this.autoScrollStep?this.autoScrollTimer||(this.autoScrollTimer=setInterval(function(){t.autoScrollStep?n.scrollTop-=t.autoScrollStep:t.stopAutoScroll()},50)):this.stopAutoScroll()},t.stopAutoScroll=function(){this.autoScrollTimer&&(clearTimeout(this.autoScrollTimer),delete this.autoScrollTimer),this.autoScrollStep&&delete this.autoScrollStep},t.setDomSelection=function(e){var t,n,i;e&&("scrollTop"in e&&this.scrollableContent&&(this.scrollableContent.scrollTop=e.scrollTop),e.paths?(t=this,i=e.paths.map(function(e){return t.node.findNodeByInternalPath(e)}),this.select(i)):(i=(n=e.path?this.node.findNodeByInternalPath(e.path):null)&&e.domName?n.dom[e.domName]:null,e.range&&i?(i=Object.assign({},e.range,{container:i}),Object(N.setSelectionOffset)(i)):n&&n.focus()))},t.getDomSelection=function(){var t=E.getNodeFromTarget(this.focusTarget),n=this.focusTarget,e=t?Object.keys(t.dom).find(function(e){return t.dom[e]===n}):null,i=Object(N.getSelectionOffset)();return i&&"DIV"!==i.container.nodeName&&(i=null),i&&i.container!==n&&(i=null),i&&delete i.container,{path:t?t.getInternalPath():null,domName:e,range:i,paths:0<this.multiselection.length?this.multiselection.nodes.map(function(e){return e.getInternalPath()}):null,scrollTop:this.scrollableContent?this.scrollableContent.scrollTop:0}},t.scrollTo=function(e,n){var i,t,o,r,s=this.scrollableContent;s?((i=this).animateTimeout&&(clearTimeout(i.animateTimeout),delete i.animateTimeout),i.animateCallback&&(i.animateCallback(!1),delete i.animateCallback),t=s.clientHeight,o=s.scrollHeight-t,r=Math.min(Math.max(e-t/4,0),o),function e(){var t=s.scrollTop,t=r-t;3<Math.abs(t)?(s.scrollTop+=t/3,i.animateCallback=n,i.animateTimeout=setTimeout(e,50)):(n&&n(!0),s.scrollTop=r,delete i.animateTimeout,delete i.animateCallback)}()):n&&n(!1)},t._createFrame=function(){this.frame=document.createElement("div"),this.frame.className="jsoneditor jsoneditor-mode-"+this.options.mode,this.container.appendChild(this.frame),this.contentOuter=document.createElement("div"),this.contentOuter.className="jsoneditor-outer";var t=this;function n(e){t._onEvent&&t._onEvent(e)}var e,i,o,r,s={target:this.frame,onFocus:this.options.onFocus||null,
onBlur:this.options.onBlur||null};this.frameFocusTracker=new a.a(s),this.frame.onclick=function(e){var t=e.target;n(e),"BUTTON"===t.nodeName&&e.preventDefault()},this.frame.oninput=n,this.frame.onchange=n,this.frame.onkeydown=n,this.frame.onkeyup=n,this.frame.oncut=n,this.frame.onpaste=n,this.frame.onmousedown=n,this.frame.onmouseup=n,this.frame.onmouseover=n,this.frame.onmouseout=n,Object(N.addEventListener)(this.frame,"focus",n,!0),Object(N.addEventListener)(this.frame,"blur",n,!0),this.frame.onfocusin=n,this.frame.onfocusout=n,this.options.mainMenuBar&&(Object(N.addClassName)(this.contentOuter,"has-main-menu-bar"),this.menu=document.createElement("div"),this.menu.className="jsoneditor-menu",this.frame.appendChild(this.menu),(s=document.createElement("button")).type="button",s.className="jsoneditor-expand-all",s.title=Object(l.c)("expandAll"),s.onclick=function(){t.expandAll()},this.menu.appendChild(s),(s=document.createElement("button")).type="button",s.title=Object(l.c)("collapseAll"),s.className="jsoneditor-collapse-all",s.onclick=function(){t.collapseAll()},this.menu.appendChild(s),this.options.enableSort&&((e=document.createElement("button")).type="button",e.className="jsoneditor-sort",e.title=Object(l.c)("sortTitleShort"),e.onclick=function(){t.node.showSortModal()},this.menu.appendChild(e)),this.options.enableTransform&&((e=document.createElement("button")).type="button",e.title=Object(l.c)("transformTitleShort"),e.className="jsoneditor-transform",e.onclick=function(){t.node.showTransformModal()},this.menu.appendChild(e)),this.history&&((i=document.createElement("button")).type="button",i.className="jsoneditor-undo jsoneditor-separator",i.title=Object(l.c)("undo"),i.onclick=function(){t._onUndo()},this.menu.appendChild(i),this.dom.undo=i,(o=document.createElement("button")).type="button",o.className="jsoneditor-redo",o.title=Object(l.c)("redo"),o.onclick=function(){t._onRedo()},this.menu.appendChild(o),this.dom.redo=o,this.history.onChange=function(){i.disabled=!t.history.canUndo(),o.disabled=!t.history.canRedo()},this.history.onChange()),this.options&&this.options.modes&&this.options.modes.length&&((r=this).modeSwitcher=new c.a(this.menu,this.options.modes,this.options.mode,function(e){r.setMode(e),r.modeSwitcher.focus()})),this.options.search&&(this.searchBox=new A(this,this.menu))),this.options.navigationBar&&(this.navBar=document.createElement("div"),this.navBar.className="jsoneditor-navigation-bar nav-bar-empty",this.frame.appendChild(this.navBar),this.treePath=new F(this.navBar,this.getPopupAnchor()),this.treePath.onSectionSelected(this._onTreePathSectionSelected.bind(this)),this.treePath.onContextMenuItemSelected(this._onTreePathMenuItemSelected.bind(this)))},t._onUndo=function(){this.history&&(this.history.undo(),this._onChange())},t._onRedo=function(){this.history&&(this.history.redo(),this._onChange())},t._onEvent=function(e){if(!E.targetIsColorPicker(e.target)){var t,n=E.getNodeFromTarget(e.target);if("keydown"===e.type&&this._onKeyDown(e),n&&"focus"===e.type&&(this.focusTarget=e.target,this.options.autocomplete&&"focus"===this.options.autocomplete.trigger&&this._showAutoComplete(e.target)),"mousedown"===e.type&&this._startDragDistance(e),"mousemove"!==e.type&&"mouseup"!==e.type&&"click"!==e.type||this._updateDragDistance(e),n&&this.options&&this.options.navigationBar&&n&&("keydown"===e.type||"mousedown"===e.type)&&(t=this,setTimeout(function(){t._updateTreePath(n.getNodePath())})),n&&n.selected){if("click"===e.type){if(e.target===n.dom.menu)return void this.showContextMenu(e.target);e.hasMoved||this.deselect()}"mousedown"===e.type&&E.onDragStart(this.multiselection.nodes,e)}else"mousedown"===e.type&&Object(N.hasParentNode)(e.target,this.content)&&(this.deselect(),n&&e.target===n.dom.drag?E.onDragStart(n,e):n&&(e.target===n.dom.field||e.target===n.dom.value||e.target===n.dom.select)||this._onMultiSelectStart(e));n&&n.onEvent(e)}},t._updateTreePath=function(e){var n;function i(e){return e.parent?"array"===e.parent.type?e.index:e.field:e.field||e.type}e&&e.length?(Object(N.removeClassName)(this.navBar,"nav-bar-empty"),n=[],e.forEach(function(e){var t={name:i(e),node:e,children:[]};e.childs&&e.childs.length&&e.childs.forEach(function(e){t.children.push({name:i(e),node:e})}),n.push(t)}),this.treePath.setPath(n)):Object(N.addClassName)(this.navBar,"nav-bar-empty")},t._onTreePathSectionSelected=function(e){e&&e.node&&(e.node.expandTo(),e.node.focus())},t._onTreePathMenuItemSelected=function(e,t){e&&e.children.length&&((e=e.children.find(function(e){return e.name===t}))&&e.node&&(this._updateTreePath(e.node.getNodePath()),e.node.expandTo(),e.node.focus()))},t._startDragDistance=function(e){this.dragDistanceEvent={initialTarget:e.target,initialPageX:e.pageX,initialPageY:e.pageY,dragDistance:0,hasMoved:!1}},t._updateDragDistance=function(e){this.dragDistanceEvent||this._startDragDistance(e);var t=e.pageX-this.dragDistanceEvent.initialPageX,n=e.pageY-this.dragDistanceEvent.initialPageY;return this.dragDistanceEvent.dragDistance=Math.sqrt(t*t+n*n),this.dragDistanceEvent.hasMoved=this.dragDistanceEvent.hasMoved||10<this.dragDistanceEvent.dragDistance,e.dragDistance=this.dragDistanceEvent.dragDistance,e.hasMoved=this.dragDistanceEvent.hasMoved,e.dragDistance},t._onMultiSelectStart=function(e){var t,n=E.getNodeFromTarget(e.target);"tree"===this.options.mode&&void 0===this.options.onEditable&&(this.multiselection={start:n||null,end:null,nodes:[]},this._startDragDistance(e),(t=this).mousemove||(this.mousemove=Object(N.addEventListener)(e.view,"mousemove",function(e){t._onMultiSelect(e)})),this.mouseup||(this.mouseup=Object(N.addEventListener)(e.view,"mouseup",function(e){t._onMultiSelectEnd(e)})),e.preventDefault())},t._onMultiSelect=function(e){var t;e.preventDefault(),this._updateDragDistance(e),e.hasMoved&&((t=E.getNodeFromTarget(e.target))&&(null==this.multiselection.start&&(this.multiselection.start=t),this.multiselection.end=t),this.deselect(),e=this.multiselection.start,t=this.multiselection.end||this.multiselection.start,e&&t&&(this.multiselection.nodes=this._findTopLevelNodes(e,t),this.multiselection.nodes&&this.multiselection.nodes.length&&(t=this.multiselection.nodes[0],this.multiselection.start===t||this.multiselection.start.isDescendantOf(t)?this.multiselection.direction="down":this.multiselection.direction="up"),this.select(this.multiselection.nodes)))},t._onMultiSelectEnd=function(e){this.multiselection.nodes[0]&&this.multiselection.nodes[0].dom.menu.focus(),this.multiselection.start=null,this.multiselection.end=null,this.mousemove&&(Object(N.removeEventListener)(e.view,"mousemove",this.mousemove),delete this.mousemove),this.mouseup&&(Object(N.removeEventListener)(e.view,"mouseup",this.mouseup),delete this.mouseup)},t.deselect=function(e){var t=!!this.multiselection.nodes.length;this.multiselection.nodes.forEach(function(e){e.setSelected(!1)}),this.multiselection.nodes=[],e&&(this.multiselection.start=null,this.multiselection.end=null),t&&this._selectionChangedHandler&&this._selectionChangedHandler()},t.select=function(e){if(!Array.isArray(e))return this.select([e]);var t;e&&(this.deselect(),this.multiselection.nodes=e.slice(0),t=e[0],e.forEach(function(e){e.expandPathToNode(),e.setSelected(!0,e===t)}),this._selectionChangedHandler&&(e=this.getSelection(),this._selectionChangedHandler(e.start,e.end)))},t._findTopLevelNodes=function(e,t){for(var n=e.getNodePath(),i=t.getNodePath(),o=0;o<n.length&&n[o]===i[o];)o++;var r=n[o-1],s=n[o],e=i[o];if(s&&e||(r.parent?r=(e=s=r).parent:(s=r.childs[0],e=r.childs[r.childs.length-1])),r&&s&&e){t=r.childs.indexOf(s),s=r.childs.indexOf(e),e=Math.min(t,s),s=Math.max(t,s);return r.childs.slice(e,s+1)}return[]},t._showAutoComplete=function(t){var n,i=E.getNodeFromTarget(t),o="";0<=t.className.indexOf("jsoneditor-value")&&(o="value"),0<=t.className.indexOf("jsoneditor-field")&&(o="field"),""!==o&&(n=this,setTimeout(function(){var e;!i||!("focus"===n.options.autocomplete.trigger||0<t.innerText.length)||null===(e=n.options.autocomplete.getOptions(t.innerText,i.getPath(),o,i.editor))?n.autocomplete.hideDropDown():"function"==typeof e.then?e.then(function(e){null===e?n.autocomplete.hideDropDown():e.options?n.autocomplete.show(t,e.startFrom,e.options):n.autocomplete.show(t,0,e)}).catch(function(e){console.error(e)}):e.options?n.autocomplete.show(t,e.startFrom,e.options):n.autocomplete.show(t,0,e)},50))},t._onKeyDown=function(e){var t,n=e.which||e.keyCode,i=e.altKey,o=e.ctrlKey,r=e.metaKey,s=e.shiftKey,a=!1,l=this.focusTarget;9===n&&(t=this,setTimeout(function(){t.focusTarget!==l&&Object(N.selectContentEditable)(t.focusTarget)},0)),this.searchBox&&(o&&70===n?(this.searchBox.dom.search.focus(),this.searchBox.dom.search.select(),a=!0):(114===n||o&&71===n)&&(s?this.searchBox.previous(!0):this.searchBox.next(!0),a=!0)),this.history&&(o&&!s&&90===n?(this._onUndo(),a=!0):o&&s&&90===n&&(this._onRedo(),a=!0)),this.options.autocomplete&&!a&&(o||i||r||1!==e.key.length&&8!==n&&46!==n||(a=!1,this._showAutoComplete(e.target))),a&&(e.preventDefault(),e.stopPropagation())},t._createTable=function(){var e;this.options.navigationBar&&Object(N.addClassName)(this.contentOuter,"has-nav-bar"),this.scrollableContent=document.createElement("div"),this.scrollableContent.className="jsoneditor-tree",this.contentOuter.appendChild(this.scrollableContent),this.content=document.createElement("div"),this.content.className="jsoneditor-tree-inner",this.scrollableContent.appendChild(this.content),this.table=document.createElement("table"),this.table.className="jsoneditor-tree",this.content.appendChild(this.table),this.colgroupContent=document.createElement("colgroup"),"tree"===this.options.mode&&((e=document.createElement("col")).width="24px",this.colgroupContent.appendChild(e)),(e=document.createElement("col")).width="24px",this.colgroupContent.appendChild(e),e=document.createElement("col"),this.colgroupContent.appendChild(e),this.table.appendChild(this.colgroupContent),this.tbody=document.createElement("tbody"),this.table.appendChild(this.tbody),this.frame.appendChild(this.contentOuter)},t.showContextMenu=function(e,t){var n,i=[],o=this.multiselection.nodes.slice();i.push({text:Object(l.c)("duplicateText"),title:Object(l.c)("duplicateTitle"),className:"jsoneditor-duplicate",click:function(){E.onDuplicate(o)}}),i.push({text:Object(l.c)("remove"),title:Object(l.c)("removeTitle"),className:"jsoneditor-remove",click:function(){E.onRemove(o)}}),this.options.onCreateMenu&&(n=o.map(function(e){return e.getPath()}),i=this.options.onCreateMenu(i,{type:"multiple",path:n[0],paths:n})),new s.a(i,{close:t}).show(e,this.getPopupAnchor())},t.getPopupAnchor=function(){return this.options.popupAnchor||this.frame},t.getSelection=function(){var e,t,n={start:null,end:null};return this.multiselection.nodes&&this.multiselection.nodes.length&&this.multiselection.nodes.length&&(e=this.multiselection.nodes[0],t=this.multiselection.nodes[this.multiselection.nodes.length-1],"down"===this.multiselection.direction?(n.start=e.serialize(),n.end=t.serialize()):(n.start=t.serialize(),n.end=e.serialize())),n},t.onSelectionChange=function(e){"function"==typeof e&&(this._selectionChangedHandler=Object(N.debounce)(e,this.DEBOUNCE_INTERVAL))},t.setSelection=function(e,t){e&&e.dom&&e.range&&(console.warn("setSelection/getSelection usage for text selection is deprecated and should not be used, see documentation for supported selection options"),this.setDomSelection(e));t=this._getNodeInstancesByRange(e,t);t.forEach(function(e){e.expandTo()}),this.select(t)},t._getNodeInstancesByRange=function(e,t){var n,i;e&&e.path&&(n=this.node.findNodeByPath(e.path),t&&t.path&&(i=this.node.findNodeByPath(t.path)));var o=[];if(n instanceof E)if(i instanceof E&&i!==n)if(n.parent===i.parent){t=n.getIndex()<i.getIndex()?(e=n,i):(e=i,n);var r=e;for(o.push(r);r=r.nextSibling(),o.push(r),r&&r!==t;);}else o=this._findTopLevelNodes(n,i);else o.push(n);return o},t.getNodesByRange=function(e,t){var t=this._getNodeInstancesByRange(e,t),n=[];return t.forEach(function(e){n.push(e.serialize())}),n};var V=[{mode:"tree",mixin:t,data:"json"},{mode:"view",mixin:t,data:"json"},{mode:"form",mixin:t,data:"json"}]},function(e,t,n){"use strict";n.r(t),n.d(t,"previewModeMixins",function(){return m});var t=n(7),i=n.n(t),s=n(2),o=n(15),r=n(8);function a(e,t){for(var n=0;n<t.length;n++){var i=t[n];i.enumerable=i.enumerable||!1,i.configurable=!0,"value"in i&&(i.writable=!0),Object.defineProperty(e,i.key,i)}}var l=function(){function i(e,t,n){!function(e){if(!(e instanceof i))throw new TypeError("Cannot call a class as a function")}(this),this.onChange=e,this.calculateItemSize=t||function(){return 1},this.limit=n,this.items=[],this.index=-1}var e,t,n;return e=i,(t=[{key:"add",value:function(e){for(;this._calculateHistorySize()>this.limit&&1<this.items.length;)this.items.shift(),this.index--;this.items=this.items.slice(0,this.index+1),this.items.push(e),this.index++,this.onChange()}},{key:"_calculateHistorySize",value:function(){var t=this.calculateItemSize,n=0;return this.items.forEach(function(e){n+=t(e)}),n}},{key:"undo",value:function(){if(this.canUndo())return this.index--,this.onChange(),this.items[this.index]}},{key:"redo",value:function(){if(this.canRedo())return this.index++,this.onChange(),this.items[this.index]}},{key:"canUndo",value:function(){return 0<this.index}},{key:"canRedo",value:function(){return this.index<this.items.length-1}},{key:"clear",value:function(){this.items=[],this.index=-1,this.onChange()}}])&&a(e.prototype,t),n&&a(e,n),i}(),c=n(1),d=n(4),h=n(9),u=n(5),p=n(6),t=n(17),f=n(0),n=t.textModeMixins[0].mixin,t={};t.create=function(e){var t=1<arguments.length&&void 0!==arguments[1]?arguments[1]:{};void 0===t.statusBar&&(t.statusBar=!0),t.mainMenuBar=!1!==t.mainMenuBar,t.enableSort=!1!==t.enableSort,t.enableTransform=!1!==t.enableTransform,t.createQuery=t.createQuery||d.a,t.executeQuery=t.executeQuery||d.b,"number"==typeof(this.options=t).indentation?this.indentation=Number(t.indentation):this.indentation=2,Object(c.b)(this.options.languages),Object(c.a)(this.options.language),this.mode="preview";var n=this;this.container=e,this.dom={},this.json=void 0,this.text="",this._debouncedValidate=Object(f.debounce)(this.validate.bind(this),this.DEBOUNCE_INTERVAL),this.width=e.clientWidth,this.height=e.clientHeight,this.frame=document.createElement("div"),this.frame.className="jsoneditor jsoneditor-mode-preview",this.frame.onclick=function(e){e.preventDefault()};var i,e={target:this.frame,onFocus:this.options.onFocus||null,onBlur:this.options.onBlur||null};this.frameFocusTracker=new r.a(e),this.content=document.createElement("div"),this.content.className="jsoneditor-outer",this.dom.busy=document.createElement("div"),this.dom.busy.className="jsoneditor-busy",this.dom.busyContent=document.createElement("span"),this.dom.busyContent.textContent="busy...",this.dom.busy.appendChild(this.dom.busyContent),this.content.appendChild(this.dom.busy),this.dom.previewContent=document.createElement("pre"),this.dom.previewContent.className="jsoneditor-preview",this.dom.previewText=document.createTextNode(""),this.dom.previewContent.appendChild(this.dom.previewText),this.content.appendChild(this.dom.previewContent),this.options.mainMenuBar&&(Object(f.addClassName)(this.content,"has-main-menu-bar"),this.menu=document.createElement("div"),this.menu.className="jsoneditor-menu",this.frame.appendChild(this.menu),(e=document.createElement("button")).type="button",e.className="jsoneditor-format",e.title=Object(c.c)("formatTitle"),this.menu.appendChild(e),e.onclick=function(){n.executeWithBusyMessage(function(){try{n.format()}catch(e){n._onError(e)}},"formatting...")},(e=document.createElement("button")).type="button",e.className="jsoneditor-compact",e.title=Object(c.c)("compactTitle"),this.menu.appendChild(e),e.onclick=function(){n.executeWithBusyMessage(function(){try{n.compact()}catch(e){n._onError(e)}},"compacting...")},this.options.enableSort&&((e=document.createElement("button")).type="button",e.className="jsoneditor-sort",e.title=Object(c.c)("sortTitleShort"),e.onclick=function(){n._showSortModal()},this.menu.appendChild(e)),this.options.enableTransform&&((i=document.createElement("button")).type="button",i.title=Object(c.c)("transformTitleShort"),i.className="jsoneditor-transform",i.onclick=function(){n._showTransformModal()},this.dom.transform=i,this.menu.appendChild(i)),(i=document.createElement("button")).type="button",i.className="jsoneditor-repair",i.title=Object(c.c)("repairTitle"),this.menu.appendChild(i),!(i.onclick=function(){void 0===n.json&&n.executeWithBusyMessage(function(){try{n.repair()}catch(e){n._onError(e)}},"repairing...")})!==this.options.history&&(this.history=new l(function(){n.dom.undo.disabled=!n.history.canUndo(),n.dom.redo.disabled=!n.history.canRedo()},function(e){return 2*e.text.length},s.c),(i=document.createElement("button")).type="button",i.className="jsoneditor-undo jsoneditor-separator",i.title=Object(c.c)("undo"),i.onclick=function(){var e=n.history.undo();e&&n._applyHistory(e)},this.menu.appendChild(i),this.dom.undo=i,(i=document.createElement("button")).type="button",i.className="jsoneditor-redo",i.title=Object(c.c)("redo"),i.onclick=function(){var e=n.history.redo();e&&n._applyHistory(e)},this.menu.appendChild(i),this.dom.redo=i,this.history.onChange()),this.options&&this.options.modes&&this.options.modes.length&&(this.modeSwitcher=new h.a(this.menu,this.options.modes,this.options.mode,function(e){n.setMode(e),n.modeSwitcher.focus()}))),this.errorTable=new o.a({errorTableVisible:!0,onToggleVisibility:function(){n.validate()},onFocusLine:null,onChangeHeight:function(e){e=e+(n.dom.statusBar?n.dom.statusBar.clientHeight:0)+1;n.content.style.marginBottom=-e+"px",n.content.style.paddingBottom=e+"px"}}),this.frame.appendChild(this.content),this.frame.appendChild(this.errorTable.getErrorTable()),this.container.appendChild(this.frame),t.statusBar&&(Object(f.addClassName)(this.content,"has-status-bar"),t=document.createElement("div"),(this.dom.statusBar=t).className="jsoneditor-statusbar",this.frame.appendChild(t),this.dom.fileSizeInfo=document.createElement("span"),this.dom.fileSizeInfo.className="jsoneditor-size-info",this.dom.fileSizeInfo.innerText="",t.appendChild(this.dom.fileSizeInfo),this.dom.arrayInfo=document.createElement("span"),this.dom.arrayInfo.className="jsoneditor-size-info",this.dom.arrayInfo.innerText="",t.appendChild(this.dom.arrayInfo),t.appendChild(this.errorTable.getErrorCounter()),t.appendChild(this.errorTable.getWarningIcon()),t.appendChild(this.errorTable.getErrorIcon())),this._renderPreview(),this.setSchema(this.options.schema,this.options.schemaRefs)},t._renderPreview=function(){var e=this.getText();this.dom.previewText.nodeValue=Object(f.limitCharacters)(e,s.b),this.dom.fileSizeInfo&&(this.dom.fileSizeInfo.innerText="Size: "+Object(f.formatSize)(e.length)),this.dom.arrayInfo&&(Array.isArray(this.json)?this.dom.arrayInfo.innerText="Array: "+this.json.length+" items":this.dom.arrayInfo.innerText="")},t._onChange=function(){if(this._debouncedValidate(),this.options.onChange)try{this.options.onChange()}catch(e){console.error("Error in onChange callback: ",e)}if(this.options.onChangeJSON)try{this.options.onChangeJSON(this.get())}catch(e){console.error("Error in onChangeJSON callback: ",e)}if(this.options.onChangeText)try{this.options.onChangeText(this.getText())}catch(e){console.error("Error in onChangeText callback: ",e)}},t._showSortModal=function(){var r=this;this.executeWithBusyMessage(function(){var e=r.options.modalAnchor||s.a,o=r.get();r._renderPreview(),Object(u.showSortModal)(e,o,function(i){r.executeWithBusyMessage(function(){var e,t,n;e=o,t=i,Array.isArray(e)&&(n=Object(f.sort)(e,t.path,t.direction),r.sortedBy=t,r._setAndFireOnChange(n)),Object(f.isObject)(e)&&(e=Object(f.sortObjectKeys)(e,t.direction),r.sortedBy=t,r._setAndFireOnChange(e))},"sorting...")},r.sortedBy)},"parsing...")},t._showTransformModal=function(){var r=this;this.executeWithBusyMessage(function(){var e=r.options,t=e.createQuery,n=e.executeQuery,i=e.modalAnchor,e=e.queryDescription,o=r.get();r._renderPreview(),Object(p.showTransformModal)({container:i||s.a,json:o,queryDescription:e,createQuery:t,executeQuery:n,onTransform:function(t){r.executeWithBusyMessage(function(){var e=n(o,t);r._setAndFireOnChange(e)},"transforming...")}})},"parsing...")},t.destroy=function(){this.frame&&this.container&&this.frame.parentNode===this.container&&this.container.removeChild(this.frame),this.modeSwitcher&&(this.modeSwitcher.destroy(),this.modeSwitcher=null),this._debouncedValidate=null,this.history&&(this.history.clear(),this.history=null),this.frameFocusTracker.destroy()},t.compact=function(){var e=this.get(),t=JSON.stringify(e);this._setTextAndFireOnChange(t,e)},t.format=function(){var e=this.get(),t=JSON.stringify(e,null,this.indentation);this._setTextAndFireOnChange(t,e)},t.repair=function(){var e=this.getText();try{var t=i()(e);this._setTextAndFireOnChange(t)}catch(e){}},t.focus=function(){this.dom.transform.focus()},t.set=function(e){this.history&&this.history.clear(),this._set(e)},t.update=function(e){this._set(e)},t._set=function(e){this.text=void 0,this.json=e,this._renderPreview(),this._pushHistory(),this._debouncedValidate()},t._setAndFireOnChange=function(e){this._set(e),this._onChange()},t.get=function(){var e;return void 0===this.json&&(e=this.getText(),this.json=Object(f.parse)(e)),this.json},t.getText=function(){return void 0===this.text&&(this.text=JSON.stringify(this.json,null,this.indentation),!0===this.options.escapeUnicode&&(this.text=Object(f.escapeUnicodeChars)(this.text))),this.text},t.setText=function(e){this.history&&this.history.clear(),this._setText(e)},t.updateText=function(e){this.getText()!==e&&this._setText(e)},t._setText=function(e,t){var n;!0===this.options.escapeUnicode?this.text=Object(f.escapeUnicodeChars)(e):this.text=e,this.json=t,this._renderPreview(),void 0===this.json?(n=this).executeWithBusyMessage(function(){try{n.json=n.get(),n._renderPreview(),n._pushHistory()}catch(e){}},"parsing..."):this._pushHistory(),this._debouncedValidate()},t._setTextAndFireOnChange=function(e,t){this._setText(e,t),this._onChange()},t._applyHistory=function(e){this.json=e.json,this.text=e.text,this._renderPreview(),this._debouncedValidate()},t._pushHistory=function(){var e;this.history&&(e={text:this.text,json:this.json},this.history.add(e))},t.executeWithBusyMessage=function(e,t){var n;this.getText().length>s.d?(n=this,Object(f.addClassName)(n.frame,"busy"),n.dom.busyContent.innerText=t,setTimeout(function(){e(),Object(f.removeClassName)(n.frame,"busy"),n.dom.busyContent.innerText=""},100)):e()},t.validate=n.validate,t._renderErrors=n._renderErrors;var m=[{mode:"preview",mixin:t,data:"json"}]}],o.c=i,o.d=function(e,t,n){o.o(e,t)||Object.defineProperty(e,t,{enumerable:!0,get:n})},o.r=function(e){"undefined"!=typeof Symbol&&Symbol.toStringTag&&Object.defineProperty(e,Symbol.toStringTag,{value:"Module"}),Object.defineProperty(e,"__esModule",{value:!0})},o.t=function(t,e){if(1&e&&(t=o(t)),8&e)return t;if(4&e&&"object"==typeof t&&t&&t.__esModule)return t;var n=Object.create(null);if(o.r(n),Object.defineProperty(n,"default",{enumerable:!0,value:t}),2&e&&"string"!=typeof t)for(var i in t)o.d(n,i,function(e){return t[e]}.bind(null,i));return n},o.n=function(e){var t=e&&e.__esModule?function(){return e.default}:function(){return e};return o.d(t,"a",t),t},o.o=function(e,t){return Object.prototype.hasOwnProperty.call(e,t)},o.p="",o(o.s=23);function o(e){if(i[e])return i[e].exports;var t=i[e]={i:e,l:!1,exports:{}};return n[e].call(t.exports,t,t.exports,o),t.l=!0,t.exports}var n,i});
//# sourceMappingURL=jsoneditor-minimalist.map